Class: Google::Cloud::Ces::V1beta::Action
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Action
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/connector_tool.rb
Overview
Configuration of an Action for the tool to use. Note: This can be either an Action or an Operation. See https://cloud.google.com/integration-connectors/docs/entities-operation-action for details.
Defined Under Namespace
Classes: EntityOperation
Instance Attribute Summary collapse
-
#connection_action_id ⇒ ::String
ID of a Connection action for the tool to use.
-
#entity_operation ⇒ ::Google::Cloud::Ces::V1beta::Action::EntityOperation
Entity operation configuration for the tool to use.
-
#input_fields ⇒ ::Array<::String>
Optional.
-
#output_fields ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#connection_action_id ⇒ ::String
Returns ID of a Connection action for the tool to use.
Note: The following fields are mutually exclusive: connection_action_id, entity_operation. If a field in that set is populated, all other fields in the set will automatically be cleared.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/ces/v1beta/connector_tool.rb', line 46 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entity CRUD operation specification. # @!attribute [rw] entity_id # @return [::String] # Required. ID of the entity. # @!attribute [rw] operation # @return [::Google::Cloud::Ces::V1beta::Action::EntityOperation::OperationType] # Required. Operation to perform on the entity. class EntityOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The operation to perform on the entity. module OperationType # Operation type unspecified. Invalid, ConnectorTool create/update # will fail. OPERATION_TYPE_UNSPECIFIED = 0 # List operation. LIST = 1 # Get operation. GET = 2 # Create operation. CREATE = 3 # Update operation. UPDATE = 4 # Delete operation. DELETE = 5 end end end |
#entity_operation ⇒ ::Google::Cloud::Ces::V1beta::Action::EntityOperation
Returns Entity operation configuration for the tool to use.
Note: The following fields are mutually exclusive: entity_operation, connection_action_id. If a field in that set is populated, all other fields in the set will automatically be cleared.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/ces/v1beta/connector_tool.rb', line 46 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entity CRUD operation specification. # @!attribute [rw] entity_id # @return [::String] # Required. ID of the entity. # @!attribute [rw] operation # @return [::Google::Cloud::Ces::V1beta::Action::EntityOperation::OperationType] # Required. Operation to perform on the entity. class EntityOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The operation to perform on the entity. module OperationType # Operation type unspecified. Invalid, ConnectorTool create/update # will fail. OPERATION_TYPE_UNSPECIFIED = 0 # List operation. LIST = 1 # Get operation. GET = 2 # Create operation. CREATE = 3 # Update operation. UPDATE = 4 # Delete operation. DELETE = 5 end end end |
#input_fields ⇒ ::Array<::String>
Returns Optional. Entity fields to use as inputs for the operation. If no fields are specified, all fields of the Entity will be used.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/ces/v1beta/connector_tool.rb', line 46 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entity CRUD operation specification. # @!attribute [rw] entity_id # @return [::String] # Required. ID of the entity. # @!attribute [rw] operation # @return [::Google::Cloud::Ces::V1beta::Action::EntityOperation::OperationType] # Required. Operation to perform on the entity. class EntityOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The operation to perform on the entity. module OperationType # Operation type unspecified. Invalid, ConnectorTool create/update # will fail. OPERATION_TYPE_UNSPECIFIED = 0 # List operation. LIST = 1 # Get operation. GET = 2 # Create operation. CREATE = 3 # Update operation. UPDATE = 4 # Delete operation. DELETE = 5 end end end |
#output_fields ⇒ ::Array<::String>
Returns Optional. Entity fields to return from the operation. If no fields are specified, all fields of the Entity will be returned.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/ces/v1beta/connector_tool.rb', line 46 class Action include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entity CRUD operation specification. # @!attribute [rw] entity_id # @return [::String] # Required. ID of the entity. # @!attribute [rw] operation # @return [::Google::Cloud::Ces::V1beta::Action::EntityOperation::OperationType] # Required. Operation to perform on the entity. class EntityOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The operation to perform on the entity. module OperationType # Operation type unspecified. Invalid, ConnectorTool create/update # will fail. OPERATION_TYPE_UNSPECIFIED = 0 # List operation. LIST = 1 # Get operation. GET = 2 # Create operation. CREATE = 3 # Update operation. UPDATE = 4 # Delete operation. DELETE = 5 end end end |