Class: Google::Cloud::Ces::V1beta::Agent::LlmAgent
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Agent::LlmAgent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent.rb
Overview
Default agent type. The agent uses instructions and callbacks specified in the agent to perform the task using a large language model.