Class: Google::Cloud::Ces::V1beta::AgentSkill

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_card.rb

Overview

Represents a distinct capability or function that an agent can perform.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Required. A detailed description of the skill.

Returns:

  • (::String)

    Required. A detailed description of the skill.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#examples::Array<::String>

Returns Example prompts or scenarios that this skill can handle.

Returns:

  • (::Array<::String>)

    Example prompts or scenarios that this skill can handle.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns Required. A unique identifier for the agent's skill.

Returns:

  • (::String)

    Required. A unique identifier for the agent's skill.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#input_modes::Array<::String>

Returns The set of supported input media types for this skill, overriding the agent's defaults.

Returns:

  • (::Array<::String>)

    The set of supported input media types for this skill, overriding the agent's defaults.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. A human-readable name for the skill.

Returns:

  • (::String)

    Required. A human-readable name for the skill.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_modes::Array<::String>

Returns The set of supported output media types for this skill, overriding the agent's defaults.

Returns:

  • (::Array<::String>)

    The set of supported output media types for this skill, overriding the agent's defaults.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tags::Array<::String>

Returns Required. A set of keywords describing the skill's capabilities.

Returns:

  • (::Array<::String>)

    Required. A set of keywords describing the skill's capabilities.



100
101
102
103
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 100

class AgentSkill
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end