Class: Google::Cloud::Ces::V1beta::AgentTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::AgentTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_tool.rb
Overview
Represents a tool that allows the agent to call another agent.
Instance Attribute Summary collapse
-
#agent ⇒ ::String
Optional.
-
#description ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#agent ⇒ ::String
Returns Optional. The resource name of the agent that is the entry point of the
tool. Format: projects/{project}/locations/{location}/agents/{agent}.
35 36 37 38 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_tool.rb', line 35 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |