Class: Google::Cloud::Ces::V1beta::ApiAuthentication
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ApiAuthentication
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/auth.rb
Overview
Authentication information required for API calls.
Instance Attribute Summary collapse
-
#api_key_config ⇒ ::Google::Cloud::Ces::V1beta::ApiKeyConfig
Optional.
-
#bearer_token_config ⇒ ::Google::Cloud::Ces::V1beta::BearerTokenConfig
Optional.
-
#oauth_config ⇒ ::Google::Cloud::Ces::V1beta::OAuthConfig
Optional.
-
#service_account_auth_config ⇒ ::Google::Cloud::Ces::V1beta::ServiceAccountAuthConfig
Optional.
-
#service_agent_id_token_auth_config ⇒ ::Google::Cloud::Ces::V1beta::ServiceAgentIdTokenAuthConfig
Optional.
Instance Attribute Details
#api_key_config ⇒ ::Google::Cloud::Ces::V1beta::ApiKeyConfig
Returns Optional. Config for API key auth.
Note: The following fields are mutually exclusive: api_key_config, oauth_config, service_agent_id_token_auth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
207 208 209 210 |
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 207 class ApiAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bearer_token_config ⇒ ::Google::Cloud::Ces::V1beta::BearerTokenConfig
Returns Optional. Config for bearer token auth.
Note: The following fields are mutually exclusive: bearer_token_config, api_key_config, oauth_config, service_agent_id_token_auth_config, service_account_auth_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
207 208 209 210 |
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 207 class ApiAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#oauth_config ⇒ ::Google::Cloud::Ces::V1beta::OAuthConfig
Returns Optional. Config for OAuth.
Note: The following fields are mutually exclusive: oauth_config, api_key_config, service_agent_id_token_auth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
207 208 209 210 |
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 207 class ApiAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_account_auth_config ⇒ ::Google::Cloud::Ces::V1beta::ServiceAccountAuthConfig
Returns Optional. Config for service account authentication.
Note: The following fields are mutually exclusive: service_account_auth_config, api_key_config, oauth_config, service_agent_id_token_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
207 208 209 210 |
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 207 class ApiAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_agent_id_token_auth_config ⇒ ::Google::Cloud::Ces::V1beta::ServiceAgentIdTokenAuthConfig
Returns Optional. Config for ID token auth generated from CES service agent.
Note: The following fields are mutually exclusive: service_agent_id_token_auth_config, api_key_config, oauth_config, service_account_auth_config, bearer_token_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
207 208 209 210 |
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 207 class ApiAuthentication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |