Class: Google::Cloud::Ces::V1beta::ApiKeyConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/auth.rb

Overview

Configurations for authentication with API key.

Defined Under Namespace

Modules: RequestLocation

Instance Attribute Summary collapse

Instance Attribute Details

#api_key_secret_version::String

Returns Required. The name of the SecretManager secret version resource storing the API key. Format: projects/{project}/secrets/{secret}/versions/{version}

Note: You should grant roles/secretmanager.secretAccessor role to the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.

Returns:

  • (::String)

    Required. The name of the SecretManager secret version resource storing the API key. Format: projects/{project}/secrets/{secret}/versions/{version}

    Note: You should grant roles/secretmanager.secretAccessor role to the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 41

class ApiKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location of the API key in the request.
  module RequestLocation
    # Unspecified. This value should not be used.
    REQUEST_LOCATION_UNSPECIFIED = 0

    # Represents the key in http header.
    HEADER = 1

    # Represents the key in query string.
    QUERY_STRING = 2
  end
end

#key_name::String

Returns Required. The parameter name or the header name of the API key. E.g., If the API request is "https://example.com/act?X-Api-Key=", "X-Api-Key" would be the parameter name.

Returns:

  • (::String)

    Required. The parameter name or the header name of the API key. E.g., If the API request is "https://example.com/act?X-Api-Key=", "X-Api-Key" would be the parameter name.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 41

class ApiKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location of the API key in the request.
  module RequestLocation
    # Unspecified. This value should not be used.
    REQUEST_LOCATION_UNSPECIFIED = 0

    # Represents the key in http header.
    HEADER = 1

    # Represents the key in query string.
    QUERY_STRING = 2
  end
end

#request_location::Google::Cloud::Ces::V1beta::ApiKeyConfig::RequestLocation

Returns Required. Key location in the request.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/auth.rb', line 41

class ApiKeyConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The location of the API key in the request.
  module RequestLocation
    # Unspecified. This value should not be used.
    REQUEST_LOCATION_UNSPECIFIED = 0

    # Represents the key in http header.
    HEADER = 1

    # Represents the key in query string.
    QUERY_STRING = 2
  end
end