Class: Google::Cloud::Ces::V1beta::App
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::App
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app's context.
Defined Under Namespace
Modules: ToolExecutionMode Classes: MetadataEntry, VariableDeclaration
Instance Attribute Summary collapse
-
#audio_processing_config ⇒ ::Google::Cloud::Ces::V1beta::AudioProcessingConfig
Optional.
-
#client_certificate_settings ⇒ ::Google::Cloud::Ces::V1beta::ClientCertificateSettings
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#data_store_settings ⇒ ::Google::Cloud::Ces::V1beta::DataStoreSettings
Optional.
-
#default_channel_profile ⇒ ::Google::Cloud::Ces::V1beta::ChannelProfile
Optional.
-
#deployment_count ⇒ ::Integer
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#error_handling_settings ⇒ ::Google::Cloud::Ces::V1beta::ErrorHandlingSettings
Optional.
-
#etag ⇒ ::String
readonly
Output only.
-
#evaluation_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds
Optional.
-
#evaluation_personas ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationPersona>
Optional.
-
#evaluation_settings ⇒ ::Google::Cloud::Ces::V1beta::EvaluationSettings
Optional.
-
#global_instruction ⇒ ::String
Optional.
-
#guardrails ⇒ ::Array<::String>
Optional.
-
#language_settings ⇒ ::Google::Cloud::Ces::V1beta::LanguageSettings
Optional.
-
#locked ⇒ ::Boolean
Optional.
-
#logging_settings ⇒ ::Google::Cloud::Ces::V1beta::LoggingSettings
Optional.
-
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#model_settings ⇒ ::Google::Cloud::Ces::V1beta::ModelSettings
Optional.
-
#name ⇒ ::String
Identifier.
-
#pinned ⇒ ::Boolean
Optional.
-
#predefined_variable_declarations ⇒ ::Array<::Google::Cloud::Ces::V1beta::App::VariableDeclaration>
readonly
Output only.
-
#root_agent ⇒ ::String
Optional.
-
#time_zone_settings ⇒ ::Google::Cloud::Ces::V1beta::TimeZoneSettings
Optional.
-
#tool_execution_mode ⇒ ::Google::Cloud::Ces::V1beta::App::ToolExecutionMode
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#variable_declarations ⇒ ::Array<::Google::Cloud::Ces::V1beta::App::VariableDeclaration>
Optional.
Instance Attribute Details
#audio_processing_config ⇒ ::Google::Cloud::Ces::V1beta::AudioProcessingConfig
Returns Optional. Audio processing configuration of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#client_certificate_settings ⇒ ::Google::Cloud::Ces::V1beta::ClientCertificateSettings
Returns Optional. The default client certificate settings for the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the app was created.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#data_store_settings ⇒ ::Google::Cloud::Ces::V1beta::DataStoreSettings
Returns Optional. The data store settings for the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#default_channel_profile ⇒ ::Google::Cloud::Ces::V1beta::ChannelProfile
Returns Optional. The default channel profile used by the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#deployment_count ⇒ ::Integer (readonly)
Returns Output only. Number of deployments in the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#description ⇒ ::String
Returns Optional. Human-readable description of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#display_name ⇒ ::String
Returns Required. Display name of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#error_handling_settings ⇒ ::Google::Cloud::Ces::V1beta::ErrorHandlingSettings
Returns Optional. Error handling settings of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#etag ⇒ ::String (readonly)
Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#evaluation_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds
Returns Optional. The evaluation thresholds for the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#evaluation_personas ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationPersona>
Returns Optional. The evaluation personas for the app. This field is used to define the personas that can be used for evaluation. Maximum of 30 personas can be defined.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#evaluation_settings ⇒ ::Google::Cloud::Ces::V1beta::EvaluationSettings
Returns Optional. The evaluation settings for the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#global_instruction ⇒ ::String
Returns Optional. Instructions for all the agents in the app. You can use this instruction to set up a stable identity or personality across all the agents.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#guardrails ⇒ ::Array<::String>
Returns Optional. List of guardrails for the app.
Format:
projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#language_settings ⇒ ::Google::Cloud::Ces::V1beta::LanguageSettings
Returns Optional. Language settings of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#locked ⇒ ::Boolean
Returns Optional. Indicates whether the app is locked for changes. If the app is locked, modifications to the app resources will be rejected.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#logging_settings ⇒ ::Google::Cloud::Ces::V1beta::LoggingSettings
Returns Optional. Logging settings of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Metadata about the app. This field can be used to store additional information relevant to the app's details or intended usages.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#model_settings ⇒ ::Google::Cloud::Ces::V1beta::ModelSettings
Returns Optional. The default LLM model settings for the app. Individual resources (e.g. agents, guardrails) can override these configurations as needed.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#name ⇒ ::String
Returns Identifier. The unique identifier of the app.
Format: projects/{project}/locations/{location}/apps/{app}.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#pinned ⇒ ::Boolean
Returns Optional. Whether the app is pinned in the app list.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#predefined_variable_declarations ⇒ ::Array<::Google::Cloud::Ces::V1beta::App::VariableDeclaration> (readonly)
Returns Output only. The declarations of predefined variables for the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#root_agent ⇒ ::String
Returns Optional. The root agent is the entry point of the app.
Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#time_zone_settings ⇒ ::Google::Cloud::Ces::V1beta::TimeZoneSettings
Returns Optional. TimeZone settings of the app.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#tool_execution_mode ⇒ ::Google::Cloud::Ces::V1beta::App::ToolExecutionMode
Returns Optional. The tool execution mode for the app. If not provided, will default to PARALLEL.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the app was last updated.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |
#variable_declarations ⇒ ::Array<::Google::Cloud::Ces::V1beta::App::VariableDeclaration>
Returns Optional. The declarations of the variables.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 127 class App include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the structure and metadata for a variable. # @!attribute [rw] name # @return [::String] # Required. The name of the variable. The name must start with a letter or # underscore and contain only letters, numbers, or underscores. # @!attribute [rw] description # @return [::String] # Required. The description of the variable. # @!attribute [rw] schema # @return [::Google::Cloud::Ces::V1beta::Schema] # Required. The schema of the variable. class VariableDeclaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Defines the tool execution behavior if there are **multiple** tools being # selected by the agent **at the same time**. module ToolExecutionMode # Unspecified tool execution mode. Default to PARALLEL. TOOL_EXECUTION_MODE_UNSPECIFIED = 0 # If there are multiple tools being selected, they will be executed in # parallel, with the same # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context). PARALLEL = 1 # If there are multiple tools being selected, they will be executed # sequentially. The next tool will only be executed after the previous tool # completes and it can see updated # [ToolContext](https://google.github.io/adk-docs/context/#the-different-types-of-context) # from the previous tool. SEQUENTIAL = 2 end end |