Module: Google::Cloud::Ces::V1beta::App::ToolExecutionMode
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Defines the tool execution behavior if there are multiple tools being selected by the agent at the same time.
Constant Summary collapse
- TOOL_EXECUTION_MODE_UNSPECIFIED =
Unspecified tool execution mode. Default to PARALLEL.
0- PARALLEL =
If there are multiple tools being selected, they will be executed in parallel, with the same ToolContext.
1- SEQUENTIAL =
If there are multiple tools being selected, they will be executed sequentially. The next tool will only be executed after the previous tool completes and it can see updated ToolContext from the previous tool.
2