Class: Google::Cloud::Ces::V1beta::App::VariableDeclaration

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Defines the structure and metadata for a variable.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Required. The description of the variable.

Returns:

  • (::String)

    Required. The description of the variable.



142
143
144
145
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 142

class VariableDeclaration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the variable. The name must start with a letter or underscore and contain only letters, numbers, or underscores.

Returns:

  • (::String)

    Required. The name of the variable. The name must start with a letter or underscore and contain only letters, numbers, or underscores.



142
143
144
145
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 142

class VariableDeclaration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema::Google::Cloud::Ces::V1beta::Schema

Returns Required. The schema of the variable.

Returns:



142
143
144
145
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 142

class VariableDeclaration
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end