Class: Google::Cloud::Ces::V1beta::AppVersion
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::AppVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app_version.rb
Overview
In Customer Engagement Suite (CES), an app version is a snapshot of the app at a specific point in time. It is immutable and cannot be modified once created.
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#creator ⇒ ::String
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Optional.
-
#etag ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#snapshot ⇒ ::Google::Cloud::Ces::V1beta::AppSnapshot
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the app version was created.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creator ⇒ ::String (readonly)
Returns Output only. Email of the user who created the app version.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. The description of the app version.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. The display name of the app version.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String (readonly)
Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The unique identifier of the app version.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#snapshot ⇒ ::Google::Cloud::Ces::V1beta::AppSnapshot (readonly)
Returns Output only. The snapshot of the app when the version is created.
76 77 78 79 |
# File 'proto_docs/google/cloud/ces/v1beta/app_version.rb', line 76 class AppVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |