Class: Google::Cloud::Ces::V1beta::AudioRecordingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Configuration for how the audio interactions should be recorded.

Instance Attribute Summary collapse

Instance Attribute Details

#gcs_bucket::String

Returns Optional. The Cloud Storage bucket to store the session audio recordings. The URI must start with "gs://".

Please choose a bucket location that meets your data residency requirements.

Note: If the Cloud Storage bucket is in a different project from the app, you should grant storage.objects.create permission to the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.

Returns:

  • (::String)

    Optional. The Cloud Storage bucket to store the session audio recordings. The URI must start with "gs://".

    Please choose a bucket location that meets your data residency requirements.

    Note: If the Cloud Storage bucket is in a different project from the app, you should grant storage.objects.create permission to the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.



702
703
704
705
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 702

class AudioRecordingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs_path_prefix::String

Returns Optional. The Cloud Storage path prefix for audio recordings.

This prefix can include the following placeholders, which will be dynamically substituted at serving time:

  • $project: project ID
  • $location: app location
  • $app: app ID
  • $date: session date in YYYY-MM-DD format
  • $session: session ID

If the path prefix is not specified, the default prefix $project/$location/$app/$date/$session/ will be used.

Returns:

  • (::String)

    Optional. The Cloud Storage path prefix for audio recordings.

    This prefix can include the following placeholders, which will be dynamically substituted at serving time:

    • $project: project ID
    • $location: app location
    • $app: app ID
    • $date: session date in YYYY-MM-DD format
    • $session: session ID

    If the path prefix is not specified, the default prefix $project/$location/$app/$date/$session/ will be used.



702
703
704
705
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 702

class AudioRecordingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end