Class: Google::Cloud::Ces::V1beta::BidiSessionClientMessage
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::BidiSessionClientMessage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/session_service.rb
Overview
The top-level message sent by the client for the SessionService.BidiRunSession method.
Instance Attribute Summary collapse
-
#config ⇒ ::Google::Cloud::Ces::V1beta::SessionConfig
Optional.
-
#realtime_input ⇒ ::Google::Cloud::Ces::V1beta::SessionInput
Optional.
Instance Attribute Details
#config ⇒ ::Google::Cloud::Ces::V1beta::SessionConfig
Returns Optional. The initial config message for the session.
Note: The following fields are mutually exclusive: config, realtime_input. If a field in that set is populated, all other fields in the set will automatically be cleared.
434 435 436 437 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 434 class BidiSessionClientMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#realtime_input ⇒ ::Google::Cloud::Ces::V1beta::SessionInput
Returns Optional. Realtime input for the session.
Note: The following fields are mutually exclusive: realtime_input, config. If a field in that set is populated, all other fields in the set will automatically be cleared.
434 435 436 437 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 434 class BidiSessionClientMessage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |