Class: Google::Cloud::Ces::V1beta::BidiSessionServerMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/session_service.rb

Overview

The top-level message returned from SessionService.BidiRunSession method.

Instance Attribute Summary collapse

Instance Attribute Details

#end_session::Google::Cloud::Ces::V1beta::EndSession

Returns Optional. Indicates that the session has ended.

Note: The following fields are mutually exclusive: end_session, session_output, recognition_result, interruption_signal, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::EndSession)

    Optional. Indicates that the session has ended.

    Note: The following fields are mutually exclusive: end_session, session_output, recognition_result, interruption_signal, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.



468
469
470
471
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 468

class BidiSessionServerMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#go_away::Google::Cloud::Ces::V1beta::GoAway

Returns Optional. Indicates that the server will disconnect soon and the client should half-close and restart the connection.

Note: The following fields are mutually exclusive: go_away, session_output, recognition_result, interruption_signal, end_session. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::GoAway)

    Optional. Indicates that the server will disconnect soon and the client should half-close and restart the connection.

    Note: The following fields are mutually exclusive: go_away, session_output, recognition_result, interruption_signal, end_session. If a field in that set is populated, all other fields in the set will automatically be cleared.



468
469
470
471
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 468

class BidiSessionServerMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#interruption_signal::Google::Cloud::Ces::V1beta::InterruptionSignal

Returns Optional. Indicates the agent's audio response has been interrupted.

Note: The following fields are mutually exclusive: interruption_signal, session_output, recognition_result, end_session, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::InterruptionSignal)

    Optional. Indicates the agent's audio response has been interrupted.

    Note: The following fields are mutually exclusive: interruption_signal, session_output, recognition_result, end_session, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.



468
469
470
471
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 468

class BidiSessionServerMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#recognition_result::Google::Cloud::Ces::V1beta::RecognitionResult

Returns Optional. Realtime speech recognition result for the audio input.

Note: The following fields are mutually exclusive: recognition_result, session_output, interruption_signal, end_session, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::RecognitionResult)

    Optional. Realtime speech recognition result for the audio input.

    Note: The following fields are mutually exclusive: recognition_result, session_output, interruption_signal, end_session, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.



468
469
470
471
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 468

class BidiSessionServerMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_output::Google::Cloud::Ces::V1beta::SessionOutput

Returns Optional. Processing result from the CES agent.

Note: The following fields are mutually exclusive: session_output, recognition_result, interruption_signal, end_session, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::SessionOutput)

    Optional. Processing result from the CES agent.

    Note: The following fields are mutually exclusive: session_output, recognition_result, interruption_signal, end_session, go_away. If a field in that set is populated, all other fields in the set will automatically be cleared.



468
469
470
471
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 468

class BidiSessionServerMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end