Class: Google::Cloud::Ces::V1beta::BigQueryExportSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/bigquery_export.rb

Overview

Settings to describe the BigQuery export behaviors for the app.

Instance Attribute Summary collapse

Instance Attribute Details

#dataset::String

Returns Optional. The BigQuery dataset ID to export the data to.

Returns:

  • (::String)

    Optional. The BigQuery dataset ID to export the data to.



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/bigquery_export.rb', line 38

class BigQueryExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enabled::Boolean

Returns Optional. Indicates whether the BigQuery export is enabled.

Returns:

  • (::Boolean)

    Optional. Indicates whether the BigQuery export is enabled.



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/bigquery_export.rb', line 38

class BigQueryExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project::String

Returns Optional. The project ID of the BigQuery dataset to export the data to.

Note: If the BigQuery dataset is in a different project from the app, you should grant roles/bigquery.admin role to the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.

Returns:

  • (::String)

    Optional. The project ID of the BigQuery dataset to export the data to.

    Note: If the BigQuery dataset is in a different project from the app, you should grant roles/bigquery.admin role to the CES service agent service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com.



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/bigquery_export.rb', line 38

class BigQueryExportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end