Class: Google::Cloud::Ces::V1beta::Callback

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/common.rb

Overview

A callback defines the custom logic to be executed at various stages of agent interaction.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. Human-readable description of the callback.

Returns:

  • (::String)

    Optional. Human-readable description of the callback.



44
45
46
47
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44

class Callback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#disabled::Boolean

Returns Optional. Whether the callback is disabled. Disabled callbacks are ignored by the agent.

Returns:

  • (::Boolean)

    Optional. Whether the callback is disabled. Disabled callbacks are ignored by the agent.



44
45
46
47
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44

class Callback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#proactive_execution_enabled::Boolean

Returns Optional. If enabled, the callback will also be executed on intermediate model outputs. This setting only affects after model callback. ENABLE WITH CAUTION. Typically after model callback only needs to be executed after receiving all model responses. Enabling proactive execution may have negative implication on the execution cost and latency, and should only be enabled in rare situations.

Returns:

  • (::Boolean)

    Optional. If enabled, the callback will also be executed on intermediate model outputs. This setting only affects after model callback. ENABLE WITH CAUTION. Typically after model callback only needs to be executed after receiving all model responses. Enabling proactive execution may have negative implication on the execution cost and latency, and should only be enabled in rare situations.



44
45
46
47
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44

class Callback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#python_code::String

Returns Required. The python code to execute for the callback.

Returns:

  • (::String)

    Required. The python code to execute for the callback.



44
45
46
47
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44

class Callback
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end