Class: Google::Cloud::Ces::V1beta::Changelog
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Changelog
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/changelog.rb
Overview
Changelogs represent a change made to the app or to an resource within the app.
Instance Attribute Summary collapse
-
#action ⇒ ::String
readonly
Output only.
-
#author ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#dependent_resources ⇒ ::Array<::Google::Protobuf::Struct>
readonly
Output only.
-
#description ⇒ ::String
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#new_resource ⇒ ::Google::Protobuf::Struct
readonly
Output only.
-
#original_resource ⇒ ::Google::Protobuf::Struct
readonly
Output only.
-
#resource ⇒ ::String
readonly
Output only.
-
#resource_type ⇒ ::String
readonly
Output only.
-
#sequence_number ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#action ⇒ ::String (readonly)
Returns Output only. The action that was performed on the resource.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#author ⇒ ::String (readonly)
Returns Output only. Email address of the change author.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the change was made.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dependent_resources ⇒ ::Array<::Google::Protobuf::Struct> (readonly)
Returns Output only. The dependent resources that were changed.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String (readonly)
Returns Output only. Description of the change. which typically captures the changed fields in the resource.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String (readonly)
Returns Output only. Display name of the change. It typically should be the display name of the resource that was changed.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The unique identifier of the changelog.
Format:
projects/{project}/locations/{location}/apps/{app}/changelogs/{changelog}.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_resource ⇒ ::Google::Protobuf::Struct (readonly)
Returns Output only. The new resource after the change.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#original_resource ⇒ ::Google::Protobuf::Struct (readonly)
Returns Output only. The original resource before the change.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource ⇒ ::String (readonly)
Returns Output only. The resource that was changed.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_type ⇒ ::String (readonly)
Returns Output only. The type of the resource that was changed.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sequence_number ⇒ ::Integer (readonly)
Returns Output only. The monotonically increasing sequence number of the changelog.
66 67 68 69 |
# File 'proto_docs/google/cloud/ces/v1beta/changelog.rb', line 66 class Changelog include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |