Class: Google::Cloud::Ces::V1beta::ChannelProfile::PersonaProperty
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ChannelProfile::PersonaProperty
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/common.rb
Overview
Represents the persona property of a channel.
Defined Under Namespace
Modules: Persona
Instance Attribute Summary collapse
Instance Attribute Details
#persona ⇒ ::Google::Cloud::Ces::V1beta::ChannelProfile::PersonaProperty::Persona
Returns Optional. The persona of the channel.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 213 class PersonaProperty include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The persona of the channel. module Persona # UNKNOWN persona. UNKNOWN = 0 # The agent keeps the responses concise and to the point CONCISE = 1 # The agent provides additional context, explanations, and details CHATTY = 2 end end |