Class: Google::Cloud::Ces::V1beta::ChannelProfile::WebWidgetConfig::SecuritySettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/common.rb

Overview

Security settings for the web widget.

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_origins::Array<::String>

Returns Optional. The origins that are allowed to host the web widget. An origin is defined by RFC 6454. If empty, all origins are allowed. A maximum of 100 origins is allowed. Example: "https://example.com".

Returns:

  • (::Array<::String>)

    Optional. The origins that are allowed to host the web widget. An origin is defined by RFC 6454. If empty, all origins are allowed. A maximum of 100 origins is allowed. Example: "https://example.com"



270
271
272
273
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 270

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_origin_check::Boolean

Returns Optional. Indicates whether origin check for the web widget is enabled. If true, the web widget will check the origin of the website that loads the web widget and only allow it to be loaded in the same origin or any of the allowed origins.

Returns:

  • (::Boolean)

    Optional. Indicates whether origin check for the web widget is enabled. If true, the web widget will check the origin of the website that loads the web widget and only allow it to be loaded in the same origin or any of the allowed origins.



270
271
272
273
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 270

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_public_access::Boolean

Returns Optional. Indicates whether public access to the web widget is enabled. If true, the web widget will be publicly accessible. If false, the web widget must be integrated with your own authentication and authorization system to return valid credentials for accessing the CES agent.

Returns:

  • (::Boolean)

    Optional. Indicates whether public access to the web widget is enabled. If true, the web widget will be publicly accessible. If false, the web widget must be integrated with your own authentication and authorization system to return valid credentials for accessing the CES agent.



270
271
272
273
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 270

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_recaptcha::Boolean

Returns Optional. Indicates whether reCAPTCHA verification for the web widget is enabled.

Returns:

  • (::Boolean)

    Optional. Indicates whether reCAPTCHA verification for the web widget is enabled.



270
271
272
273
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 270

class SecuritySettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end