Class: Google::Cloud::Ces::V1beta::ChannelProfile::WhatsAppConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/common.rb

Overview

Configuration specific to WhatsApp deployments.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String (readonly)

Returns Output only. The description of the Meta business page or profile.

Returns:

  • (::String)

    Output only. The description of the Meta business page or profile.



331
332
333
334
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 331

class WhatsAppConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. The fetched Meta business page name.

Returns:

  • (::String)

    Output only. The fetched Meta business page name.



331
332
333
334
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 331

class WhatsAppConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phone_number::String

Returns Optional. The phone number in E.164 format.

Returns:

  • (::String)

    Optional. The phone number in E.164 format.



331
332
333
334
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 331

class WhatsAppConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phone_number_id::String

Returns Required. The Meta phone number ID.

Returns:

  • (::String)

    Required. The Meta phone number ID.



331
332
333
334
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 331

class WhatsAppConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#thumbnail_url::String (readonly)

Returns Output only. The fetched Meta business profile thumbnail URL.

Returns:

  • (::String)

    Output only. The fetched Meta business profile thumbnail URL.



331
332
333
334
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 331

class WhatsAppConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#waba_id::String

Returns Required. The WhatsApp Business Account ID.

Returns:

  • (::String)

    Required. The WhatsApp Business Account ID.



331
332
333
334
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 331

class WhatsAppConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end