Class: Google::Cloud::Ces::V1beta::ClientCertificateSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings for custom client certificates.

Instance Attribute Summary collapse

Instance Attribute Details

#passphrase::String

Returns Optional. The name of the SecretManager secret version resource storing the passphrase to decrypt the private key. Should be left unset if the private key is not encrypted. Format: projects/{project}/secrets/{secret}/versions/{version}.

Returns:

  • (::String)

    Optional. The name of the SecretManager secret version resource storing the passphrase to decrypt the private key. Should be left unset if the private key is not encrypted. Format: projects/{project}/secrets/{secret}/versions/{version}



649
650
651
652
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 649

class ClientCertificateSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#private_key::String

Returns Required. The name of the SecretManager secret version resource storing the private key encoded in PEM format. Format: projects/{project}/secrets/{secret}/versions/{version}.

Returns:

  • (::String)

    Required. The name of the SecretManager secret version resource storing the private key encoded in PEM format. Format: projects/{project}/secrets/{secret}/versions/{version}



649
650
651
652
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 649

class ClientCertificateSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tls_certificate::String

Returns Required. The TLS certificate encoded in PEM format. This string must include the begin header and end footer lines.

Returns:

  • (::String)

    Required. The TLS certificate encoded in PEM format. This string must include the begin header and end footer lines.



649
650
651
652
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 649

class ClientCertificateSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end