Class: Google::Cloud::Ces::V1beta::Conversation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/conversation.rb

Overview

A conversation represents an interaction between an end user and the CES app.

Defined Under Namespace

Modules: ChannelType, InputType, Source Classes: Turn

Instance Attribute Summary collapse

Instance Attribute Details

#app_version::String (readonly)

Returns Output only. The version of the app used for processing the conversation. Format: projects/{project}/locations/{location}/apps/{app}/versions/{version}.

Returns:

  • (::String)

    Output only. The version of the app used for processing the conversation. Format: projects/{project}/locations/{location}/apps/{app}/versions/{version}



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#channel_type::Google::Cloud::Ces::V1beta::Conversation::ChannelType

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns DEPRECATED. Please use input_types instead.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#deployment::String (readonly)

Returns Output only. The deployment of the app used for processing the conversation. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}.

Returns:

  • (::String)

    Output only. The deployment of the app used for processing the conversation. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the conversation was completed.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#entry_agent::String (readonly)

Returns Output only. The agent that initially handles the conversation. If not specified, the conversation is handled by the root agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.

Returns:

  • (::String)

    Output only. The agent that initially handles the conversation. If not specified, the conversation is handled by the root agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#input_types::Array<::Google::Cloud::Ces::V1beta::Conversation::InputType> (readonly)

Returns Output only. The input types of the conversation.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#language_code::String (readonly)

Returns Output only. The language code of the conversation.

Returns:

  • (::String)

    Output only. The language code of the conversation.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#messages::Array<::Google::Cloud::Ces::V1beta::Message>

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated. Use turns instead.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#name::String

Returns Identifier. The unique identifier of the conversation. Format: projects/{project}/locations/{location}/apps/{app}/conversations/{conversation}.

Returns:

  • (::String)

    Identifier. The unique identifier of the conversation. Format: projects/{project}/locations/{location}/apps/{app}/conversations/{conversation}



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#source::Google::Cloud::Ces::V1beta::Conversation::Source (readonly)

Returns Output only. Indicate the source of the conversation.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the conversation was created.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#turn_count::Integer (readonly)

Returns Output only. The number of turns in the conversation.

Returns:

  • (::Integer)

    Output only. The number of turns in the conversation.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end

#turns::Array<::Google::Cloud::Ces::V1beta::Conversation::Turn>

Returns Required. The turns in the conversation.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 75

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # All information about a single turn in the conversation.
  # @!attribute [rw] messages
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Message>]
  #     Optional. List of messages in the conversation turn, including user
  #     input, agent responses and intermediate events during the processing.
  # @!attribute [rw] root_span
  #   @return [::Google::Cloud::Ces::V1beta::Span]
  #     Optional. The root span of the action processing.
  class Turn
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The channel type of the conversation.
  module ChannelType
    # Unspecified channel type.
    CHANNEL_TYPE_UNSPECIFIED = 0

    # The conversation only contains text messages between the end user and the
    # agent.
    TEXT = 1

    # The conversation contains audio messages between the end user and the
    # agent.
    AUDIO = 2

    # The conversation multi-modal messages (e.g. image) between the end user
    # and the agent.
    MULTIMODAL = 3
  end

  # The source of the conversation.
  module Source
    # Unspecified source.
    SOURCE_UNSPECIFIED = 0

    # The conversation is from the live end user.
    LIVE = 1

    # The conversation is from the simulator.
    SIMULATOR = 2

    # The conversation is from the evaluation.
    EVAL = 3

    # The conversation is from an agent tool. Agent tool runs the agent in a
    # separate session, which is persisted for testing and debugging purposes.
    AGENT_TOOL = 4
  end

  # Type of the input message.
  module InputType
    # Unspecified input type.
    INPUT_TYPE_UNSPECIFIED = 0

    # The input message is text.
    INPUT_TYPE_TEXT = 1

    # The input message is audio.
    INPUT_TYPE_AUDIO = 2

    # The input message is image.
    INPUT_TYPE_IMAGE = 3

    # The input message is blob file.
    INPUT_TYPE_BLOB = 4

    # The input message is client function tool response.
    INPUT_TYPE_TOOL_RESPONSE = 5

    # The input message are variables.
    INPUT_TYPE_VARIABLES = 6
  end
end