Module: Google::Cloud::Ces::V1beta::Conversation::Source

Defined in:
proto_docs/google/cloud/ces/v1beta/conversation.rb

Overview

The source of the conversation.

Constant Summary collapse

SOURCE_UNSPECIFIED =

Unspecified source.

0
LIVE =

The conversation is from the live end user.

1
SIMULATOR =

The conversation is from the simulator.

2
EVAL =

The conversation is from the evaluation.

3
AGENT_TOOL =

The conversation is from an agent tool. Agent tool runs the agent in a separate session, which is persisted for testing and debugging purposes.

4