Class: Google::Cloud::Ces::V1beta::Conversation::Turn
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Conversation::Turn
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/conversation.rb
Overview
All information about a single turn in the conversation.
Instance Attribute Summary collapse
-
#messages ⇒ ::Array<::Google::Cloud::Ces::V1beta::Message>
Optional.
-
#root_span ⇒ ::Google::Cloud::Ces::V1beta::Span
Optional.
Instance Attribute Details
#messages ⇒ ::Array<::Google::Cloud::Ces::V1beta::Message>
Returns Optional. List of messages in the conversation turn, including user input, agent responses and intermediate events during the processing.
87 88 89 90 |
# File 'proto_docs/google/cloud/ces/v1beta/conversation.rb', line 87 class Turn include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |