Class: Google::Cloud::Ces::V1beta::ConversationLoggingSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings to describe the conversation logging behaviors for the app.

Instance Attribute Summary collapse

Instance Attribute Details

#disable_conversation_logging::Boolean

Returns Optional. Whether to disable conversation logging for the sessions.

Returns:

  • (::Boolean)

    Optional. Whether to disable conversation logging for the sessions.



662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 662

class ConversationLoggingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#retention_window::Google::Protobuf::Duration

Returns Optional. Controls the retention window for the conversation. If not set, the conversation will be retained for 365 days.

Returns:

  • (::Google::Protobuf::Duration)

    Optional. Controls the retention window for the conversation. If not set, the conversation will be retained for 365 days.



662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 662

class ConversationLoggingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end