Class: Google::Cloud::Ces::V1beta::CreateAgentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::CreateAgentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.CreateAgent.
Instance Attribute Summary collapse
-
#agent ⇒ ::Google::Cloud::Ces::V1beta::Agent
Required.
-
#agent_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#agent ⇒ ::Google::Cloud::Ces::V1beta::Agent
Returns Required. The agent to create.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 353 class CreateAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#agent_id ⇒ ::String
Returns Optional. The ID to use for the agent, which will become the final component of the agent's resource name. If not provided, a unique ID will be automatically assigned for the agent.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 353 class CreateAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the app to create an agent in.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 353 class CreateAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |