Class: Google::Cloud::Ces::V1beta::CreateAppVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::CreateAppVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.CreateAppVersion
Instance Attribute Summary collapse
-
#app_version ⇒ ::Google::Cloud::Ces::V1beta::AppVersion
Required.
-
#app_version_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#app_version ⇒ ::Google::Cloud::Ces::V1beta::AppVersion
Returns Required. The app version to create.
1159 1160 1161 1162 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1159 class CreateAppVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#app_version_id ⇒ ::String
Returns Optional. The ID to use for the app version, which will become the final component of the app version's resource name. If not provided, a unique ID will be automatically assigned for the app version.
1159 1160 1161 1162 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1159 class CreateAppVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the app to create an app version in.
1159 1160 1161 1162 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1159 class CreateAppVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |