Class: Google::Cloud::Ces::V1beta::CreateDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.CreateDeployment.

Instance Attribute Summary collapse

Instance Attribute Details

#deployment::Google::Cloud::Ces::V1beta::Deployment

Returns Required. The deployment to create.

Returns:



928
929
930
931
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 928

class CreateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deployment_id::String

Returns Optional. The ID to use for the deployment, which will become the final component of the deployment's resource name. If not provided, a unique ID will be automatically assigned for the deployment.

Returns:

  • (::String)

    Optional. The ID to use for the deployment, which will become the final component of the deployment's resource name. If not provided, a unique ID will be automatically assigned for the deployment.



928
929
930
931
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 928

class CreateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent app. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The parent app. Format: projects/{project}/locations/{location}/apps/{app}



928
929
930
931
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 928

class CreateDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end