Class: Google::Cloud::Ces::V1beta::CreateEvaluationExpectationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_expectation::Google::Cloud::Ces::V1beta::EvaluationExpectation

Returns Required. The evaluation expectation to create.

Returns:



789
790
791
792
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 789

class CreateEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#evaluation_expectation_id::String

Returns Optional. The ID to use for the evaluation expectation, which will become the final component of the evaluation expectation's resource name. If not provided, a unique ID will be automatically assigned for the evaluation expectation.

Returns:

  • (::String)

    Optional. The ID to use for the evaluation expectation, which will become the final component of the evaluation expectation's resource name. If not provided, a unique ID will be automatically assigned for the evaluation expectation.



789
790
791
792
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 789

class CreateEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The app to create the evaluation expectation for. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The app to create the evaluation expectation for. Format: projects/{project}/locations/{location}/apps/{app}



789
790
791
792
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 789

class CreateEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end