Class: Google::Cloud::Ces::V1beta::CreateEvaluationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Request message for EvaluationService.CreateEvaluation.

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation::Google::Cloud::Ces::V1beta::Evaluation

Returns Required. The evaluation to create.

Returns:



98
99
100
101
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 98

class CreateEvaluationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#evaluation_id::String

Returns Optional. The ID to use for the evaluation, which will become the final component of the evaluation's resource name. If not provided, a unique ID will be automatically assigned for the evaluation.

Returns:

  • (::String)

    Optional. The ID to use for the evaluation, which will become the final component of the evaluation's resource name. If not provided, a unique ID will be automatically assigned for the evaluation.



98
99
100
101
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 98

class CreateEvaluationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The app to create the evaluation for. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The app to create the evaluation for. Format: projects/{project}/locations/{location}/apps/{app}



98
99
100
101
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 98

class CreateEvaluationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end