Class: Google::Cloud::Ces::V1beta::CreateGuardrailRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.CreateGuardrail.

Instance Attribute Summary collapse

Instance Attribute Details

#guardrail::Google::Cloud::Ces::V1beta::Guardrail

Returns Required. The guardrail to create.

Returns:



814
815
816
817
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 814

class CreateGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#guardrail_id::String

Returns Optional. The ID to use for the guardrail, which will become the final component of the guardrail's resource name. If not provided, a unique ID will be automatically assigned for the guardrail.

Returns:

  • (::String)

    Optional. The ID to use for the guardrail, which will become the final component of the guardrail's resource name. If not provided, a unique ID will be automatically assigned for the guardrail.



814
815
816
817
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 814

class CreateGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to create a guardrail in.

Returns:

  • (::String)

    Required. The resource name of the app to create a guardrail in.



814
815
816
817
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 814

class CreateGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end