Class: Google::Cloud::Ces::V1beta::CreateScheduledEvaluationRunRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The app to create the scheduled evaluation run for. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The app to create the scheduled evaluation run for. Format: projects/{project}/locations/{location}/apps/{app}



611
612
613
614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 611

class CreateScheduledEvaluationRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scheduled_evaluation_run::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun

Returns Required. The scheduled evaluation run to create.

Returns:



611
612
613
614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 611

class CreateScheduledEvaluationRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scheduled_evaluation_run_id::String

Returns Optional. The ID to use for the scheduled evaluation run, which will become the final component of the scheduled evaluation run's resource name. If not provided, a unique ID will be automatically assigned.

Returns:

  • (::String)

    Optional. The ID to use for the scheduled evaluation run, which will become the final component of the scheduled evaluation run's resource name. If not provided, a unique ID will be automatically assigned.



611
612
613
614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 611

class CreateScheduledEvaluationRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end