Class: Google::Cloud::Ces::V1beta::CreateToolRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.CreateTool.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The resource name of the app to create a tool in.

Returns:

  • (::String)

    Required. The resource name of the app to create a tool in.



591
592
593
594
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 591

class CreateToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool::Google::Cloud::Ces::V1beta::Tool

Returns Required. The tool to create.

Returns:



591
592
593
594
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 591

class CreateToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool_id::String

Returns Optional. The ID to use for the tool, which will become the final component of the tool's resource name. If not provided, a unique ID will be automatically assigned for the tool.

Returns:

  • (::String)

    Optional. The ID to use for the tool, which will become the final component of the tool's resource name. If not provided, a unique ID will be automatically assigned for the tool.



591
592
593
594
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 591

class CreateToolRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end