Class: Google::Cloud::Ces::V1beta::CreateToolsetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::CreateToolsetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.CreateToolset.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#toolset ⇒ ::Google::Cloud::Ces::V1beta::Toolset
Required.
-
#toolset_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The resource name of the app to create a toolset in.
1031 1032 1033 1034 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1031 class CreateToolsetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset ⇒ ::Google::Cloud::Ces::V1beta::Toolset
Returns Required. The toolset to create.
1031 1032 1033 1034 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1031 class CreateToolsetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_id ⇒ ::String
Returns Optional. The ID to use for the toolset, which will become the final component of the toolset's resource name. If not provided, a unique ID will be automatically assigned for the toolset.
1031 1032 1033 1034 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1031 class CreateToolsetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |