Class: Google::Cloud::Ces::V1beta::DataStoreSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Data store related settings for the app.

Defined Under Namespace

Classes: Engine

Instance Attribute Summary collapse

Instance Attribute Details

#engines::Array<::Google::Cloud::Ces::V1beta::DataStoreSettings::Engine> (readonly)

Returns Output only. The engines for the app.

Returns:



808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 808

class DataStoreSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An engine to which the data stores are connected.
  # See Vertex AI Search:
  # https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search-introduction.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the engine.
  #     Format:
  #     `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}`
  # @!attribute [r] type
  #   @return [::Google::Cloud::Ces::V1beta::DataStoreSettings::Engine::Type]
  #     Output only. The type of the engine.
  class Engine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the engine.
    # See the documentation available at
    # https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1/SolutionType
    # and
    # https://cloud.google.com/generative-ai-app-builder/docs/create-datastore-ingest.
    module Type
      # Unspecified engine type.
      TYPE_UNSPECIFIED = 0

      # The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores
      # added to the app will be added to this engine.
      ENGINE_TYPE_SEARCH = 1

      # Chat engine type.
      # The SOLUTION_TYPE_CHAT engine for the app. All connector data stores
      # added to the app will be added to this engine.
      ENGINE_TYPE_CHAT = 2
    end
  end
end