Class: Google::Cloud::Ces::V1beta::DataStoreTool::BoostSpecs

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/data_store_tool.rb

Overview

Boost specifications to boost certain documents. For more information, please refer to https://cloud.google.com/generative-ai-app-builder/docs/boosting.

Instance Attribute Summary collapse

Instance Attribute Details

#data_stores::Array<::String>

Returns Required. The Data Store where the boosting configuration is applied. Full resource name of DataStore, such as projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}.

Returns:

  • (::Array<::String>)

    Required. The Data Store where the boosting configuration is applied. Full resource name of DataStore, such as projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}.



154
155
156
157
# File 'proto_docs/google/cloud/ces/v1beta/data_store_tool.rb', line 154

class BoostSpecs
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#spec::Array<::Google::Cloud::Ces::V1beta::DataStoreTool::BoostSpec>

Returns Required. A list of boosting specifications.

Returns:



154
155
156
157
# File 'proto_docs/google/cloud/ces/v1beta/data_store_tool.rb', line 154

class BoostSpecs
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end