Class: Google::Cloud::Ces::V1beta::DeleteAgentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.DeleteAgent.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the agent. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the agent, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the agent. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the agent, deletion will be blocked and an ABORTED error will be returned.



392
393
394
395
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 392

class DeleteAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#force::Boolean

Returns Optional. Indicates whether to forcefully delete the agent, even if it is still referenced by other app/agents/examples.

  • If force = false, the deletion fails if other agents/examples reference it.
  • If force = true, delete the agent and remove it from all referencing apps/agents/examples.

Returns:

  • (::Boolean)

    Optional. Indicates whether to forcefully delete the agent, even if it is still referenced by other app/agents/examples.

    • If force = false, the deletion fails if other agents/examples reference it.
    • If force = true, delete the agent and remove it from all referencing apps/agents/examples.


392
393
394
395
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 392

class DeleteAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the agent to delete.

Returns:

  • (::String)

    Required. The resource name of the agent to delete.



392
393
394
395
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 392

class DeleteAgentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end