Class: Google::Cloud::Ces::V1beta::DeleteEvaluationExpectationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the evaluation expectation. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the evaluation expectation, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the evaluation expectation. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the evaluation expectation, deletion will be blocked and an ABORTED error will be returned.



857
858
859
860
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 857

class DeleteEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the evaluation expectation to delete.

Returns:

  • (::String)

    Required. The resource name of the evaluation expectation to delete.



857
858
859
860
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 857

class DeleteEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end