Class: Google::Cloud::Ces::V1beta::DeleteEvaluationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Request message for EvaluationService.DeleteEvaluation.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the evaluation. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the evaluation, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the evaluation. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the evaluation, deletion will be blocked and an ABORTED error will be returned.



327
328
329
330
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 327

class DeleteEvaluationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#force::Boolean

Returns Optional. Indicates whether to forcefully delete the evaluation, even if it is still referenced by evaluation datasets.

  • If force = false, the deletion will fail if any datasets still reference the evaluation.
  • If force = true, all existing references from datasets will be removed and the evaluation will be deleted.

Returns:

  • (::Boolean)

    Optional. Indicates whether to forcefully delete the evaluation, even if it is still referenced by evaluation datasets.

    • If force = false, the deletion will fail if any datasets still reference the evaluation.
    • If force = true, all existing references from datasets will be removed and the evaluation will be deleted.


327
328
329
330
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 327

class DeleteEvaluationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the evaluation to delete.

Returns:

  • (::String)

    Required. The resource name of the evaluation to delete.



327
328
329
330
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 327

class DeleteEvaluationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end