Class: Google::Cloud::Ces::V1beta::DeleteGuardrailRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.DeleteGuardrail.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the guardrail. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the guardrail, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the guardrail. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the guardrail, deletion will be blocked and an ABORTED error will be returned.



853
854
855
856
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 853

class DeleteGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#force::Boolean

Returns Optional. Indicates whether to forcefully delete the guardrail, even if it is still referenced by app/agents.

  • If force = false, the deletion fails if any apps/agents still reference the guardrail.
  • If force = true, all existing references from apps/agents will be removed and the guardrail will be deleted.

Returns:

  • (::Boolean)

    Optional. Indicates whether to forcefully delete the guardrail, even if it is still referenced by app/agents.

    • If force = false, the deletion fails if any apps/agents still reference the guardrail.
    • If force = true, all existing references from apps/agents will be removed and the guardrail will be deleted.


853
854
855
856
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 853

class DeleteGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the guardrail to delete.

Returns:

  • (::String)

    Required. The resource name of the guardrail to delete.



853
854
855
856
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 853

class DeleteGuardrailRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end