Class: Google::Cloud::Ces::V1beta::DeleteToolRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DeleteToolRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.DeleteTool.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the tool. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the tool, deletion will be blocked and an ABORTED error will be returned.
630 631 632 633 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 630 class DeleteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#force ⇒ ::Boolean
Returns Optional. Indicates whether to forcefully delete the tool, even if it is still referenced by agents/examples.
- If
force = false, the deletion will fail if any agents still reference the tool. - If
force = true, all existing references from agents will be removed and the tool will be deleted.
630 631 632 633 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 630 class DeleteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the tool to delete.
630 631 632 633 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 630 class DeleteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |