Class: Google::Cloud::Ces::V1beta::DeleteToolsetRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.DeleteToolset.

Instance Attribute Summary collapse

Instance Attribute Details

#etag::String

Returns Optional. The current etag of the toolset. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the toolset, deletion will be blocked and an ABORTED error will be returned.

Returns:

  • (::String)

    Optional. The current etag of the toolset. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the toolset, deletion will be blocked and an ABORTED error will be returned.



1070
1071
1072
1073
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1070

class DeleteToolsetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#force::Boolean

Returns Optional. Indicates whether to forcefully delete the toolset, even if it is still referenced by app/agents.

  • If force = false, the deletion fails if any agents still reference the toolset.
  • If force = true, all existing references from agents will be removed and the toolset will be deleted.

Returns:

  • (::Boolean)

    Optional. Indicates whether to forcefully delete the toolset, even if it is still referenced by app/agents.

    • If force = false, the deletion fails if any agents still reference the toolset.
    • If force = true, all existing references from agents will be removed and the toolset will be deleted.


1070
1071
1072
1073
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1070

class DeleteToolsetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the toolset to delete.

Returns:

  • (::String)

    Required. The resource name of the toolset to delete.



1070
1071
1072
1073
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1070

class DeleteToolsetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end