Class: Google::Cloud::Ces::V1beta::Deployment
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Deployment
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/deployment.rb
Overview
A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.
Instance Attribute Summary collapse
-
#app_version ⇒ ::String
Optional.
-
#channel_profile ⇒ ::Google::Cloud::Ces::V1beta::ChannelProfile
Required.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#etag ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#app_version ⇒ ::String
Returns Optional. The resource name of the app version to deploy.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}
Use projects/{project}/locations/{location}/apps/{app}/versions/- to use
the draft app.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#channel_profile ⇒ ::Google::Cloud::Ces::V1beta::ChannelProfile
Returns Required. The channel profile used in the deployment.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when this deployment was created.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. Display name of the deployment.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String (readonly)
Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the deployment.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when this deployment was last updated.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 55 class Deployment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |