Class: Google::Cloud::Ces::V1beta::EndpointControlPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/security_settings.rb

Overview

Defines project/location level endpoint control policy.

Defined Under Namespace

Modules: EnforcementScope

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_origins::Array<::String>

Returns Optional. The allowed HTTP(s) origins that tools in the App are able to directly call. The enforcement depends on the value of enforcement_scope and the VPC-SC status of the project. If a port number is not provided, all ports will be allowed. Otherwise, the port number must match exactly. For example, "https://example.com" will match "https://example.com:443" and any other port. "https://example.com:443" will only match "https://example.com:443".

Returns:

  • (::Array<::String>)

    Optional. The allowed HTTP(s) origins that tools in the App are able to directly call. The enforcement depends on the value of enforcement_scope and the VPC-SC status of the project. If a port number is not provided, all ports will be allowed. Otherwise, the port number must match exactly. For example, "https://example.com" will match "https://example.com:443" and any other port. "https://example.com:443" will only match "https://example.com:443".



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/ces/v1beta/security_settings.rb', line 60

class EndpointControlPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the scope in which this policy's allowed_origins list is
  # enforced.
  module EnforcementScope
    # Unspecified. This policy will be treated as VPCSC_ONLY.
    ENFORCEMENT_SCOPE_UNSPECIFIED = 0

    # This policy applies only when VPC-SC is active.
    VPCSC_ONLY = 1

    # This policy ALWAYS applies, regardless of VPC-SC status.
    ALWAYS = 2
  end
end

#enforcement_scope::Google::Cloud::Ces::V1beta::EndpointControlPolicy::EnforcementScope

Returns Optional. The scope in which this policy's allowed_origins list is enforced.

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'proto_docs/google/cloud/ces/v1beta/security_settings.rb', line 60

class EndpointControlPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the scope in which this policy's allowed_origins list is
  # enforced.
  module EnforcementScope
    # Unspecified. This policy will be treated as VPCSC_ONLY.
    ENFORCEMENT_SCOPE_UNSPECIFIED = 0

    # This policy applies only when VPC-SC is active.
    VPCSC_ONLY = 1

    # This policy ALWAYS applies, regardless of VPC-SC status.
    ALWAYS = 2
  end
end