Class: Google::Cloud::Ces::V1beta::ErrorHandlingSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings to describe how errors should be handled in the app.

Defined Under Namespace

Modules: ErrorHandlingStrategy Classes: EndSessionConfig, FallbackResponseConfig

Instance Attribute Summary collapse

Instance Attribute Details

#end_session_config::Google::Cloud::Ces::V1beta::ErrorHandlingSettings::EndSessionConfig

Returns Optional. Configuration for ending the session in case of system errors (e.g. LLM errors).

Returns:



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 424

class ErrorHandlingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for handling fallback responses.
  # @!attribute [rw] custom_fallback_messages
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     Optional. The fallback messages in case of system errors (e.g. LLM
  #     errors), mapped by [supported language
  #     code](https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/reference/language).
  # @!attribute [rw] max_fallback_attempts
  #   @return [::Integer]
  #     Optional. The maximum number of fallback attempts to make before the
  #     agent emitting {::Google::Cloud::Ces::V1beta::EndSession EndSession} Signal.
  class FallbackResponseConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class CustomFallbackMessagesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Configuration for ending the session in case of system errors (e.g. LLM
  # errors).
  # @!attribute [rw] escalate_session
  #   @return [::Boolean]
  #     Optional. Whether to escalate the session in
  #     {::Google::Cloud::Ces::V1beta::EndSession EndSession}. If session is
  #     escalated, [metadata in
  #     EndSession][google.cloud.ces.v1beta.EndSession.metadata] will contain
  #     `session_escalated = true`. See
  #     https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/deploy/google-telephony-platform#transfer_a_call_to_a_human_agent
  #     for details.
  class EndSessionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines the strategy for handling errors.
  module ErrorHandlingStrategy
    # Unspecified error handling strategy.
    ERROR_HANDLING_STRATEGY_UNSPECIFIED = 0

    # No specific handling is enabled.
    NONE = 1

    # A fallback message will be returned to the user in case of
    # system errors (e.g. LLM errors).
    FALLBACK_RESPONSE = 2

    # An {::Google::Cloud::Ces::V1beta::EndSession EndSession} signal will be
    # emitted in case of system errors (e.g. LLM errors).
    END_SESSION = 3
  end
end

#error_handling_strategy::Google::Cloud::Ces::V1beta::ErrorHandlingSettings::ErrorHandlingStrategy

Returns Optional. The strategy to use for error handling.

Returns:



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 424

class ErrorHandlingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for handling fallback responses.
  # @!attribute [rw] custom_fallback_messages
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     Optional. The fallback messages in case of system errors (e.g. LLM
  #     errors), mapped by [supported language
  #     code](https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/reference/language).
  # @!attribute [rw] max_fallback_attempts
  #   @return [::Integer]
  #     Optional. The maximum number of fallback attempts to make before the
  #     agent emitting {::Google::Cloud::Ces::V1beta::EndSession EndSession} Signal.
  class FallbackResponseConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class CustomFallbackMessagesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Configuration for ending the session in case of system errors (e.g. LLM
  # errors).
  # @!attribute [rw] escalate_session
  #   @return [::Boolean]
  #     Optional. Whether to escalate the session in
  #     {::Google::Cloud::Ces::V1beta::EndSession EndSession}. If session is
  #     escalated, [metadata in
  #     EndSession][google.cloud.ces.v1beta.EndSession.metadata] will contain
  #     `session_escalated = true`. See
  #     https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/deploy/google-telephony-platform#transfer_a_call_to_a_human_agent
  #     for details.
  class EndSessionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines the strategy for handling errors.
  module ErrorHandlingStrategy
    # Unspecified error handling strategy.
    ERROR_HANDLING_STRATEGY_UNSPECIFIED = 0

    # No specific handling is enabled.
    NONE = 1

    # A fallback message will be returned to the user in case of
    # system errors (e.g. LLM errors).
    FALLBACK_RESPONSE = 2

    # An {::Google::Cloud::Ces::V1beta::EndSession EndSession} signal will be
    # emitted in case of system errors (e.g. LLM errors).
    END_SESSION = 3
  end
end

#fallback_response_config::Google::Cloud::Ces::V1beta::ErrorHandlingSettings::FallbackResponseConfig

Returns Optional. Configuration for handling fallback responses.

Returns:



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 424

class ErrorHandlingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for handling fallback responses.
  # @!attribute [rw] custom_fallback_messages
  #   @return [::Google::Protobuf::Map{::String => ::String}]
  #     Optional. The fallback messages in case of system errors (e.g. LLM
  #     errors), mapped by [supported language
  #     code](https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/reference/language).
  # @!attribute [rw] max_fallback_attempts
  #   @return [::Integer]
  #     Optional. The maximum number of fallback attempts to make before the
  #     agent emitting {::Google::Cloud::Ces::V1beta::EndSession EndSession} Signal.
  class FallbackResponseConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] key
    #   @return [::String]
    # @!attribute [rw] value
    #   @return [::String]
    class CustomFallbackMessagesEntry
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # Configuration for ending the session in case of system errors (e.g. LLM
  # errors).
  # @!attribute [rw] escalate_session
  #   @return [::Boolean]
  #     Optional. Whether to escalate the session in
  #     {::Google::Cloud::Ces::V1beta::EndSession EndSession}. If session is
  #     escalated, [metadata in
  #     EndSession][google.cloud.ces.v1beta.EndSession.metadata] will contain
  #     `session_escalated = true`. See
  #     https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/deploy/google-telephony-platform#transfer_a_call_to_a_human_agent
  #     for details.
  class EndSessionConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Defines the strategy for handling errors.
  module ErrorHandlingStrategy
    # Unspecified error handling strategy.
    ERROR_HANDLING_STRATEGY_UNSPECIFIED = 0

    # No specific handling is enabled.
    NONE = 1

    # A fallback message will be returned to the user in case of
    # system errors (e.g. LLM errors).
    FALLBACK_RESPONSE = 2

    # An {::Google::Cloud::Ces::V1beta::EndSession EndSession} signal will be
    # emitted in case of system errors (e.g. LLM errors).
    END_SESSION = 3
  end
end