Module: Google::Cloud::Ces::V1beta::ErrorHandlingSettings::ErrorHandlingStrategy

Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Defines the strategy for handling errors.

Constant Summary collapse

ERROR_HANDLING_STRATEGY_UNSPECIFIED =

Unspecified error handling strategy.

0
NONE =

No specific handling is enabled.

1
FALLBACK_RESPONSE =

A fallback message will be returned to the user in case of system errors (e.g. LLM errors).

2
END_SESSION =

An EndSession signal will be emitted in case of system errors (e.g. LLM errors).

3