Class: Google::Cloud::Ces::V1beta::Evaluation::Golden

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The steps required to replay a golden conversation.

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_expectations::Array<::String>

Returns Optional. The evaluation expectations to evaluate the replayed conversation against. Format: projects/{project}/locations/{location}/apps/{app}/evaluationExpectations/{evaluationExpectation}.

Returns:

  • (::Array<::String>)

    Optional. The evaluation expectations to evaluate the replayed conversation against. Format: projects/{project}/locations/{location}/apps/{app}/evaluationExpectations/{evaluationExpectation}



305
306
307
308
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 305

class Golden
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#turns::Array<::Google::Cloud::Ces::V1beta::Evaluation::GoldenTurn>

Returns Required. The golden turns required to replay a golden conversation.

Returns:



305
306
307
308
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 305

class Golden
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end