Class: Google::Cloud::Ces::V1beta::Evaluation::Step

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

A step defines a singular action to happen during the evaluation.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_transfer::Google::Cloud::Ces::V1beta::AgentTransfer

Returns Optional. Transfer the conversation to a different agent.

Note: The following fields are mutually exclusive: agent_transfer, user_input, expectation. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::AgentTransfer)

    Optional. Transfer the conversation to a different agent.

    Note: The following fields are mutually exclusive: agent_transfer, user_input, expectation. If a field in that set is populated, all other fields in the set will automatically be cleared.



278
279
280
281
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 278

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expectation::Google::Cloud::Ces::V1beta::Evaluation::GoldenExpectation

Returns Optional. Executes an expectation on the current turn.

Note: The following fields are mutually exclusive: expectation, user_input, agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::Evaluation::GoldenExpectation)

    Optional. Executes an expectation on the current turn.

    Note: The following fields are mutually exclusive: expectation, user_input, agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.



278
279
280
281
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 278

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_input::Google::Cloud::Ces::V1beta::SessionInput

Returns Optional. User input for the conversation.

Note: The following fields are mutually exclusive: user_input, agent_transfer, expectation. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::SessionInput)

    Optional. User input for the conversation.

    Note: The following fields are mutually exclusive: user_input, agent_transfer, expectation. If a field in that set is populated, all other fields in the set will automatically be cleared.



278
279
280
281
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 278

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end