Class: Google::Cloud::Ces::V1beta::EvaluationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
EvaluationConfig configures settings for running the evaluation.
Defined Under Namespace
Modules: EvaluationChannel
Instance Attribute Summary collapse
-
#evaluation_channel ⇒ ::Google::Cloud::Ces::V1beta::EvaluationConfig::EvaluationChannel
Optional.
-
#input_audio_config ⇒ ::Google::Cloud::Ces::V1beta::InputAudioConfig
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#output_audio_config ⇒ ::Google::Cloud::Ces::V1beta::OutputAudioConfig
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#tool_call_behaviour ⇒ ::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour
Optional.
Instance Attribute Details
#evaluation_channel ⇒ ::Google::Cloud::Ces::V1beta::EvaluationConfig::EvaluationChannel
Returns Optional. The channel to evaluate.
1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1418 class EvaluationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The channel to evaluate. module EvaluationChannel # Unspecified evaluation channel. EVALUATION_CHANNEL_UNSPECIFIED = 0 # Text-only evaluation channel. TEXT = 1 # Audio evaluation channel. AUDIO = 2 end end |
#input_audio_config ⇒ ::Google::Cloud::Ces::V1beta::InputAudioConfig
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Configuration for processing the input audio.
1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1418 class EvaluationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The channel to evaluate. module EvaluationChannel # Unspecified evaluation channel. EVALUATION_CHANNEL_UNSPECIFIED = 0 # Text-only evaluation channel. TEXT = 1 # Audio evaluation channel. AUDIO = 2 end end |
#output_audio_config ⇒ ::Google::Cloud::Ces::V1beta::OutputAudioConfig
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Configuration for generating the output audio.
1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1418 class EvaluationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The channel to evaluate. module EvaluationChannel # Unspecified evaluation channel. EVALUATION_CHANNEL_UNSPECIFIED = 0 # Text-only evaluation channel. TEXT = 1 # Audio evaluation channel. AUDIO = 2 end end |
#tool_call_behaviour ⇒ ::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour
Returns Optional. Specifies whether the evaluation should use real tool calls or fake tools.
1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1418 class EvaluationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The channel to evaluate. module EvaluationChannel # Unspecified evaluation channel. EVALUATION_CHANNEL_UNSPECIFIED = 0 # Text-only evaluation channel. TEXT = 1 # Audio evaluation channel. AUDIO = 2 end end |