Class: Google::Cloud::Ces::V1beta::EvaluationDataset

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

An evaluation dataset represents a set of evaluations that are grouped together basaed on shared tags.

Instance Attribute Summary collapse

Instance Attribute Details

#aggregated_metrics::Google::Cloud::Ces::V1beta::AggregatedMetrics (readonly)

Returns Output only. The aggregated metrics for this evaluation dataset across all runs.

Returns:



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the evaluation dataset was created.

Returns:



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#created_by::String (readonly)

Returns Output only. The user who created the evaluation dataset.

Returns:

  • (::String)

    Output only. The user who created the evaluation dataset.



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. User-defined display name of the evaluation dataset. Unique within an App.

Returns:

  • (::String)

    Required. User-defined display name of the evaluation dataset. Unique within an App.



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#etag::String (readonly)

Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.

Returns:

  • (::String)

    Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#evaluations::Array<::String>

Returns Optional. Evaluations that are included in this dataset.

Returns:

  • (::Array<::String>)

    Optional. Evaluations that are included in this dataset.



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#last_updated_by::String (readonly)

Returns Output only. The user who last updated the evaluation dataset.

Returns:

  • (::String)

    Output only. The user who last updated the evaluation dataset.



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The unique identifier of this evaluation dataset. Format: projects/{project}/locations/{location}/apps/{app}/evaluationDatasets/{evaluationDataset}.

Returns:

  • (::String)

    Identifier. The unique identifier of this evaluation dataset. Format: projects/{project}/locations/{location}/apps/{app}/evaluationDatasets/{evaluationDataset}



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the evaluation dataset was last updated.

Returns:



463
464
465
466
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 463

class EvaluationDataset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end