Class: Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings for matching tool calls.

Defined Under Namespace

Modules: ExtraToolCallBehavior

Instance Attribute Summary collapse

Instance Attribute Details

#extra_tool_call_behavior::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior

Returns Optional. Behavior for extra tool calls. Defaults to FAIL.

Returns:



566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 566

class ToolMatchingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the behavior when an extra tool call is encountered. An extra
  # tool call is a tool call that is present in the execution but does not
  # match any tool call in the golden expectation.
  module ExtraToolCallBehavior
    # Unspecified behavior. Defaults to FAIL.
    EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0

    # Fail the evaluation if an extra tool call is encountered.
    FAIL = 1

    # Allow the extra tool call.
    ALLOW = 2
  end
end