Module: Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Defines the behavior when an extra tool call is encountered. An extra tool call is a tool call that is present in the execution but does not match any tool call in the golden expectation.
Constant Summary collapse
- EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED =
Unspecified behavior. Defaults to FAIL.
0- FAIL =
Fail the evaluation if an extra tool call is encountered.
1- ALLOW =
Allow the extra tool call.
2