Class: Google::Cloud::Ces::V1beta::EvaluationResult::OverallToolInvocationResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The result of the overall tool invocation check.

Instance Attribute Summary collapse

Instance Attribute Details

#outcome::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome (readonly)

Returns Output only. The outcome of the tool invocation check. This is determined by comparing the tool_invocation_score to the overall_tool_invocation_correctness_threshold. If the score is equal to or above the threshold, the outcome will be PASS. Otherwise, the outcome will be FAIL.

Returns:

  • (::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome)

    Output only. The outcome of the tool invocation check. This is determined by comparing the tool_invocation_score to the overall_tool_invocation_correctness_threshold. If the score is equal to or above the threshold, the outcome will be PASS. Otherwise, the outcome will be FAIL.



947
948
949
950
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 947

class OverallToolInvocationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool_invocation_score::Float

Returns The overall tool invocation score for this turn. This indicates the overall percent of tools from the expected turn that were actually invoked.

Returns:

  • (::Float)

    The overall tool invocation score for this turn. This indicates the overall percent of tools from the expected turn that were actually invoked.



947
948
949
950
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 947

class OverallToolInvocationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end