Class: Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioRubricOutcome

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The outcome of the evaluation against the rubric.

Instance Attribute Summary collapse

Instance Attribute Details

#rubric::String (readonly)

Returns Output only. The rubric that was used to evaluate the conversation.

Returns:

  • (::String)

    Output only. The rubric that was used to evaluate the conversation.



697
698
699
700
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 697

class ScenarioRubricOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#score::Float (readonly)

Returns Output only. The score of the conversation against the rubric.

Returns:

  • (::Float)

    Output only. The score of the conversation against the rubric.



697
698
699
700
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 697

class ScenarioRubricOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#score_explanation::String (readonly)

Returns Output only. The rater's response to the rubric.

Returns:

  • (::String)

    Output only. The rater's response to the rubric.



697
698
699
700
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 697

class ScenarioRubricOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end