Class: Google::Cloud::Ces::V1beta::EvaluationResult::SemanticSimilarityResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The result of the semantic similarity check.

Instance Attribute Summary collapse

Instance Attribute Details

#explanation::String (readonly)

Returns Output only. The explanation for the semantic similarity score.

Returns:

  • (::String)

    Output only. The explanation for the semantic similarity score.



929
930
931
932
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 929

class SemanticSimilarityResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label::String (readonly)

Returns Output only. The label associated with each score. Score 4: Fully Consistent Score 3: Mostly Consistent Score 2: Partially Consistent (Minor Omissions) Score 1: Largely Inconsistent (Major Omissions) Score 0: Completely Inconsistent / Contradictory.

Returns:

  • (::String)

    Output only. The label associated with each score. Score 4: Fully Consistent Score 3: Mostly Consistent Score 2: Partially Consistent (Minor Omissions) Score 1: Largely Inconsistent (Major Omissions) Score 0: Completely Inconsistent / Contradictory



929
930
931
932
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 929

class SemanticSimilarityResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#outcome::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome (readonly)

Returns Output only. The outcome of the semantic similarity check. This is determined by comparing the score to the semantic_similarity_success_threshold. If the score is equal to or above the threshold, the outcome will be PASS. Otherwise, the outcome will be FAIL.

Returns:

  • (::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome)

    Output only. The outcome of the semantic similarity check. This is determined by comparing the score to the semantic_similarity_success_threshold. If the score is equal to or above the threshold, the outcome will be PASS. Otherwise, the outcome will be FAIL.



929
930
931
932
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 929

class SemanticSimilarityResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#score::Integer (readonly)

Returns Output only. The semantic similarity score. Can be 0, 1, 2, 3, or 4.

Returns:

  • (::Integer)

    Output only. The semantic similarity score. Can be 0, 1, 2, 3, or 4.



929
930
931
932
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 929

class SemanticSimilarityResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end