Class: Google::Cloud::Ces::V1beta::EvaluationRun::EvaluationRunSummary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

Contains the summary of passed and failed result counts for a specific evaluation in an evaluation run.

Instance Attribute Summary collapse

Instance Attribute Details

#error_count::Integer (readonly)

Returns Output only. Number of error results for the associated Evaluation in this run.

Returns:

  • (::Integer)

    Output only. Number of error results for the associated Evaluation in this run.



1146
1147
1148
1149
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1146

class EvaluationRunSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#failed_count::Integer (readonly)

Returns Output only. Number of failed results for the associated Evaluation in this run.

Returns:

  • (::Integer)

    Output only. Number of failed results for the associated Evaluation in this run.



1146
1147
1148
1149
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1146

class EvaluationRunSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#passed_count::Integer (readonly)

Returns Output only. Number of passed results for the associated Evaluation in this run.

Returns:

  • (::Integer)

    Output only. Number of passed results for the associated Evaluation in this run.



1146
1147
1148
1149
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1146

class EvaluationRunSummary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end