Class: Google::Cloud::Ces::V1beta::EvaluationRun::Progress

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The progress of the evaluation run.

Instance Attribute Summary collapse

Instance Attribute Details

#completed_count::Integer (readonly)

Returns Output only. Number of evaluation results that finished successfully. (EvaluationResult.execution_state is COMPLETED).

Returns:

  • (::Integer)

    Output only. Number of evaluation results that finished successfully. (EvaluationResult.execution_state is COMPLETED).



1127
1128
1129
1130
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1127

class Progress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#error_count::Integer (readonly)

Returns Output only. Number of evaluation results that failed to execute. (EvaluationResult.execution_state is ERROR).

Returns:

  • (::Integer)

    Output only. Number of evaluation results that failed to execute. (EvaluationResult.execution_state is ERROR).



1127
1128
1129
1130
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1127

class Progress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#failed_count::Integer (readonly)

Returns Output only. Number of completed evaluation results with an outcome of FAIL. (EvaluationResult.execution_state is COMPLETED and EvaluationResult.evaluation_status is FAIL).

Returns:

  • (::Integer)

    Output only. Number of completed evaluation results with an outcome of FAIL. (EvaluationResult.execution_state is COMPLETED and EvaluationResult.evaluation_status is FAIL).



1127
1128
1129
1130
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1127

class Progress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#passed_count::Integer (readonly)

Returns Output only. Number of completed evaluation results with an outcome of PASS. (EvaluationResult.execution_state is COMPLETED and EvaluationResult.evaluation_status is PASS).

Returns:

  • (::Integer)

    Output only. Number of completed evaluation results with an outcome of PASS. (EvaluationResult.execution_state is COMPLETED and EvaluationResult.evaluation_status is PASS).



1127
1128
1129
1130
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1127

class Progress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_count::Integer (readonly)

Returns Output only. Total number of evaluation results in this run.

Returns:

  • (::Integer)

    Output only. Total number of evaluation results in this run.



1127
1128
1129
1130
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1127

class Progress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end