Class: Google::Cloud::Ces::V1beta::EvaluationRunCachingSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/common.rb

Overview

Settings for evaluation run caching.

Defined Under Namespace

Modules: EvaluationRunCachingMode

Instance Attribute Summary collapse

Instance Attribute Details

#run_caching_mode::Google::Cloud::Ces::V1beta::EvaluationRunCachingSettings::EvaluationRunCachingMode

Returns Optional. The caching mode to use for the evaluation run. If not set, default to FORCE_RUN.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 420

class EvaluationRunCachingSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The evaluation result caching behavior. Controls whether to return the last
  # completed evaluation result (if existing) or to execute a new evaluation.
  module EvaluationRunCachingMode
    # The run caching mode is unspecified.
    EVALUATION_RUN_CACHING_MODE_UNSPECIFIED = 0

    # Always execute a full live simulation regardless of whether changelogs
    # exist.
    FORCE_RUN = 1

    # Skip execution and copy previous verified results if no dependencies have
    # mutated, the evaluation channel/run method are the same.
    SKIP_IF_UNCHANGED = 2
  end
end