Module: Google::Cloud::Ces::V1beta::EvaluationRunCachingSettings::EvaluationRunCachingMode

Defined in:
proto_docs/google/cloud/ces/v1beta/common.rb

Overview

The evaluation result caching behavior. Controls whether to return the last completed evaluation result (if existing) or to execute a new evaluation.

Constant Summary collapse

EVALUATION_RUN_CACHING_MODE_UNSPECIFIED =

The run caching mode is unspecified.

0
FORCE_RUN =

Always execute a full live simulation regardless of whether changelogs exist.

1
SKIP_IF_UNCHANGED =

Skip execution and copy previous verified results if no dependencies have mutated, the evaluation channel/run method are the same.

2