Class: Google::Cloud::Ces::V1beta::Example

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/example.rb

Overview

An example represents a sample conversation between the user and the agent(s).

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the example was created.

Returns:



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Optional. Human-readable description of the example.

Returns:

  • (::String)

    Optional. Human-readable description of the example.



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Required. Display name of the example.

Returns:

  • (::String)

    Required. Display name of the example.



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#entry_agent::String

Returns Optional. The agent that initially handles the conversation. If not specified, the example represents a conversation that is handled by the root agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.

Returns:

  • (::String)

    Optional. The agent that initially handles the conversation. If not specified, the example represents a conversation that is handled by the root agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#etag::String

Returns Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.

Returns:

  • (::String)

    Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#invalid::Boolean (readonly)

Returns Output only. The example may become invalid if referencing resources are deleted. Invalid examples will not be used as few-shot examples.

Returns:

  • (::Boolean)

    Output only. The example may become invalid if referencing resources are deleted. Invalid examples will not be used as few-shot examples.



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#messages::Array<::Google::Cloud::Ces::V1beta::Message>

Returns Optional. The collection of messages that make up the conversation.

Returns:



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The unique identifier of the example. Format: projects/{project}/locations/{location}/apps/{app}/examples/{example}.

Returns:

  • (::String)

    Identifier. The unique identifier of the example. Format: projects/{project}/locations/{location}/apps/{app}/examples/{example}



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the example was last updated.

Returns:



61
62
63
64
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 61

class Example
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end