Class: Google::Cloud::Ces::V1beta::ExecuteToolRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ExecuteToolRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/tool_service.rb
Overview
Request message for ToolService.ExecuteTool.
Instance Attribute Summary collapse
-
#args ⇒ ::Google::Protobuf::Struct
Optional.
-
#context ⇒ ::Google::Protobuf::Struct
Optional.
-
#mock_config ⇒ ::Google::Cloud::Ces::V1beta::MockConfig
Optional.
-
#parent ⇒ ::String
Required.
-
#tool ⇒ ::String
Optional.
-
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Optional.
-
#variables ⇒ ::Google::Protobuf::Struct
Optional.
Instance Attribute Details
#args ⇒ ::Google::Protobuf::Struct
Returns Optional. The input parameters and values for the tool in JSON object format.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#context ⇒ ::Google::Protobuf::Struct
Returns Optional. The ToolCallContext to be passed to the Python tool.
Note: The following fields are mutually exclusive: context, variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mock_config ⇒ ::Google::Cloud::Ces::V1beta::MockConfig
Returns Optional. Mock configuration for the tool execution. If this field is set, tools that call other tools will be mocked based on the provided patterns and responses.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the app which the tool/toolset belongs to.
Format: projects/{project}/locations/{location}/apps/{app}.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String
Returns Optional. The name of the tool to execute. Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Returns Optional. The toolset tool to execute. Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.
Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variables ⇒ ::Google::Protobuf::Struct
Returns Optional. The variables that are available for the tool execution.
Note: The following fields are mutually exclusive: variables, context. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 64 class ExecuteToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |