Class: Google::Cloud::Ces::V1beta::ExportAppRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.ExportApp.

Defined Under Namespace

Modules: ExportFormat

Instance Attribute Summary collapse

Instance Attribute Details

#app_version::String

Returns Optional. The resource name of the app version to export. Format: projects/{project}/locations/{location}/apps/{app}/versions/{version}.

Returns:

  • (::String)

    Optional. The resource name of the app version to export. Format: projects/{project}/locations/{location}/apps/{app}/versions/{version}.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 149

class ExportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Export format for the app.
  module ExportFormat
    # The export format is unspecified.
    EXPORT_FORMAT_UNSPECIFIED = 0

    # The export format is JSON.
    JSON = 1

    # The export format is YAML.
    YAML = 2
  end
end

#export_format::Google::Cloud::Ces::V1beta::ExportAppRequest::ExportFormat

Returns Required. The format to export the app in.

Returns:



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 149

class ExportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Export format for the app.
  module ExportFormat
    # The export format is unspecified.
    EXPORT_FORMAT_UNSPECIFIED = 0

    # The export format is JSON.
    JSON = 1

    # The export format is YAML.
    YAML = 2
  end
end

#gcs_uri::String

Returns Optional. The Google Cloud Storage URI to which to export the app. The format of this URI must be gs://<bucket-name>/<object-name>. The exported app archive will be written directly to the specified GCS object.

Returns:

  • (::String)

    Optional. The Google Cloud Storage URI to which to export the app. The format of this URI must be gs://<bucket-name>/<object-name>. The exported app archive will be written directly to the specified GCS object.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 149

class ExportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Export format for the app.
  module ExportFormat
    # The export format is unspecified.
    EXPORT_FORMAT_UNSPECIFIED = 0

    # The export format is JSON.
    JSON = 1

    # The export format is YAML.
    YAML = 2
  end
end

#name::String

Returns Required. The resource name of the app to export.

Returns:

  • (::String)

    Required. The resource name of the app to export.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 149

class ExportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Export format for the app.
  module ExportFormat
    # The export format is unspecified.
    EXPORT_FORMAT_UNSPECIFIED = 0

    # The export format is JSON.
    JSON = 1

    # The export format is YAML.
    YAML = 2
  end
end