Class: Google::Cloud::Ces::V1beta::ExportAppResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Response message for AgentService.ExportApp.

Instance Attribute Summary collapse

Instance Attribute Details

#app_content::String

Returns App folder compressed as a zip file.

Note: The following fields are mutually exclusive: app_content, app_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    App folder compressed as a zip file.

    Note: The following fields are mutually exclusive: app_content, app_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



179
180
181
182
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 179

class ExportAppResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#app_uri::String

Returns The Google Cloud Storage URI to which the app was exported.

Note: The following fields are mutually exclusive: app_uri, app_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The Google Cloud Storage URI to which the app was exported.

    Note: The following fields are mutually exclusive: app_uri, app_content. If a field in that set is populated, all other fields in the set will automatically be cleared.



179
180
181
182
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 179

class ExportAppResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end