Class: Google::Cloud::Ces::V1beta::ExportEvaluationRunsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Response message for [EvaluationService.ExportEvaluationRuns][google.cloud.ces.v1beta.EvaluationService.ExportEvaluationRuns].

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_runs_content::String

Returns The content of the exported Evaluation Runs. This will be populated if gcs_uri was not specified in the request.

Note: The following fields are mutually exclusive: evaluation_runs_content, evaluation_runs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The content of the exported Evaluation Runs. This will be populated if gcs_uri was not specified in the request.

    Note: The following fields are mutually exclusive: evaluation_runs_content, evaluation_runs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



1002
1003
1004
1005
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 1002

class ExportEvaluationRunsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#evaluation_runs_uri::String

Returns The Google Cloud Storage URI folder where the exported Evaluation Runs were written. This will be populated if gcs_uri was specified in the request.

Note: The following fields are mutually exclusive: evaluation_runs_uri, evaluation_runs_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The Google Cloud Storage URI folder where the exported Evaluation Runs were written. This will be populated if gcs_uri was specified in the request.

    Note: The following fields are mutually exclusive: evaluation_runs_uri, evaluation_runs_content. If a field in that set is populated, all other fields in the set will automatically be cleared.



1002
1003
1004
1005
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 1002

class ExportEvaluationRunsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end