Class: Google::Cloud::Ces::V1beta::FileSearchTool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/file_search_tool.rb

Overview

The file search tool allows the agent to search across the files uploaded by the app/agent developer. It has presets to give relatively good quality search over the uploaded files and summarization of the retrieved results.

Defined Under Namespace

Modules: CorpusType

Instance Attribute Summary collapse

Instance Attribute Details

#corpus_type::Google::Cloud::Ces::V1beta::FileSearchTool::CorpusType

Returns Optional. The type of the corpus. Default is FULLY_MANAGED.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/file_search_tool.rb', line 41

class FileSearchTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the Vertex RAG corpus.
  module CorpusType
    # Unspecified corpus type.
    CORPUS_TYPE_UNSPECIFIED = 0

    # The corpus is created and owned by the user.
    USER_OWNED = 1

    # The corpus is created by the agent.
    FULLY_MANAGED = 2
  end
end

#description::String

Returns Optional. The tool description.

Returns:

  • (::String)

    Optional. The tool description.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/file_search_tool.rb', line 41

class FileSearchTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the Vertex RAG corpus.
  module CorpusType
    # Unspecified corpus type.
    CORPUS_TYPE_UNSPECIFIED = 0

    # The corpus is created and owned by the user.
    USER_OWNED = 1

    # The corpus is created by the agent.
    FULLY_MANAGED = 2
  end
end

#file_corpus::String

Returns Optional. The corpus where files are stored. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}.

Returns:

  • (::String)

    Optional. The corpus where files are stored. Format: projects/{project}/locations/{location}/ragCorpora/{rag_corpus}



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/file_search_tool.rb', line 41

class FileSearchTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the Vertex RAG corpus.
  module CorpusType
    # Unspecified corpus type.
    CORPUS_TYPE_UNSPECIFIED = 0

    # The corpus is created and owned by the user.
    USER_OWNED = 1

    # The corpus is created by the agent.
    FULLY_MANAGED = 2
  end
end

#name::String

Returns Required. The tool name.

Returns:

  • (::String)

    Required. The tool name.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'proto_docs/google/cloud/ces/v1beta/file_search_tool.rb', line 41

class FileSearchTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the Vertex RAG corpus.
  module CorpusType
    # Unspecified corpus type.
    CORPUS_TYPE_UNSPECIFIED = 0

    # The corpus is created and owned by the user.
    USER_OWNED = 1

    # The corpus is created by the agent.
    FULLY_MANAGED = 2
  end
end