Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::AppVersionContext

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The app version context specifying the base snapshot and target agent.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_resource_name::String

Returns The resource name of the target agent to be used by the LLM assistant. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.

Returns:

  • (::String)

    The resource name of the target agent to be used by the LLM assistant. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}



1245
1246
1247
1248
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1245

class AppVersionContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#app_version::String

Returns The resource name of the app version to be used by the LLM assistant. Format: projects/{project}/locations/{location}/apps/{app}/versions/{version}.

Returns:

  • (::String)

    The resource name of the app version to be used by the LLM assistant. Format: projects/{project}/locations/{location}/apps/{app}/versions/{version}



1245
1246
1247
1248
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1245

class AppVersionContext
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end