Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::EvaluationGenerationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The configuration to be used to generate the evaluations.

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_id::String

Returns Optional. The insights dataset to be used to fetch conversation data for generating the evaluations. Format: projects/{project}/locations/{location}/datasets/{dataset}.

Returns:

  • (::String)

    Optional. The insights dataset to be used to fetch conversation data for generating the evaluations. Format: projects/{project}/locations/{location}/datasets/{dataset}.



1341
1342
1343
1344
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1341

class EvaluationGenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end