Class: Google::Cloud::Ces::V1beta::GenerateChatTokenRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/widget_service.rb

Overview

Request message for WidgetService.GenerateChatToken.

Instance Attribute Summary collapse

Instance Attribute Details

#deployment::String

Returns Required. The deployment of the app to use for the session. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}.

Returns:

  • (::String)

    Required. The deployment of the app to use for the session. Format: projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}



42
43
44
45
# File 'proto_docs/google/cloud/ces/v1beta/widget_service.rb', line 42

class GenerateChatTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#live_handoff_enabled::Boolean

Returns Optional. Indicates if live handoff is enabled for the session.

Returns:

  • (::Boolean)

    Optional. Indicates if live handoff is enabled for the session.



42
43
44
45
# File 'proto_docs/google/cloud/ces/v1beta/widget_service.rb', line 42

class GenerateChatTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The session name to generate the chat token for. Format: projects/{project}/locations/{location}/apps/{app}/sessions/{session}.

Returns:

  • (::String)

    Required. The session name to generate the chat token for. Format: projects/{project}/locations/{location}/apps/{app}/sessions/{session}



42
43
44
45
# File 'proto_docs/google/cloud/ces/v1beta/widget_service.rb', line 42

class GenerateChatTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#recaptcha_token::String

Returns Optional. The reCAPTCHA token generated by the client-side chat widget.

Returns:

  • (::String)

    Optional. The reCAPTCHA token generated by the client-side chat widget.



42
43
44
45
# File 'proto_docs/google/cloud/ces/v1beta/widget_service.rb', line 42

class GenerateChatTokenRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end