Class: Google::Cloud::Ces::V1beta::GenerateEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateEvaluationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Request message for EvaluationService.GenerateEvaluation.
Defined Under Namespace
Modules: EvaluationType
Instance Attribute Summary collapse
-
#conversation ⇒ ::String
Required.
-
#evaluation_type ⇒ ::Google::Cloud::Ces::V1beta::GenerateEvaluationRequest::EvaluationType
Optional.
-
#source ⇒ ::Google::Cloud::Ces::V1beta::Conversation::Source
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#conversation ⇒ ::String
Returns Required. The conversation to create the golden evaluation for.
Format:
projects/{project}/locations/{location}/apps/{app}/conversations/{conversation}.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 141 class GenerateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of evaluation to generate. module EvaluationType # Unspecified type. Defaults to GOLDEN. EVALUATION_TYPE_UNSPECIFIED = 0 # Golden evaluation. GOLDEN = 1 # Scenario evaluation. SCENARIO = 2 end end |
#evaluation_type ⇒ ::Google::Cloud::Ces::V1beta::GenerateEvaluationRequest::EvaluationType
Returns Optional. The type of evaluation to generate. Defaults to GOLDEN if unspecified.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 141 class GenerateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of evaluation to generate. module EvaluationType # Unspecified type. Defaults to GOLDEN. EVALUATION_TYPE_UNSPECIFIED = 0 # Golden evaluation. GOLDEN = 1 # Scenario evaluation. SCENARIO = 2 end end |
#source ⇒ ::Google::Cloud::Ces::V1beta::Conversation::Source
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Indicate the source of the conversation. If not set, all sources will be searched.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 141 class GenerateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of evaluation to generate. module EvaluationType # Unspecified type. Defaults to GOLDEN. EVALUATION_TYPE_UNSPECIFIED = 0 # Golden evaluation. GOLDEN = 1 # Scenario evaluation. SCENARIO = 2 end end |