Class: Google::Cloud::Ces::V1beta::GetConversationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GetConversationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.GetConversation.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#source ⇒ ::Google::Cloud::Ces::V1beta::Conversation::Source
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The resource name of the conversation to retrieve.
694 695 696 697 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 694 class GetConversationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::Google::Cloud::Ces::V1beta::Conversation::Source
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Indicate the source of the conversation. If not set, all source will be searched.
694 695 696 697 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 694 class GetConversationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |