Class: Google::Cloud::Ces::V1beta::GoogleSearchSuggestions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/search_suggestions.rb

Overview

Search suggestions from [Google Search Tool][google.cloud.ces.v1beta.GoogleSearchTool].

Instance Attribute Summary collapse

Instance Attribute Details

#htmls::Array<::String>

Returns Compliant HTML and CSS styling for search suggestions. The provided HTML and CSS automatically adapts to your device settings, displaying in either light or dark mode indicated by @media(prefers-color-scheme).

Returns:

  • (::Array<::String>)

    Compliant HTML and CSS styling for search suggestions. The provided HTML and CSS automatically adapts to your device settings, displaying in either light or dark mode indicated by @media(prefers-color-scheme).



36
37
38
39
# File 'proto_docs/google/cloud/ces/v1beta/search_suggestions.rb', line 36

class GoogleSearchSuggestions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#web_search_queries::Array<::Google::Cloud::Ces::V1beta::WebSearchQuery>

Returns List of queries used to perform the google search along with the search result URIs forming the search suggestions.

Returns:



36
37
38
39
# File 'proto_docs/google/cloud/ces/v1beta/search_suggestions.rb', line 36

class GoogleSearchSuggestions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end