Class: Google::Cloud::Ces::V1beta::GoogleSearchTool::PromptConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GoogleSearchTool::PromptConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/google_search_tool.rb
Overview
Prompt settings used by the model when processing or summarizing the google search results.
Instance Attribute Summary collapse
-
#text_prompt ⇒ ::String
Optional.
-
#voice_prompt ⇒ ::String
Optional.
Instance Attribute Details
#text_prompt ⇒ ::String
Returns Optional. Defines the prompt used for the system instructions when interacting with the agent in chat conversations. If not set, default prompt will be used.
68 69 70 71 |
# File 'proto_docs/google/cloud/ces/v1beta/google_search_tool.rb', line 68 class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#voice_prompt ⇒ ::String
Returns Optional. Defines the prompt used for the system instructions when interacting with the agent in voice conversations. If not set, default prompt will be used.
68 69 70 71 |
# File 'proto_docs/google/cloud/ces/v1beta/google_search_tool.rb', line 68 class PromptConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |