Module: Google::Cloud::Ces::V1beta::Guardrail::LlmPolicy::PolicyScope

Defined in:
proto_docs/google/cloud/ces/v1beta/guardrail.rb

Overview

Defines when to apply the policy check during the conversation.

Constant Summary collapse

POLICY_SCOPE_UNSPECIFIED =

Policy scope is not specified.

0
USER_QUERY =

Policy check is triggered on user input.

1
AGENT_RESPONSE =

Policy check is triggered on agent response. Applying this policy scope will introduce additional latency before the agent can respond.

2
USER_QUERY_AND_AGENT_RESPONSE =

Policy check is triggered on both user input and agent response. Applying this policy scope will introduce additional latency before the agent can respond.

3