Class: Google::Cloud::Ces::V1beta::ImportAppRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.ImportApp.

Defined Under Namespace

Classes: ImportOptions

Instance Attribute Summary collapse

Instance Attribute Details

#app_content::String

Returns Raw bytes representing the compressed zip file with the app folder structure.

Note: The following fields are mutually exclusive: app_content, gcs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Raw bytes representing the compressed zip file with the app folder structure.

    Note: The following fields are mutually exclusive: app_content, gcs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end

#app_id::String

Returns Optional. The ID to use for the imported app.

  • If not specified, a unique ID will be automatically assigned for the app.
  • Otherwise, the imported app will use this ID as the final component of its resource name. If an app with the same ID already exists at the specified location in the project, the content of the existing app will be replaced.

Returns:

  • (::String)

    Optional. The ID to use for the imported app.

    • If not specified, a unique ID will be automatically assigned for the app.
    • Otherwise, the imported app will use this ID as the final component of its resource name. If an app with the same ID already exists at the specified location in the project, the content of the existing app will be replaced.


227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end

#display_name::String

Returns Optional. The display name of the app to import.

  • If the app is created on import, and the display name is specified, the imported app will use this display name. If a conflict is detected with an existing app, a timestamp will be appended to the display name to make it unique.
  • If the app is a reimport, this field should not be set. Providing a display name during reimport will result in an INVALID_ARGUMENT error.

Returns:

  • (::String)

    Optional. The display name of the app to import.

    • If the app is created on import, and the display name is specified, the imported app will use this display name. If a conflict is detected with an existing app, a timestamp will be appended to the display name to make it unique.
    • If the app is a reimport, this field should not be set. Providing a display name during reimport will result in an INVALID_ARGUMENT error.


227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end

#gcs_uri::String

Returns The Google Cloud Storage URI from which to import app. The format of this URI must be gs://<bucket-name>/<object-name>.

Note: The following fields are mutually exclusive: gcs_uri, app_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The Google Cloud Storage URI from which to import app. The format of this URI must be gs://<bucket-name>/<object-name>.

    Note: The following fields are mutually exclusive: gcs_uri, app_content. If a field in that set is populated, all other fields in the set will automatically be cleared.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end

#ignore_app_lock::Boolean

Returns Optional. Flag for overriding the app lock during import. If set to true, the import process will ignore the app lock.

Returns:

  • (::Boolean)

    Optional. Flag for overriding the app lock during import. If set to true, the import process will ignore the app lock.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end

#import_options::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions

Returns Optional. Options governing the import process for the app.

Returns:



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end

#parent::String

Returns Required. The parent resource name with the location of the app to import.

Returns:

  • (::String)

    Required. The parent resource name with the location of the app to import.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 227

class ImportAppRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration options for the app import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing app data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportAppRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an app with the same ID
    # already exists, or when imported resources (like Agents, Tools, etc.)
    # have the same display names as existing resources within that app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Replace existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # updated based on the imported app.
      # - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the
      #   imported app that have the same display name as existing resources
      #   will overwrite the existing ones.
      # - Imported resources with new display names will be created.
      # - Existing resources that do not have a matching display name in the
      #   imported app will remain untouched.
      REPLACE = 1

      # Overwrite existing data with imported data.
      # If an app with the same `app_id` already exists, its content will be
      # overwritten with the imported app.
      # - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in
      #   the app will be deleted.
      # - Imported resources will be created as new resources.
      OVERWRITE = 2
    end
  end
end