Class: Google::Cloud::Ces::V1beta::ImportAppResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Response message for AgentService.ImportApp.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns The resource name of the app that was imported.

Returns:

  • (::String)

    The resource name of the app that was imported.



280
281
282
283
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 280

class ImportAppResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#warnings::Array<::String>

Returns Warning messages generated during the import process. If errors occur for specific resources, they will not be included in the imported app and the error will be mentioned here.

Returns:

  • (::Array<::String>)

    Warning messages generated during the import process. If errors occur for specific resources, they will not be included in the imported app and the error will be mentioned here.



280
281
282
283
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 280

class ImportAppResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end