Class: Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Configuration options for the evaluation import process. These options control how the import behaves, particularly when conflicts arise with existing evaluations data.
Defined Under Namespace
Modules: ConflictResolutionStrategy
Instance Attribute Summary collapse
Instance Attribute Details
#conflict_resolution_strategy ⇒ ::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy
Returns Optional. The strategy to use when resolving conflicts during import.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 204 class ImportOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the strategy for handling conflicts when an evaluation with the # same evaluation ID already exists in the app. module ConflictResolutionStrategy # The conflict resolution strategy is unspecified. CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0 # Overwrite the existing evaluation with the new one. OVERWRITE = 1 # Keep the existing evaluation and skip the new one. SKIP = 2 # Keep the existing evaluation and duplicate the new one as a new # evaluation. DUPLICATE = 3 end end |