Module: Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy

Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Defines the strategy for handling conflicts when an evaluation with the same evaluation ID already exists in the app.

Constant Summary collapse

CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED =

The conflict resolution strategy is unspecified.

0
OVERWRITE =

Overwrite the existing evaluation with the new one.

1
SKIP =

Keep the existing evaluation and skip the new one.

2
DUPLICATE =

Keep the existing evaluation and duplicate the new one as a new evaluation.

3