Class: Google::Cloud::Ces::V1beta::InputAudioConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/session_service.rb

Overview

InputAudioConfig configures how the CES agent should interpret the incoming audio data.

Instance Attribute Summary collapse

Instance Attribute Details

#audio_encoding::Google::Cloud::Ces::V1beta::AudioEncoding

Returns Required. The encoding of the input audio data.

Returns:



62
63
64
65
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 62

class InputAudioConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#noise_suppression_level::String

Returns Optional. Whether to enable noise suppression on the input audio. Available values are "low", "moderate", "high", "very_high".

Returns:

  • (::String)

    Optional. Whether to enable noise suppression on the input audio. Available values are "low", "moderate", "high", "very_high".



62
63
64
65
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 62

class InputAudioConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sample_rate_hertz::Integer

Returns Required. The sample rate (in Hertz) of the input audio data.

Returns:

  • (::Integer)

    Required. The sample rate (in Hertz) of the input audio data.



62
63
64
65
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 62

class InputAudioConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end