Class: Google::Cloud::Ces::V1beta::InstagramCredentials

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/deployment.rb

Overview

Ephemeral Meta credentials for Instagram native integration.

Instance Attribute Summary collapse

Instance Attribute Details

#auth_code::String

Returns Required. The Meta auth code provided by the embedded signup flow.

Returns:

  • (::String)

    Required. The Meta auth code provided by the embedded signup flow.



160
161
162
163
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 160

class InstagramCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#conversation_profile_id::String

Returns Required. The Conversation Profile ID to use for the deployment.

Returns:

  • (::String)

    Required. The Conversation Profile ID to use for the deployment.



160
161
162
163
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 160

class InstagramCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end