Class: Google::Cloud::Ces::V1beta::LanguageSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::LanguageSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Language settings of the app.
Instance Attribute Summary collapse
-
#default_language_code ⇒ ::String
Optional.
-
#enable_multilingual_support ⇒ ::Boolean
Optional.
-
#fallback_action ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#supported_language_codes ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#default_language_code ⇒ ::String
Returns Optional. The default language code of the app.
215 216 217 218 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 215 class LanguageSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_multilingual_support ⇒ ::Boolean
Returns Optional. Enables multilingual support. If true, agents in the app will use pre-built instructions to improve handling of multilingual input.
215 216 217 218 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 215 class LanguageSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fallback_action ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: This feature is no longer supported. Use
enable_multilingual_support instead to improve handling of multilingual
input.
The action to perform when an agent receives input in an unsupported
language.
This can be a predefined action or a custom tool call. Valid values are:
- A tool's full resource name, which triggers a specific tool execution.
- A predefined system action, such as "escalate" or "exit", which triggers an EndSession signal with corresponding metadata to terminate the conversation.
215 216 217 218 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 215 class LanguageSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#supported_language_codes ⇒ ::Array<::String>
Returns Optional. List of languages codes supported by the app, in addition to the
default_language_code.
215 216 217 218 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 215 class LanguageSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |