Class: Google::Cloud::Ces::V1beta::LatencyReport
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::LatencyReport
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
Latency report for the evaluation run.
Defined Under Namespace
Classes: CallbackLatency, GuardrailLatency, LatencyMetrics, LlmCallLatency, ToolLatency
Instance Attribute Summary collapse
-
#callback_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::CallbackLatency>
readonly
Output only.
-
#guardrail_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::GuardrailLatency>
readonly
Output only.
-
#llm_call_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::LlmCallLatency>
readonly
Output only.
-
#session_count ⇒ ::Integer
readonly
Output only.
-
#tool_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::ToolLatency>
readonly
Output only.
Instance Attribute Details
#callback_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::CallbackLatency> (readonly)
Returns Output only. Unordered list. Latency metrics for each callback.
1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1274 class LatencyReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Latency metrics for a component. # @!attribute [r] p50_latency # @return [::Google::Protobuf::Duration] # Output only. The 50th percentile latency. # @!attribute [r] p90_latency # @return [::Google::Protobuf::Duration] # Output only. The 90th percentile latency. # @!attribute [r] p99_latency # @return [::Google::Protobuf::Duration] # Output only. The 99th percentile latency. # @!attribute [r] call_count # @return [::Integer] # Output only. The number of times the resource was called. class LatencyMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single tool. # @!attribute [r] tool # @return [::String] # Output only. Format: # `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`. # # Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] toolset_tool # @return [::Google::Cloud::Ces::V1beta::ToolsetTool] # Output only. The toolset tool identifier. # # Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] tool_display_name # @return [::String] # Output only. The display name of the tool. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the tool. class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single callback. # @!attribute [r] stage # @return [::String] # Output only. The stage of the callback. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the callback. class CallbackLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single guardrail. # @!attribute [r] guardrail # @return [::String] # Output only. The name of the guardrail. # Format: # `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`. # @!attribute [r] guardrail_display_name # @return [::String] # Output only. The display name of the guardrail. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the guardrail. class GuardrailLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single LLM call. # @!attribute [r] model # @return [::String] # Output only. The name of the model. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the LLM call. class LlmCallLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#guardrail_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::GuardrailLatency> (readonly)
Returns Output only. Unordered list. Latency metrics for each guardrail.
1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1274 class LatencyReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Latency metrics for a component. # @!attribute [r] p50_latency # @return [::Google::Protobuf::Duration] # Output only. The 50th percentile latency. # @!attribute [r] p90_latency # @return [::Google::Protobuf::Duration] # Output only. The 90th percentile latency. # @!attribute [r] p99_latency # @return [::Google::Protobuf::Duration] # Output only. The 99th percentile latency. # @!attribute [r] call_count # @return [::Integer] # Output only. The number of times the resource was called. class LatencyMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single tool. # @!attribute [r] tool # @return [::String] # Output only. Format: # `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`. # # Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] toolset_tool # @return [::Google::Cloud::Ces::V1beta::ToolsetTool] # Output only. The toolset tool identifier. # # Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] tool_display_name # @return [::String] # Output only. The display name of the tool. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the tool. class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single callback. # @!attribute [r] stage # @return [::String] # Output only. The stage of the callback. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the callback. class CallbackLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single guardrail. # @!attribute [r] guardrail # @return [::String] # Output only. The name of the guardrail. # Format: # `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`. # @!attribute [r] guardrail_display_name # @return [::String] # Output only. The display name of the guardrail. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the guardrail. class GuardrailLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single LLM call. # @!attribute [r] model # @return [::String] # Output only. The name of the model. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the LLM call. class LlmCallLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#llm_call_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::LlmCallLatency> (readonly)
Returns Output only. Unordered list. Latency metrics for each LLM call.
1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1274 class LatencyReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Latency metrics for a component. # @!attribute [r] p50_latency # @return [::Google::Protobuf::Duration] # Output only. The 50th percentile latency. # @!attribute [r] p90_latency # @return [::Google::Protobuf::Duration] # Output only. The 90th percentile latency. # @!attribute [r] p99_latency # @return [::Google::Protobuf::Duration] # Output only. The 99th percentile latency. # @!attribute [r] call_count # @return [::Integer] # Output only. The number of times the resource was called. class LatencyMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single tool. # @!attribute [r] tool # @return [::String] # Output only. Format: # `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`. # # Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] toolset_tool # @return [::Google::Cloud::Ces::V1beta::ToolsetTool] # Output only. The toolset tool identifier. # # Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] tool_display_name # @return [::String] # Output only. The display name of the tool. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the tool. class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single callback. # @!attribute [r] stage # @return [::String] # Output only. The stage of the callback. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the callback. class CallbackLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single guardrail. # @!attribute [r] guardrail # @return [::String] # Output only. The name of the guardrail. # Format: # `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`. # @!attribute [r] guardrail_display_name # @return [::String] # Output only. The display name of the guardrail. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the guardrail. class GuardrailLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single LLM call. # @!attribute [r] model # @return [::String] # Output only. The name of the model. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the LLM call. class LlmCallLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session_count ⇒ ::Integer (readonly)
Returns Output only. The total number of sessions considered in the latency report.
1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1274 class LatencyReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Latency metrics for a component. # @!attribute [r] p50_latency # @return [::Google::Protobuf::Duration] # Output only. The 50th percentile latency. # @!attribute [r] p90_latency # @return [::Google::Protobuf::Duration] # Output only. The 90th percentile latency. # @!attribute [r] p99_latency # @return [::Google::Protobuf::Duration] # Output only. The 99th percentile latency. # @!attribute [r] call_count # @return [::Integer] # Output only. The number of times the resource was called. class LatencyMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single tool. # @!attribute [r] tool # @return [::String] # Output only. Format: # `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`. # # Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] toolset_tool # @return [::Google::Cloud::Ces::V1beta::ToolsetTool] # Output only. The toolset tool identifier. # # Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] tool_display_name # @return [::String] # Output only. The display name of the tool. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the tool. class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single callback. # @!attribute [r] stage # @return [::String] # Output only. The stage of the callback. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the callback. class CallbackLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single guardrail. # @!attribute [r] guardrail # @return [::String] # Output only. The name of the guardrail. # Format: # `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`. # @!attribute [r] guardrail_display_name # @return [::String] # Output only. The display name of the guardrail. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the guardrail. class GuardrailLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single LLM call. # @!attribute [r] model # @return [::String] # Output only. The name of the model. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the LLM call. class LlmCallLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tool_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::LatencyReport::ToolLatency> (readonly)
Returns Output only. Unordered list. Latency metrics for each tool.
1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1274 class LatencyReport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Latency metrics for a component. # @!attribute [r] p50_latency # @return [::Google::Protobuf::Duration] # Output only. The 50th percentile latency. # @!attribute [r] p90_latency # @return [::Google::Protobuf::Duration] # Output only. The 90th percentile latency. # @!attribute [r] p99_latency # @return [::Google::Protobuf::Duration] # Output only. The 99th percentile latency. # @!attribute [r] call_count # @return [::Integer] # Output only. The number of times the resource was called. class LatencyMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single tool. # @!attribute [r] tool # @return [::String] # Output only. Format: # `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`. # # Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] toolset_tool # @return [::Google::Cloud::Ces::V1beta::ToolsetTool] # Output only. The toolset tool identifier. # # Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] tool_display_name # @return [::String] # Output only. The display name of the tool. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the tool. class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single callback. # @!attribute [r] stage # @return [::String] # Output only. The stage of the callback. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the callback. class CallbackLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single guardrail. # @!attribute [r] guardrail # @return [::String] # Output only. The name of the guardrail. # Format: # `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`. # @!attribute [r] guardrail_display_name # @return [::String] # Output only. The display name of the guardrail. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the guardrail. class GuardrailLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Latency metrics for a single LLM call. # @!attribute [r] model # @return [::String] # Output only. The name of the model. # @!attribute [r] latency_metrics # @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics] # Output only. The latency metrics for the LLM call. class LlmCallLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |