Class: Google::Cloud::Ces::V1beta::ListChangelogsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ListChangelogsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.ListChangelogs.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter to be applied when listing the changelogs. See https://google.aip.dev/160 for more details.
The filter string can be used to filter by action, resource_type,
resource_name, author, and create_time.
The : comparator can be used for case-insensitive partial matching on
string fields, while = performs an exact case-sensitive match.
Examples:
action:update(case-insensitive partial match)action="Create"(case-sensitive exact match)resource_type:agentresource_name:my-agentauthor:me@example.comcreate_time > "2025-01-01T00:00:00Z"create_time <= "2025-01-01T00:00:00Z" AND resource_type:tool.
1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1603 class ListChangelogsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Field to sort by. Only "name" and "create_time" is supported. See https://google.aip.dev/132#ordering for more details.
1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1603 class ListChangelogsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1603 class ListChangelogsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. The next_page_token value returned from a previous list AgentService.ListChangelogs call.
1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1603 class ListChangelogsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the app to list changelogs from.
1603 1604 1605 1606 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1603 class ListChangelogsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |