Class: Google::Cloud::Ces::V1beta::ListChangelogsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ListChangelogsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Response message for AgentService.ListChangelogs.
Instance Attribute Summary collapse
-
#changelogs ⇒ ::Array<::Google::Cloud::Ces::V1beta::Changelog>
The list of changelogs.
-
#next_page_token ⇒ ::String
A token that can be sent as ListChangelogsRequest.page_token to retrieve the next page.
Instance Attribute Details
#changelogs ⇒ ::Array<::Google::Cloud::Ces::V1beta::Changelog>
Returns The list of changelogs.
1619 1620 1621 1622 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1619 class ListChangelogsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as ListChangelogsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.
1619 1620 1621 1622 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1619 class ListChangelogsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |