Class: Google::Cloud::Ces::V1beta::ListDeploymentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.ListDeployments.

Instance Attribute Summary collapse

Instance Attribute Details

#order_by::String

Returns Optional. Field to sort by. Only "name" and "create_time" is supported. See https://google.aip.dev/132#ordering for more details.

Returns:



882
883
884
885
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 882

class ListDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of deployments to return. The service may return fewer than this value. If unspecified, at most 50 deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of deployments to return. The service may return fewer than this value. If unspecified, at most 50 deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



882
883
884
885
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 882

class ListDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListDeployments call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListDeployments must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListDeployments call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListDeployments must match the call that provided the page token.



882
883
884
885
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 882

class ListDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent app. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The parent app. Format: projects/{project}/locations/{location}/apps/{app}



882
883
884
885
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 882

class ListDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end