Class: Google::Cloud::Ces::V1beta::ListGuardrailsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ListGuardrailsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Response message for AgentService.ListGuardrails.
Instance Attribute Summary collapse
-
#guardrails ⇒ ::Array<::Google::Cloud::Ces::V1beta::Guardrail>
The list of guardrails.
-
#next_page_token ⇒ ::String
A token that can be sent as ListGuardrailsRequest.page_token to retrieve the next page.
Instance Attribute Details
#guardrails ⇒ ::Array<::Google::Cloud::Ces::V1beta::Guardrail>
Returns The list of guardrails.
786 787 788 789 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 786 class ListGuardrailsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as ListGuardrailsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.
786 787 788 789 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 786 class ListGuardrailsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |