Class: Google::Cloud::Ces::V1beta::ListScheduledEvaluationRunsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter to be applied when listing the scheduled evaluation runs. See https://google.aip.dev/160 for more details. Currently supports filtering by:

  • request.evaluations:evaluation_id
  • request.evaluation_dataset:evaluation_dataset_id.

Returns:

  • (::String)

    Optional. Filter to be applied when listing the scheduled evaluation runs. See https://google.aip.dev/160 for more details. Currently supports filtering by:

    • request.evaluations:evaluation_id
    • request.evaluation_dataset:evaluation_dataset_id


658
659
660
661
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 658

class ListScheduledEvaluationRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to sort by. Supported fields are: "name" (ascending), "create_time" (descending), "update_time" (descending), "next_scheduled_execution" (ascending), and "last_completed_run.create_time" (descending). If not included, "update_time" will be the default. See https://google.aip.dev/132#ordering for more details.

Returns:

  • (::String)

    Optional. Field to sort by. Supported fields are: "name" (ascending), "create_time" (descending), "update_time" (descending), "next_scheduled_execution" (ascending), and "last_completed_run.create_time" (descending). If not included, "update_time" will be the default. See https://google.aip.dev/132#ordering for more details.



658
659
660
661
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 658

class ListScheduledEvaluationRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.



658
659
660
661
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 658

class ListScheduledEvaluationRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous list EvaluationService.ListScheduledEvaluationRuns call.

Returns:



658
659
660
661
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 658

class ListScheduledEvaluationRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the app to list scheduled evaluation runs from.

Returns:

  • (::String)

    Required. The resource name of the app to list scheduled evaluation runs from.



658
659
660
661
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 658

class ListScheduledEvaluationRunsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end