Class: Google::Cloud::Ces::V1beta::ListScheduledEvaluationRunsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that can be sent as ListScheduledEvaluationRunsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.

Returns:



674
675
676
677
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 674

class ListScheduledEvaluationRunsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scheduled_evaluation_runs::Array<::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun>

Returns The list of scheduled evaluation runs.

Returns:



674
675
676
677
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 674

class ListScheduledEvaluationRunsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end