Class: Google::Cloud::Ces::V1beta::ListToolsetsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Response message for AgentService.ListToolsets.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that can be sent as ListToolsetsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as ListToolsetsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.



1003
1004
1005
1006
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1003

class ListToolsetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#toolsets::Array<::Google::Cloud::Ces::V1beta::Toolset>

Returns The list of toolsets.

Returns:



1003
1004
1005
1006
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1003

class ListToolsetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end