Class: Google::Cloud::Ces::V1beta::McpToolOverride

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb

Overview

Overrides associated with a given tool in a Toolset. This enables "pinning" or "overriding" of tool definitions from the external dynamic server.

Instance Attribute Summary collapse

Instance Attribute Details

#description_override::String

Returns Optional. If present, this tool uses this description instead of the original description from the server.

Returns:

  • (::String)

    Optional. If present, this tool uses this description instead of the original description from the server.



94
95
96
97
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 94

class McpToolOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name_override::String

Returns Optional. If present, this tool uses this name in the Agent instead of the original name. This is primarily used as an alias if the MCP server offers poorly named tools.

Returns:

  • (::String)

    Optional. If present, this tool uses this name in the Agent instead of the original name. This is primarily used as an alias if the MCP server offers poorly named tools.



94
95
96
97
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 94

class McpToolOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#snapshot::Google::Cloud::Ces::V1beta::McpToolDefinition (readonly)

Returns Output only. If present, this tool is "Pinned" and uses the snapshot values as fallbacks if the server becomes temporarily unavailable or if no Override is present.

Returns:



94
95
96
97
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 94

class McpToolOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool::String

Returns Required. The original name of the tool as it is emitted by the MCP server.

Returns:

  • (::String)

    Required. The original name of the tool as it is emitted by the MCP server.



94
95
96
97
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 94

class McpToolOverride
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end