Class: Google::Cloud::Ces::V1beta::MetricAnalysisSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline.

Instance Attribute Summary collapse

Instance Attribute Details

#llm_metrics_opted_out::Boolean

Returns Optional. Whether to collect conversation data for llm analysis metrics. If true, conversation data will not be collected for llm analysis metrics; otherwise, conversation data will be collected.

Returns:

  • (::Boolean)

    Optional. Whether to collect conversation data for llm analysis metrics. If true, conversation data will not be collected for llm analysis metrics; otherwise, conversation data will be collected.



376
377
378
379
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 376

class MetricAnalysisSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end