Class: Google::Cloud::Ces::V1beta::OmnichannelIntegrationConfig::WhatsappConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::OmnichannelIntegrationConfig::WhatsappConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/omnichannel.rb
Overview
How Omnichannel should receive/reply events from WhatsApp.
Instance Attribute Summary collapse
-
#meta_business_portfolio_id ⇒ ::String
The Meta Business Portfolio (MBP) ID.
-
#phone_number ⇒ ::String
The phone number used for sending/receiving messages.
-
#phone_number_id ⇒ ::String
The Phone Number ID associated with the WhatsApp Business Account.
-
#webhook_verify_token ⇒ ::String
The verify token configured in the Meta App Dashboard for webhook verification.
-
#whatsapp_business_account_id ⇒ ::String
The customer's WhatsApp Business Account (WABA) ID.
-
#whatsapp_business_token ⇒ ::String
The access token for authenticating API calls to the WhatsApp Cloud API.
Instance Attribute Details
#meta_business_portfolio_id ⇒ ::String
Returns The Meta Business Portfolio (MBP) ID. https://www.facebook.com/business/help/1710077379203657.
100 101 102 103 |
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel.rb', line 100 class WhatsappConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#phone_number ⇒ ::String
Returns The phone number used for sending/receiving messages.
100 101 102 103 |
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel.rb', line 100 class WhatsappConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#phone_number_id ⇒ ::String
Returns The Phone Number ID associated with the WhatsApp Business Account.
100 101 102 103 |
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel.rb', line 100 class WhatsappConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#webhook_verify_token ⇒ ::String
Returns The verify token configured in the Meta App Dashboard for webhook verification.
100 101 102 103 |
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel.rb', line 100 class WhatsappConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#whatsapp_business_account_id ⇒ ::String
Returns The customer's WhatsApp Business Account (WABA) ID.
100 101 102 103 |
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel.rb', line 100 class WhatsappConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#whatsapp_business_token ⇒ ::String
Returns The access token for authenticating API calls to the WhatsApp Cloud API. https://developers.facebook.com/docs/whatsapp/business-management-api/get-started/#business-integration-system-user-access-tokens.
100 101 102 103 |
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel.rb', line 100 class WhatsappConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |