Class: Google::Cloud::Ces::V1beta::OmnichannelOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/omnichannel_service.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation was created.

Returns:



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel_service.rb', line 38

class OmnichannelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation finished running.

Returns:



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel_service.rb', line 38

class OmnichannelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requested_cancellation::Boolean (readonly)

Returns Output only. Identifies whether the user has requested cancellation of the operation.

Returns:

  • (::Boolean)

    Output only. Identifies whether the user has requested cancellation of the operation.



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel_service.rb', line 38

class OmnichannelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status_message::String (readonly)

Returns Output only. Human-readable status of the operation, if any.

Returns:

  • (::String)

    Output only. Human-readable status of the operation, if any.



38
39
40
41
# File 'proto_docs/google/cloud/ces/v1beta/omnichannel_service.rb', line 38

class OmnichannelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end