Class: Google::Cloud::Ces::V1beta::OpenApiTool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/open_api_tool.rb

Overview

A remote API tool defined by an OpenAPI schema.

Instance Attribute Summary collapse

Instance Attribute Details

#api_authentication::Google::Cloud::Ces::V1beta::ApiAuthentication

Returns Optional. Authentication information required by the API.

Returns:



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Optional. The description of the tool. If not provided, the description of the tool will be derived from the OpenAPI schema, from operation.description or operation.summary.

Returns:

  • (::String)

    Optional. The description of the tool. If not provided, the description of the tool will be derived from the OpenAPI schema, from operation.description or operation.summary.



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ignore_unknown_fields::Boolean

Returns Optional. If true, the agent will ignore unknown fields in the API response.

Returns:

  • (::Boolean)

    Optional. If true, the agent will ignore unknown fields in the API response.



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Optional. The name of the tool. If not provided, the name of the tool will be derived from the OpenAPI schema, from operation.operationId.

Returns:

  • (::String)

    Optional. The name of the tool. If not provided, the name of the tool will be derived from the OpenAPI schema, from operation.operationId.



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#open_api_schema::String

Returns Required. The OpenAPI schema in JSON or YAML format.

Returns:

  • (::String)

    Required. The OpenAPI schema in JSON or YAML format.



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_directory_config::Google::Cloud::Ces::V1beta::ServiceDirectoryConfig

Returns Optional. Service Directory configuration.

Returns:



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tls_config::Google::Cloud::Ces::V1beta::TlsConfig

Returns Optional. The TLS configuration. Includes the custom server certificates that the client will trust.

Returns:



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#url::String

Returns Optional. The server URL of the Open API schema. This field is only set in tools in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema.

Returns:

  • (::String)

    Optional. The server URL of the Open API schema. This field is only set in tools in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema.



59
60
61
62
# File 'proto_docs/google/cloud/ces/v1beta/open_api_tool.rb', line 59

class OpenApiTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end