Class: Google::Cloud::Ces::V1beta::PersonaRunConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

Configuration for running an evaluation for a specific persona.

Instance Attribute Summary collapse

Instance Attribute Details

#persona::String

Returns Optional. The persona to use for the evaluation. Format: projects/{project}/locations/{location}/apps/{app}/evaluationPersonas/{evaluationPersona}.

Returns:

  • (::String)

    Optional. The persona to use for the evaluation. Format: projects/{project}/locations/{location}/apps/{app}/evaluationPersonas/{evaluationPersona}



1567
1568
1569
1570
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1567

class PersonaRunConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#task_count::Integer

Returns Optional. The number of tasks to run for the persona.

Returns:

  • (::Integer)

    Optional. The number of tasks to run for the persona.



1567
1568
1569
1570
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1567

class PersonaRunConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end