Class: Google::Cloud::Ces::V1beta::QualityReport::AgentIssues

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Issues identified for a single agent.

Instance Attribute Summary collapse

Instance Attribute Details

#agent::String

Returns Optional. The name of the agent to which the issues are related. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}.

Returns:

  • (::String)

    Optional. The name of the agent to which the issues are related. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}



1500
1501
1502
1503
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1500

class AgentIssues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#issues::Array<::Google::Cloud::Ces::V1beta::QualityReport::Issue>

Returns Optional. List of issues found for this agent.

Returns:



1500
1501
1502
1503
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1500

class AgentIssues
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end