Class: Google::Cloud::Ces::V1beta::QualityReport::Issue

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The issue identified.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. Description of the issue found.

Returns:

  • (::String)

    Optional. Description of the issue found.



1486
1487
1488
1489
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1486

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#occurrence_count::Integer

Returns Optional. How many times this issue occurred.

Returns:

  • (::Integer)

    Optional. How many times this issue occurred.



1486
1487
1488
1489
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1486

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#proposed_solution::String

Returns Optional. Proposed solution to fix the issue by modifying instructions or tools.

Returns:

  • (::String)

    Optional. Proposed solution to fix the issue by modifying instructions or tools.



1486
1487
1488
1489
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1486

class Issue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end