Class: Google::Cloud::Ces::V1beta::RedactionConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Configuration to instruct how sensitive data should be handled.

Instance Attribute Summary collapse

Instance Attribute Details

#deidentify_template::String

Returns Optional. DLP deidentify template name to instruct on how to de-identify content.

Format: projects/{project}/locations/{location}/deidentifyTemplates/{deidentify_template}.

Returns:

  • (::String)

    Optional. DLP deidentify template name to instruct on how to de-identify content.

    Format: projects/{project}/locations/{location}/deidentifyTemplates/{deidentify_template}



726
727
728
729
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 726

class RedactionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_redaction::Boolean

Returns Optional. If true, redaction will be applied in various logging scenarios, including conversation history, Cloud Logging and audio recording.

Returns:

  • (::Boolean)

    Optional. If true, redaction will be applied in various logging scenarios, including conversation history, Cloud Logging and audio recording.



726
727
728
729
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 726

class RedactionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#inspect_template::String

Returns Optional. DLP inspect template name to configure detection of sensitive data types.

Format: projects/{project}/locations/{location}/inspectTemplates/{inspect_template}.

Returns:

  • (::String)

    Optional. DLP inspect template name to configure detection of sensitive data types.

    Format: projects/{project}/locations/{location}/inspectTemplates/{inspect_template}



726
727
728
729
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 726

class RedactionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end