Class: Google::Cloud::Ces::V1beta::RemoteAgentTool

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_card.rb

Overview

Represents a tool that allows the agent to call another remote agent.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_card::Google::Cloud::Ces::V1beta::AgentCard

Returns Required. The agent card of the remote agent that this tool invokes.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 115

class RemoteAgentTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Required. The description of the tool.

Returns:

  • (::String)

    Required. The description of the tool.



115
116
117
118
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 115

class RemoteAgentTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the tool.

Returns:

  • (::String)

    Required. The name of the tool.



115
116
117
118
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 115

class RemoteAgentTool
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end