Class: Google::Cloud::Ces::V1beta::RetrieveToolSchemaRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/tool_service.rb

Overview

Request message for ToolService.RetrieveToolSchema.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The resource name of the app which the tool/toolset belongs to. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The resource name of the app which the tool/toolset belongs to. Format: projects/{project}/locations/{location}/apps/{app}



116
117
118
119
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 116

class RetrieveToolSchemaRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tool::String

Returns Optional. The name of the tool to retrieve the schema for. Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}

Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. The name of the tool to retrieve the schema for. Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}

    Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



116
117
118
119
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 116

class RetrieveToolSchemaRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#toolset_tool::Google::Cloud::Ces::V1beta::ToolsetTool

Optional. The toolset tool to retrieve the schema for. Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.

Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::ToolsetTool)

    Optional. The toolset tool to retrieve the schema for. Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.

    Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.



116
117
118
119
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 116

class RetrieveToolSchemaRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end