Class: Google::Cloud::Ces::V1beta::RunEvaluationResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Response message for EvaluationService.RunEvaluation.

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_run::String

Returns The name of the evaluation run that was created. Format: projects/{project}/locations/{location}/apps/{app}/evaluationRuns/{evaluation_run}.

Returns:

  • (::String)

    The name of the evaluation run that was created. Format: projects/{project}/locations/{location}/apps/{app}/evaluationRuns/{evaluation_run}



31
32
33
34
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 31

class RunEvaluationResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end