Class: Google::Cloud::Ces::V1beta::ScheduledEvaluationRun

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

Represents a scheduled evaluation run configuration.

Defined Under Namespace

Classes: SchedulingConfig

Instance Attribute Summary collapse

Instance Attribute Details

#active::Boolean

Returns Optional. Whether this config is active.

Returns:

  • (::Boolean)

    Optional. Whether this config is active



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the scheduled evaluation run was created.

Returns:



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#created_by::String (readonly)

Returns Output only. The user who created the scheduled evaluation run.

Returns:

  • (::String)

    Output only. The user who created the scheduled evaluation run.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#description::String

Returns Optional. User-defined description of the scheduled evaluation run.

Returns:

  • (::String)

    Optional. User-defined description of the scheduled evaluation run.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#display_name::String

Returns Required. User-defined display name of the scheduled evaluation run config.

Returns:

  • (::String)

    Required. User-defined display name of the scheduled evaluation run config.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#etag::String (readonly)

Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.

Returns:

  • (::String)

    Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#last_completed_run::String (readonly)

Returns Output only. The last successful EvaluationRun of this scheduled execution. Format: projects/{project}/locations/{location}/apps/{app}/evaluationRuns/{evaluationRun}.

Returns:

  • (::String)

    Output only. The last successful EvaluationRun of this scheduled execution. Format: projects/{project}/locations/{location}/apps/{app}/evaluationRuns/{evaluationRun}



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#last_updated_by::String (readonly)

Returns Output only. The user who last updated the evaluation.

Returns:

  • (::String)

    Output only. The user who last updated the evaluation.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#name::String

Returns Identifier. The unique identifier of the scheduled evaluation run config. Format: projects/{projectId}/locations/{locationId}/apps/{appId}/scheduledEvaluationRuns/{scheduledEvaluationRunId}.

Returns:

  • (::String)

    Identifier. The unique identifier of the scheduled evaluation run config. Format: projects/{projectId}/locations/{locationId}/apps/{appId}/scheduledEvaluationRuns/{scheduledEvaluationRunId}



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#next_scheduled_execution_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The next time this is scheduled to execute.

Returns:



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#request::Google::Cloud::Ces::V1beta::RunEvaluationRequest

Returns Required. The RunEvaluationRequest to schedule.

Returns:



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#scheduling_config::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig

Returns Required. Configuration for the timing and frequency with which to execute the evaluations.

Returns:



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#total_executions::Integer (readonly)

Returns Output only. The total number of times this run has been executed.

Returns:

  • (::Integer)

    Output only. The total number of times this run has been executed



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when the evaluation was last updated.

Returns:



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1587

class ScheduledEvaluationRun
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Eval scheduling configuration details
  # @!attribute [rw] frequency
  #   @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency]
  #     Required. The frequency with which to run the eval
  # @!attribute [rw] start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Required. Timestamp when the eval should start.
  # @!attribute [rw] days_of_week
  #   @return [::Array<::Integer>]
  #     Optional. The days of the week to run the eval. Applicable only for
  #     Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is
  #     Sunday.
  class SchedulingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The frequencies evals can be run at
    module Frequency
      # The frequency is unspecified.
      FREQUENCY_UNSPECIFIED = 0

      # Indicates a one-time scheduled run that should not repeat
      NONE = 1

      # Run the evaluation daily.
      DAILY = 2

      # Run the evaluation weekly.
      WEEKLY = 3

      # Run the evaluation biweekly.
      BIWEEKLY = 4
    end
  end
end