Class: Google::Cloud::Ces::V1beta::SessionService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::SessionService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/ces/v1beta/session_service/rest/client.rb
Overview
REST client for the SessionService service.
Session service provides APIs for interacting with CES agents.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new SessionService REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#run_session(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Ces::V1beta::RunSessionResponse
Initiates a single-turn interaction with the CES agent within a session.
-
#stream_run_session(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::RunSessionResponse>
Initiates a single-turn interaction with the CES agent.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#agent_path, #session_path, #tool_path, #toolset_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new SessionService REST client object.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 137 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @session_service_stub = ::Google::Cloud::Ces::V1beta::SessionService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @session_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @session_service_stub.endpoint config.universe_domain = @session_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @session_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
193 194 195 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 193 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Ces", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.run_session.timeout = 220.0 default_config.rpcs.run_session.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
107 108 109 110 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 107 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
200 201 202 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 200 def logger @session_service_stub.logger end |
#run_session(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::RunSessionResponse #run_session(config: nil, inputs: nil) ⇒ ::Google::Cloud::Ces::V1beta::RunSessionResponse
Initiates a single-turn interaction with the CES agent within a session.
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 251 def run_session request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::RunSessionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.run_session..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.run_session.timeout, metadata: , retry_policy: @config.rpcs.run_session.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @session_service_stub.run_session request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#stream_run_session(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::RunSessionResponse> #stream_run_session(config: nil, inputs: nil) ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::RunSessionResponse>
Initiates a single-turn interaction with the CES agent. Uses server-side streaming to deliver incremental results and partial responses as they are generated.
By default, complete responses (e.g., messages from callbacks or full LLM responses) are sent to the client as soon as they are available. To enable streaming individual text chunks directly from the model, set enable_text_streaming to true.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 338 def stream_run_session request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::RunSessionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.stream_run_session..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.stream_run_session.timeout, metadata: , retry_policy: @config.rpcs.stream_run_session.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy ::Gapic::Rest::ServerStream.new( ::Google::Cloud::Ces::V1beta::RunSessionResponse, ::Gapic::Rest::ThreadedEnumerator.new do |in_q, out_q| @session_service_stub.stream_run_session request, do |chunk| in_q.deq out_q.enq chunk end end ) rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
117 118 119 |
# File 'lib/google/cloud/ces/v1beta/session_service/rest/client.rb', line 117 def universe_domain @session_service_stub.universe_domain end |