Class: Google::Cloud::Ces::V1beta::TimeZoneSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

TimeZone settings of the app.

Instance Attribute Summary collapse

Instance Attribute Details

#time_zone::String

Returns Optional. The time zone of the app from the time zone database, e.g., America/Los_Angeles, Europe/Paris.

Returns:

  • (::String)

    Optional. The time zone of the app from the time zone database, e.g., America/Los_Angeles, Europe/Paris.



182
183
184
185
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 182

class TimeZoneSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end