Class: Google::Cloud::Ces::V1beta::ToolResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ToolResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/example.rb
Overview
The execution result of a specific tool from the client or the agent.
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
readonly
Output only.
-
#id ⇒ ::String
Optional.
-
#response ⇒ ::Google::Protobuf::Struct
Required.
-
#tool ⇒ ::String
Optional.
-
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Optional.
Instance Attribute Details
#display_name ⇒ ::String (readonly)
Returns Output only. Display name of the tool.
223 224 225 226 |
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 223 class ToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns Optional. The matching ID of the [tool call][google.cloud.ces.v1beta.ToolCall] the response is for.
223 224 225 226 |
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 223 class ToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#response ⇒ ::Google::Protobuf::Struct
Returns Required. The tool execution result in JSON object format. Use "output" key to specify tool response and "error" key to specify error details (if any). If "output" and "error" keys are not specified, then whole "response" is treated as tool execution result.
223 224 225 226 |
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 223 class ToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String
Returns Optional. The name of the tool to execute.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
223 224 225 226 |
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 223 class ToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Returns Optional. The toolset tool that got executed.
Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
223 224 225 226 |
# File 'proto_docs/google/cloud/ces/v1beta/example.rb', line 223 class ToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |