Class: Google::Cloud::Ces::V1beta::ToolService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/ces/v1beta/tool_service/client.rb

Overview

Client for the ToolService service.

Tool service provides APIs for interacting with CES tools.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#app_path, #tool_path, #toolset_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new ToolService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Ces::V1beta::ToolService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Ces::V1beta::ToolService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the ToolService client.

Yield Parameters:



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 130

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/ces/v1beta/tool_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @tool_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Ces::V1beta::ToolService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @tool_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @tool_service_stub.endpoint
    config.universe_domain = @tool_service_stub.universe_domain
    config.logger = @tool_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Client)


194
195
196
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 194

def location_client
  @location_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the ToolService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all ToolService clients
::Google::Cloud::Ces::V1beta::ToolService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Ces", "V1beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.timeout = 60.0
    default_config.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the ToolService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



100
101
102
103
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 100

def configure
  yield @config if block_given?
  @config
end

#execute_tool(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::ExecuteToolResponse #execute_tool(tool: nil, toolset_tool: nil, variables: nil, context: nil, parent: nil, args: nil, mock_config: nil) ⇒ ::Google::Cloud::Ces::V1beta::ExecuteToolResponse

Executes the given tool with the given arguments.

Examples:

Basic example

require "google/cloud/ces/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Ces::V1beta::ToolService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Ces::V1beta::ExecuteToolRequest.new

# Call the execute_tool method.
result = client.execute_tool request

# The returned object is of type Google::Cloud::Ces::V1beta::ExecuteToolResponse.
p result

Overloads:

  • #execute_tool(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::ExecuteToolResponse

    Pass arguments to execute_tool via a request object, either of type ExecuteToolRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Ces::V1beta::ExecuteToolRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #execute_tool(tool: nil, toolset_tool: nil, variables: nil, context: nil, parent: nil, args: nil, mock_config: nil) ⇒ ::Google::Cloud::Ces::V1beta::ExecuteToolResponse

    Pass arguments to execute_tool via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • tool (::String) (defaults to: nil)

      Optional. The name of the tool to execute. Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}

      Note: The following parameters are mutually exclusive: tool, toolset_tool. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • toolset_tool (::Google::Cloud::Ces::V1beta::ToolsetTool, ::Hash) (defaults to: nil)

      Optional. The toolset tool to execute. Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.

      Note: The following parameters are mutually exclusive: toolset_tool, tool. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • variables (::Google::Protobuf::Struct, ::Hash) (defaults to: nil)

      Optional. The variables that are available for the tool execution.

      Note: The following parameters are mutually exclusive: variables, context. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • context (::Google::Protobuf::Struct, ::Hash) (defaults to: nil)

      Optional. The ToolCallContext to be passed to the Python tool.

      Note: The following parameters are mutually exclusive: context, variables. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • parent (::String) (defaults to: nil)

      Required. The resource name of the app which the tool/toolset belongs to. Format: projects/{project}/locations/{location}/apps/{app}

    • args (::Google::Protobuf::Struct, ::Hash) (defaults to: nil)

      Optional. The input parameters and values for the tool in JSON object format.

    • mock_config (::Google::Cloud::Ces::V1beta::MockConfig, ::Hash) (defaults to: nil)

      Optional. Mock configuration for the tool execution. If this field is set, tools that call other tools will be mocked based on the provided patterns and responses.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 280

def execute_tool request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::ExecuteToolRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.execute_tool..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Ces::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.execute_tool.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.execute_tool.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tool_service_stub.call_rpc :execute_tool, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


201
202
203
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 201

def logger
  @tool_service_stub.logger
end

#retrieve_tool_schema(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolSchemaResponse #retrieve_tool_schema(tool: nil, toolset_tool: nil, parent: nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolSchemaResponse

Retrieve the schema of the given tool. The schema is computed on the fly for the given instance of the tool.

Examples:

Basic example

require "google/cloud/ces/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Ces::V1beta::ToolService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Ces::V1beta::RetrieveToolSchemaRequest.new

# Call the retrieve_tool_schema method.
result = client.retrieve_tool_schema request

# The returned object is of type Google::Cloud::Ces::V1beta::RetrieveToolSchemaResponse.
p result

Overloads:

  • #retrieve_tool_schema(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolSchemaResponse

    Pass arguments to retrieve_tool_schema via a request object, either of type RetrieveToolSchemaRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Ces::V1beta::RetrieveToolSchemaRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #retrieve_tool_schema(tool: nil, toolset_tool: nil, parent: nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolSchemaResponse

    Pass arguments to retrieve_tool_schema via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • tool (::String) (defaults to: nil)

      Optional. The name of the tool to retrieve the schema for. Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}

      Note: The following parameters are mutually exclusive: tool, toolset_tool. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • toolset_tool (::Google::Cloud::Ces::V1beta::ToolsetTool, ::Hash) (defaults to: nil)

      Optional. The toolset tool to retrieve the schema for. Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.

      Note: The following parameters are mutually exclusive: toolset_tool, tool. At most one of these parameters can be set. If more than one is set, only one will be used, and it is not defined which one.

    • parent (::String) (defaults to: nil)

      Required. The resource name of the app which the tool/toolset belongs to. Format: projects/{project}/locations/{location}/apps/{app}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 379

def retrieve_tool_schema request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::RetrieveToolSchemaRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.retrieve_tool_schema..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Ces::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.retrieve_tool_schema.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.retrieve_tool_schema.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tool_service_stub.call_rpc :retrieve_tool_schema, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#retrieve_tools(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolsResponse #retrieve_tools(toolset: nil, tool_ids: nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolsResponse

Retrieve the list of tools included in the specified toolset.

Examples:

Basic example

require "google/cloud/ces/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Ces::V1beta::ToolService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Ces::V1beta::RetrieveToolsRequest.new

# Call the retrieve_tools method.
result = client.retrieve_tools request

# The returned object is of type Google::Cloud::Ces::V1beta::RetrieveToolsResponse.
p result

Overloads:

  • #retrieve_tools(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolsResponse

    Pass arguments to retrieve_tools via a request object, either of type RetrieveToolsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Ces::V1beta::RetrieveToolsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #retrieve_tools(toolset: nil, tool_ids: nil) ⇒ ::Google::Cloud::Ces::V1beta::RetrieveToolsResponse

    Pass arguments to retrieve_tools via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • toolset (::String) (defaults to: nil)

      Required. The name of the toolset to retrieve the tools for. Format: projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}

    • tool_ids (::Array<::String>) (defaults to: nil)

      Optional. The identifiers of the tools to retrieve from the toolset. If empty, all tools in the toolset will be returned.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 469

def retrieve_tools request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::RetrieveToolsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.retrieve_tools..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Ces::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.toolset
    header_params["toolset"] = request.toolset
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.retrieve_tools.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.retrieve_tools.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @tool_service_stub.call_rpc :retrieve_tools, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


110
111
112
# File 'lib/google/cloud/ces/v1beta/tool_service/client.rb', line 110

def universe_domain
  @tool_service_stub.universe_domain
end