Class: Google::Cloud::Ces::V1beta::TransferRule::DeterministicTransfer

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_transfers.rb

Overview

Deterministic transfer rule. When the condition evaluates to true, the transfer occurs.

Instance Attribute Summary collapse

Instance Attribute Details

#expression_condition::Google::Cloud::Ces::V1beta::ExpressionCondition

Returns Optional. A rule that evaluates a session state condition. If the condition evaluates to true, the transfer occurs.

Note: The following fields are mutually exclusive: expression_condition, python_code_condition. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::ExpressionCondition)

    Optional. A rule that evaluates a session state condition. If the condition evaluates to true, the transfer occurs.

    Note: The following fields are mutually exclusive: expression_condition, python_code_condition. If a field in that set is populated, all other fields in the set will automatically be cleared.



81
82
83
84
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 81

class DeterministicTransfer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#python_code_condition::Google::Cloud::Ces::V1beta::PythonCodeCondition

Returns Optional. A rule that uses Python code block to evaluate the conditions. If the condition evaluates to true, the transfer occurs.

Note: The following fields are mutually exclusive: python_code_condition, expression_condition. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::PythonCodeCondition)

    Optional. A rule that uses Python code block to evaluate the conditions. If the condition evaluates to true, the transfer occurs.

    Note: The following fields are mutually exclusive: python_code_condition, expression_condition. If a field in that set is populated, all other fields in the set will automatically be cleared.



81
82
83
84
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 81

class DeterministicTransfer
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end