Class: Google::Cloud::Ces::V1beta::TriggerAction::TransferAgent
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::TriggerAction::TransferAgent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/common.rb
Overview
The agent will transfer the conversation to a different agent.
Instance Attribute Summary collapse
-
#agent ⇒ ::String
Required.
Instance Attribute Details
#agent ⇒ ::String
Returns Required. The name of the agent to transfer the conversation to. The
agent must be in the same app as the current agent. Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}.
123 124 125 126 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 123 class TransferAgent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |