Class: Google::Cloud::Ces::V1beta::UpdateEvaluationDatasetRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_dataset::Google::Cloud::Ces::V1beta::EvaluationDataset

Returns Required. The evaluation dataset to update.

Returns:



280
281
282
283
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 280

class UpdateEvaluationDatasetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



280
281
282
283
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 280

class UpdateEvaluationDatasetRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end