Class: Google::Cloud::Ces::V1beta::UpdateEvaluationExpectationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_expectation::Google::Cloud::Ces::V1beta::EvaluationExpectation

Returns Required. The evaluation expectation to update.

Returns:



803
804
805
806
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 803

class UpdateEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



803
804
805
806
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 803

class UpdateEvaluationExpectationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end