Class: Google::Cloud::Ces::V1beta::UpdateExampleRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Request message for AgentService.UpdateExample.

Instance Attribute Summary collapse

Instance Attribute Details

#example::Google::Cloud::Ces::V1beta::Example

Returns Required. The example to update.

Returns:



501
502
503
504
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 501

class UpdateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



501
502
503
504
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 501

class UpdateExampleRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end