Class: Google::Cloud::Ces::V1beta::UpdateScheduledEvaluationRunRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#scheduled_evaluation_run::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun

Returns Required. The scheduled evaluation run to update.

Returns:



688
689
690
691
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 688

class UpdateScheduledEvaluationRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



688
689
690
691
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 688

class UpdateScheduledEvaluationRunRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end