Class: Google::Cloud::Ces::V1beta::UpdateSecuritySettingsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#security_settings::Google::Cloud::Ces::V1beta::SecuritySettings

Returns Required. The security settings to update.

Returns:



1675
1676
1677
1678
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1675

class UpdateSecuritySettingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



1675
1676
1677
1678
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1675

class UpdateSecuritySettingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end