Class: Google::Cloud::Ces::V1beta::UpdateToolRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::UpdateToolRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.UpdateTool.
Instance Attribute Summary collapse
-
#tool ⇒ ::Google::Cloud::Ces::V1beta::Tool
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#tool ⇒ ::Google::Cloud::Ces::V1beta::Tool
Returns Required. The tool to update.
605 606 607 608 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 605 class UpdateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
605 606 607 608 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 605 class UpdateToolRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |