Class: Google::Cloud::Ces::V1beta::UploadEvaluationAudioRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#audio_content::String

Returns Required. The raw audio bytes. The format of the audio must be single-channel LINEAR16 with a sample rate of 16kHz (default InputAudioConfig).

Returns:

  • (::String)

    Required. The raw audio bytes. The format of the audio must be single-channel LINEAR16 with a sample rate of 16kHz (default InputAudioConfig).



741
742
743
744
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 741

class UploadEvaluationAudioRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the Evaluation for which to upload the evaluation audio. Format: projects/{project}/locations/{location}/apps/{app}/evaluations/{evaluation}.

Returns:

  • (::String)

    Required. The resource name of the Evaluation for which to upload the evaluation audio. Format: projects/{project}/locations/{location}/apps/{app}/evaluations/{evaluation}



741
742
743
744
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 741

class UploadEvaluationAudioRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#previous_audio_gcs_uri::String

Returns Optional. The Google Cloud Storage URI of the previously uploaded audio file to be deleted. Format: gs://<bucket-name>/<object-name>.

Returns:

  • (::String)

    Optional. The Google Cloud Storage URI of the previously uploaded audio file to be deleted. Format: gs://<bucket-name>/<object-name>



741
742
743
744
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 741

class UploadEvaluationAudioRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end