Class: Google::Cloud::Ces::V1beta::WhatsAppCredentials

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/deployment.rb

Overview

Ephemeral Meta credentials for WhatsApp native integration.

Instance Attribute Summary collapse

Instance Attribute Details

#auth_code::String

Returns Required. The Meta auth code provided by the embedded signup flow.

Returns:

  • (::String)

    Required. The Meta auth code provided by the embedded signup flow.



148
149
150
151
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 148

class WhatsAppCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#business_account_id::String

Returns Required. The Business Account ID to use for the phone number.

Returns:

  • (::String)

    Required. The Business Account ID to use for the phone number.



148
149
150
151
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 148

class WhatsAppCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#conversation_profile_id::String

Returns Required. The Conversation Profile ID to use for the deployment.

Returns:

  • (::String)

    Required. The Conversation Profile ID to use for the deployment.



148
149
150
151
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 148

class WhatsAppCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phone_number::String

Returns Required. The phone number to register with WhatsApp.

Returns:

  • (::String)

    Required. The phone number to register with WhatsApp.



148
149
150
151
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 148

class WhatsAppCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pin::String

Returns Required. The 6-digit PIN created by the user for two-step verification.

Returns:

  • (::String)

    Required. The 6-digit PIN created by the user for two-step verification.



148
149
150
151
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 148

class WhatsAppCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#waba_id::String

Returns Required. The WhatsApp Business Account ID.

Returns:

  • (::String)

    Required. The WhatsApp Business Account ID.



148
149
150
151
# File 'proto_docs/google/cloud/ces/v1beta/deployment.rb', line 148

class WhatsAppCredentials
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end