Class: Google::Cloud::Ces::V1beta::WidgetTool::TextResponseConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/widget_tool.rb

Overview

Configuration for the text response returned with the widget.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#static_text::String

Returns Optional. The static text response to return when type is STATIC.

Returns:

  • (::String)

    Optional. The static text response to return when type is STATIC.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'proto_docs/google/cloud/ces/v1beta/widget_tool.rb', line 67

class TextResponseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how the text response is produced.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # The LLM dynamically decides whether to generate a text response
    # alongside the widget based on the conversation context.
    NONE = 1

    # The LLM is explicitly required to generate a text response.
    LLM_GENERATED = 2

    # A pre-defined static text response is always used.
    STATIC = 3
  end
end

#text_response_instruction::String

Returns Optional. Instruction for the LLM on how to generate the text response. Used as the description for the text response parameter if type is LLM_GENERATED.

Returns:

  • (::String)

    Optional. Instruction for the LLM on how to generate the text response. Used as the description for the text response parameter if type is LLM_GENERATED.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'proto_docs/google/cloud/ces/v1beta/widget_tool.rb', line 67

class TextResponseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how the text response is produced.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # The LLM dynamically decides whether to generate a text response
    # alongside the widget based on the conversation context.
    NONE = 1

    # The LLM is explicitly required to generate a text response.
    LLM_GENERATED = 2

    # A pre-defined static text response is always used.
    STATIC = 3
  end
end

#type::Google::Cloud::Ces::V1beta::WidgetTool::TextResponseConfig::Type

Returns Optional. The strategy for providing the text response.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'proto_docs/google/cloud/ces/v1beta/widget_tool.rb', line 67

class TextResponseConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines how the text response is produced.
  module Type
    # Unspecified type.
    TYPE_UNSPECIFIED = 0

    # The LLM dynamically decides whether to generate a text response
    # alongside the widget based on the conversation context.
    NONE = 1

    # The LLM is explicitly required to generate a text response.
    LLM_GENERATED = 2

    # A pre-defined static text response is always used.
    STATIC = 3
  end
end