Class: Google::Cloud::Ces::V1beta::Agent::RemoteDialogflowAgent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent.rb

Overview

The agent which will transfer execution to a remote Dialogflow CX agent. The Dialogflow agent will process subsequent user queries until the session ends or flow ends, and the control is transferred back to the parent CES agent.

Defined Under Namespace

Classes: InputVariableMappingEntry, OutputVariableMappingEntry

Instance Attribute Summary collapse

Instance Attribute Details

#agent::String

Returns Required. The Dialogflow agent resource name. Format: projects/{project}/locations/{location}/agents/{agent}.

Returns:

  • (::String)

    Required. The Dialogflow agent resource name. Format: projects/{project}/locations/{location}/agents/{agent}



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'proto_docs/google/cloud/ces/v1beta/agent.rb', line 184

class RemoteDialogflowAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class OutputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#environment_id::String

Returns Optional. The environment ID of the Dialogflow agent to be used for the agent execution. If not specified, the draft environment will be used.

Returns:

  • (::String)

    Optional. The environment ID of the Dialogflow agent to be used for the agent execution. If not specified, the draft environment will be used.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'proto_docs/google/cloud/ces/v1beta/agent.rb', line 184

class RemoteDialogflowAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class OutputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#flow_id::String

Returns Optional. The flow ID of the flow in the Dialogflow agent.

Returns:

  • (::String)

    Optional. The flow ID of the flow in the Dialogflow agent.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'proto_docs/google/cloud/ces/v1beta/agent.rb', line 184

class RemoteDialogflowAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class OutputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#input_variable_mapping::Google::Protobuf::Map{::String => ::String}

Returns Optional. The mapping of the app variables names to the Dialogflow session parameters names to be sent to the Dialogflow agent as input.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The mapping of the app variables names to the Dialogflow session parameters names to be sent to the Dialogflow agent as input.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'proto_docs/google/cloud/ces/v1beta/agent.rb', line 184

class RemoteDialogflowAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class OutputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#output_variable_mapping::Google::Protobuf::Map{::String => ::String}

Returns Optional. The mapping of the Dialogflow session parameters names to the app variables names to be sent back to the CES agent after the Dialogflow agent execution ends.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The mapping of the Dialogflow session parameters names to the app variables names to be sent back to the CES agent after the Dialogflow agent execution ends.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'proto_docs/google/cloud/ces/v1beta/agent.rb', line 184

class RemoteDialogflowAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class OutputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#respect_response_interruption_settings::Boolean

Returns Optional. Indicates whether to respect the message-level interruption settings configured in the Dialogflow agent.

  • If false: all response messages from the Dialogflow agent follow the app-level barge-in settings.
  • If true: only response messages with allow_playback_interruption set to true will be interruptable, all other messages follow the app-level barge-in settings.

Returns:

  • (::Boolean)

    Optional. Indicates whether to respect the message-level interruption settings configured in the Dialogflow agent.

    • If false: all response messages from the Dialogflow agent follow the app-level barge-in settings.
    • If true: only response messages with allow_playback_interruption set to true will be interruptable, all other messages follow the app-level barge-in settings.


184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'proto_docs/google/cloud/ces/v1beta/agent.rb', line 184

class RemoteDialogflowAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class InputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class OutputVariableMappingEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end