Class: Google::Cloud::Ces::V1beta::AgentCard
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::AgentCard
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_card.rb
Overview
AgentCard conveys key information about a remote agent. It is a trimmed version of the AgentCard defined in the A2A protocol https://a2a-protocol.org/dev/specification/#441-agentcard
Instance Attribute Summary collapse
-
#description ⇒ ::String
Required.
-
#name ⇒ ::String
Required.
-
#skills ⇒ ::Array<::Google::Cloud::Ces::V1beta::AgentSkill>
Required.
-
#supported_interfaces ⇒ ::Array<::Google::Cloud::Ces::V1beta::AgentInterface>
Required.
-
#version ⇒ ::String
Required.
Instance Attribute Details
#description ⇒ ::String
Returns Required. A description of the agent's domain of action/solution space.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 45 class AgentCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. A human-readable name for the agent.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 45 class AgentCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#skills ⇒ ::Array<::Google::Cloud::Ces::V1beta::AgentSkill>
Returns Required. Skills represent a unit of ability an agent can perform. This may somewhat abstract but represents a more focused set of actions that the agent is highly likely to succeed at.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 45 class AgentCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#supported_interfaces ⇒ ::Array<::Google::Cloud::Ces::V1beta::AgentInterface>
Returns Required. Ordered list of supported interfaces. The first entry is preferred.
45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 45 class AgentCard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |