Class: Google::Cloud::Ces::V1beta::AgentInterface
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::AgentInterface
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_card.rb
Overview
Declares a combination of a target URL, transport and protocol version for interacting with the agent. This allows agents to expose the same functionality over multiple protocol binding mechanisms.
Instance Attribute Summary collapse
-
#protocol_binding ⇒ ::String
Required.
-
#protocol_version ⇒ ::String
Required.
-
#tenant ⇒ ::String
Tenant ID to be used in the request when calling the agent.
-
#url ⇒ ::String
Required.
Instance Attribute Details
#protocol_binding ⇒ ::String
Returns Required. The protocol binding supported at this URL. This is an open form
string, to be easily extended for other protocol bindings. The core ones
officially supported are JSONRPC, GRPC and HTTP+JSON.
71 72 73 74 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 71 class AgentInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#protocol_version ⇒ ::String
Returns Required. The version of the A2A protocol this interface exposes. Use the latest supported minor version per major version. Examples: "0.3", "1.0".
71 72 73 74 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 71 class AgentInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tenant ⇒ ::String
Returns Tenant ID to be used in the request when calling the agent.
71 72 73 74 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 71 class AgentInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#url ⇒ ::String
Returns Required. The URL where this interface is available. Must be a valid absolute HTTPS URL in production. Example: "https://api.example.com/a2a/v1", "https://grpc.example.com/a2a".
71 72 73 74 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_card.rb', line 71 class AgentInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |