Class: Google::Cloud::Ces::V1beta::AgentTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::AgentTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_tool.rb
Overview
Represents a tool that allows the agent to call another agent.
Instance Attribute Summary collapse
-
#agent ⇒ ::String
Optional.
-
#description ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#root_agent ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#agent ⇒ ::String
Returns Optional. The resource name of the agent that is the entry point of the
tool. Format: projects/{project}/locations/{location}/agents/{agent}.
41 42 43 44 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_tool.rb', line 41 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. Description of the tool's purpose.
41 42 43 44 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_tool.rb', line 41 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the agent tool.
41 42 43 44 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_tool.rb', line 41 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#root_agent ⇒ ::String
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: Use agent instead.
The resource name of the root agent that is the entry point of the tool.
Format: projects/{project}/locations/{location}/agents/{agent}.
41 42 43 44 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_tool.rb', line 41 class AgentTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |