Class: Google::Cloud::Ces::V1beta::AudioProcessingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::AudioProcessingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Configuration for how the input and output audio should be processed and delivered.
Defined Under Namespace
Classes: SynthesizeSpeechConfigsEntry
Instance Attribute Summary collapse
-
#ambient_sound_config ⇒ ::Google::Cloud::Ces::V1beta::AmbientSoundConfig
Optional.
-
#barge_in_config ⇒ ::Google::Cloud::Ces::V1beta::BargeInConfig
Optional.
-
#inactivity_timeout ⇒ ::Google::Protobuf::Duration
Optional.
-
#synthesize_speech_configs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig}
Optional.
Instance Attribute Details
#ambient_sound_config ⇒ ::Google::Cloud::Ces::V1beta::AmbientSoundConfig
Returns Optional. Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 246 class AudioProcessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig] class SynthesizeSpeechConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#barge_in_config ⇒ ::Google::Cloud::Ces::V1beta::BargeInConfig
Returns Optional. Configures the agent behavior for the user barge-in activities.
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 246 class AudioProcessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig] class SynthesizeSpeechConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#inactivity_timeout ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration of user inactivity (no speech or interaction) before the agent prompts the user for reengagement. If not set, the agent will not prompt the user for reengagement.
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 246 class AudioProcessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig] class SynthesizeSpeechConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#synthesize_speech_configs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig}
Returns Optional. Configuration of how the agent response should be synthesized, mapping from the language code to SynthesizeSpeechConfig.
If the configuration for the specified language code is not found, the configuration for the root language code will be used. For example, if the map contains "en-us" and "en", and the specified language code is "en-gb", then "en" configuration will be used.
Note: Language code is case-insensitive.
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 246 class AudioProcessingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig] class SynthesizeSpeechConfigsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |