Class: Google::Cloud::Ces::V1beta::BatchDeleteConversationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::BatchDeleteConversationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Response message for AgentService.BatchDeleteConversations.
Instance Attribute Summary collapse
-
#deleted_conversations ⇒ ::Array<::String>
The list of conversations that were successfully deleted.
-
#error_messages ⇒ ::Array<::String>
Optional.
-
#failed_conversations ⇒ ::Array<::String>
The list of conversations that failed to be deleted.
Instance Attribute Details
#deleted_conversations ⇒ ::Array<::String>
Returns The list of conversations that were successfully deleted.
741 742 743 744 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 741 class BatchDeleteConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_messages ⇒ ::Array<::String>
Returns Optional. A list of error messages associated with conversations that failed to be deleted.
741 742 743 744 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 741 class BatchDeleteConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#failed_conversations ⇒ ::Array<::String>
Returns The list of conversations that failed to be deleted.
741 742 743 744 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 741 class BatchDeleteConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |