Class: Google::Cloud::Ces::V1beta::Callback
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Callback
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/common.rb
Overview
A callback defines the custom logic to be executed at various stages of agent interaction.
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional.
-
#disabled ⇒ ::Boolean
Optional.
-
#proactive_execution_enabled ⇒ ::Boolean
Optional.
-
#python_code ⇒ ::String
Required.
Instance Attribute Details
#description ⇒ ::String
Returns Optional. Human-readable description of the callback.
44 45 46 47 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44 class Callback include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disabled ⇒ ::Boolean
Returns Optional. Whether the callback is disabled. Disabled callbacks are ignored by the agent.
44 45 46 47 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44 class Callback include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#proactive_execution_enabled ⇒ ::Boolean
Returns Optional. If enabled, the callback will also be executed on intermediate model outputs. This setting only affects after model callback. ENABLE WITH CAUTION. Typically after model callback only needs to be executed after receiving all model responses. Enabling proactive execution may have negative implication on the execution cost and latency, and should only be enabled in rare situations.
44 45 46 47 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 44 class Callback include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |