Class: Google::Cloud::Ces::V1beta::Citations::CitedChunk
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Citations::CitedChunk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/session_service.rb
Overview
Piece of cited information.
Instance Attribute Summary collapse
-
#requires_attribution ⇒ ::Boolean
Whether this citation requires attribution to be shown to the end users.
-
#text ⇒ ::String
Text used for citation.
-
#title ⇒ ::String
Title of the cited document.
-
#uri ⇒ ::String
URI used for citation.
Instance Attribute Details
#requires_attribution ⇒ ::Boolean
Returns Whether this citation requires attribution to be shown to the end users.
213 214 215 216 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 213 class CitedChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::String
Returns Text used for citation.
213 214 215 216 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 213 class CitedChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String
Returns Title of the cited document.
213 214 215 216 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 213 class CitedChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#uri ⇒ ::String
Returns URI used for citation.
213 214 215 216 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 213 class CitedChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |