Class: Google::Cloud::Ces::V1beta::CreateScheduledEvaluationRunRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::CreateScheduledEvaluationRunRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Request message for EvaluationService.CreateScheduledEvaluationRun.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#scheduled_evaluation_run ⇒ ::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun
Required.
-
#scheduled_evaluation_run_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The app to create the scheduled evaluation run for.
Format:
projects/{project}/locations/{location}/apps/{app}.
611 612 613 614 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 611 class CreateScheduledEvaluationRunRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scheduled_evaluation_run ⇒ ::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun
Returns Required. The scheduled evaluation run to create.
611 612 613 614 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 611 class CreateScheduledEvaluationRunRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scheduled_evaluation_run_id ⇒ ::String
Returns Optional. The ID to use for the scheduled evaluation run, which will become the final component of the scheduled evaluation run's resource name. If not provided, a unique ID will be automatically assigned.
611 612 613 614 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 611 class CreateScheduledEvaluationRunRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |