Class: Google::Cloud::Ces::V1beta::DataStoreSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Data store related settings for the app.

Defined Under Namespace

Classes: Engine

Instance Attribute Summary collapse

Instance Attribute Details

#engines::Array<::Google::Cloud::Ces::V1beta::DataStoreSettings::Engine> (readonly)

Returns Output only. The engines for the app.

Returns:



735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 735

class DataStoreSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An engine to which the data stores are connected.
  # See Vertex AI Search:
  # https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search-introduction.
  # @!attribute [r] name
  #   @return [::String]
  #     Output only. The resource name of the engine.
  #     Format:
  #     `projects/{project}/locations/{location}/collections/{collection}/engines/{engine}`
  # @!attribute [r] type
  #   @return [::Google::Cloud::Ces::V1beta::DataStoreSettings::Engine::Type]
  #     Output only. The type of the engine.
  class Engine
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The type of the engine.
    # See the documentation available at
    # https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1/SolutionType
    # and
    # https://cloud.google.com/generative-ai-app-builder/docs/create-datastore-ingest.
    module Type
      # Unspecified engine type.
      TYPE_UNSPECIFIED = 0

      # The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores
      # added to the app will be added to this engine.
      ENGINE_TYPE_SEARCH = 1

      # Chat engine type.
      # The SOLUTION_TYPE_CHAT engine for the app. All connector data stores
      # added to the app will be added to this engine.
      ENGINE_TYPE_CHAT = 2
    end
  end
end