Class: Google::Cloud::Ces::V1beta::DataStoreSettings::Engine
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DataStoreSettings::Engine
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
An engine to which the data stores are connected. See Vertex AI Search: https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search-introduction.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#name ⇒ ::String
readonly
Output only.
-
#type ⇒ ::Google::Cloud::Ces::V1beta::DataStoreSettings::Engine::Type
readonly
Output only.
Instance Attribute Details
#name ⇒ ::String (readonly)
Returns Output only. The resource name of the engine.
Format:
projects/{project}/locations/{location}/collections/{collection}/engines/{engine}.
750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 750 class Engine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the engine. # See the documentation available at # https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1/SolutionType # and # https://cloud.google.com/generative-ai-app-builder/docs/create-datastore-ingest. module Type # Unspecified engine type. TYPE_UNSPECIFIED = 0 # The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores # added to the app will be added to this engine. ENGINE_TYPE_SEARCH = 1 # Chat engine type. # The SOLUTION_TYPE_CHAT engine for the app. All connector data stores # added to the app will be added to this engine. ENGINE_TYPE_CHAT = 2 end end |
#type ⇒ ::Google::Cloud::Ces::V1beta::DataStoreSettings::Engine::Type (readonly)
Returns Output only. The type of the engine.
750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 750 class Engine include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the engine. # See the documentation available at # https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1/SolutionType # and # https://cloud.google.com/generative-ai-app-builder/docs/create-datastore-ingest. module Type # Unspecified engine type. TYPE_UNSPECIFIED = 0 # The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores # added to the app will be added to this engine. ENGINE_TYPE_SEARCH = 1 # Chat engine type. # The SOLUTION_TYPE_CHAT engine for the app. All connector data stores # added to the app will be added to this engine. ENGINE_TYPE_CHAT = 2 end end |