Class: Google::Cloud::Ces::V1beta::DataStoreTool::GroundingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DataStoreTool::GroundingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/data_store_tool.rb
Overview
Grounding configuration.
Instance Attribute Summary collapse
-
#disabled ⇒ ::Boolean
Optional.
-
#grounding_level ⇒ ::Float
Optional.
Instance Attribute Details
#disabled ⇒ ::Boolean
Returns Optional. Whether grounding is disabled.
102 103 104 105 |
# File 'proto_docs/google/cloud/ces/v1beta/data_store_tool.rb', line 102 class GroundingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#grounding_level ⇒ ::Float
Returns Optional. The groundedness threshold of the answer based on the retrieved sources. The value has a configurable range of [1, 5]. The level is used to threshold the groundedness of the answer, meaning that all responses with a groundedness score below the threshold will fall back to returning relevant snippets only.
For example, a level of 3 means that the groundedness score must be 3 or higher for the response to be returned.
102 103 104 105 |
# File 'proto_docs/google/cloud/ces/v1beta/data_store_tool.rb', line 102 class GroundingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |