Class: Google::Cloud::Ces::V1beta::DeleteAppRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DeleteAppRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.DeleteApp.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the app. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the app, deletion will be blocked and an ABORTED error will be returned.
125 126 127 128 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 125 class DeleteAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the app to delete.
125 126 127 128 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 125 class DeleteAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |