Class: Google::Cloud::Ces::V1beta::DeleteDeploymentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DeleteDeploymentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.DeleteDeployment.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The etag of the deployment. If an etag is provided and does not match the current etag of the deployment, deletion will be blocked and an ABORTED error will be returned.
958 959 960 961 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 958 class DeleteDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the deployment to delete.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}.
958 959 960 961 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 958 class DeleteDeploymentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |