Class: Google::Cloud::Ces::V1beta::DeleteEvaluationDatasetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DeleteEvaluationDatasetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Request message for EvaluationService.DeleteEvaluationDataset.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the evaluation dataset. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the evaluation dataset, deletion will be blocked and an ABORTED error will be returned.
331 332 333 334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 331 class DeleteEvaluationDatasetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the evaluation dataset to delete.
331 332 333 334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 331 class DeleteEvaluationDatasetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |