Class: Google::Cloud::Ces::V1beta::DeleteExampleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::DeleteExampleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.DeleteExample.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The current etag of the example. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the example, deletion will be blocked and an ABORTED error will be returned.
517 518 519 520 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 517 class DeleteExampleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the example to delete.
517 518 519 520 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 517 class DeleteExampleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |