Class: Google::Cloud::Ces::V1beta::Evaluation::GoldenTurn
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Evaluation::GoldenTurn
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
A golden turn defines a single turn in a golden conversation.
Instance Attribute Summary collapse
-
#hallucination_metric_behavior_override ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Optional.
-
#root_span ⇒ ::Google::Cloud::Ces::V1beta::Span
Optional.
-
#steps ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::Step>
Required.
-
#turn_level_metrics_thresholds_override ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds
Optional.
Instance Attribute Details
#hallucination_metric_behavior_override ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Returns Optional. Override for turn-level hallucination metric behavior.
325 326 327 328 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 325 class GoldenTurn include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#root_span ⇒ ::Google::Cloud::Ces::V1beta::Span
Returns Optional. The root span of the golden turn for processing and maintaining audio information. The uri for the audio must contain audio saved in 16Khz sample rate.
325 326 327 328 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 325 class GoldenTurn include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#steps ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::Step>
Returns Required. The steps required to replay a golden conversation.
325 326 327 328 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 325 class GoldenTurn include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#turn_level_metrics_thresholds_override ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds
Returns Optional. Overrides for turn-level metric thresholds.
325 326 327 328 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 325 class GoldenTurn include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |