Class: Google::Cloud::Ces::V1beta::Evaluation::GoldenTurn

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

A golden turn defines a single turn in a golden conversation.

Instance Attribute Summary collapse

Instance Attribute Details

#root_span::Google::Cloud::Ces::V1beta::Span

Returns Optional. The root span of the golden turn for processing and maintaining audio information.

Returns:



291
292
293
294
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 291

class GoldenTurn
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#steps::Array<::Google::Cloud::Ces::V1beta::Evaluation::Step>

Returns Required. The steps required to replay a golden conversation.

Returns:



291
292
293
294
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 291

class GoldenTurn
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end