Class: Google::Cloud::Ces::V1beta::Evaluation::Scenario
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Evaluation::Scenario
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The config for a scenario
Defined Under Namespace
Modules: TaskCompletionBehavior, UserGoalBehavior Classes: UserFact
Instance Attribute Summary collapse
-
#evaluation_expectations ⇒ ::Array<::String>
Optional.
-
#max_turns ⇒ ::Integer
Optional.
-
#rubrics ⇒ ::Array<::String>
Required.
-
#scenario_execution_mode ⇒ ::Google::Cloud::Ces::V1beta::EvaluationSettings::ScenarioExecutionMode
Optional.
-
#scenario_expectations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation>
Required.
-
#task ⇒ ::String
Required.
-
#task_completion_behavior ⇒ ::Google::Cloud::Ces::V1beta::Evaluation::Scenario::TaskCompletionBehavior
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#user_facts ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::Scenario::UserFact>
Optional.
-
#user_goal_behavior ⇒ ::Google::Cloud::Ces::V1beta::Evaluation::Scenario::UserGoalBehavior
Optional.
-
#variable_overrides ⇒ ::Google::Protobuf::Struct
Optional.
Instance Attribute Details
#evaluation_expectations ⇒ ::Array<::String>
Returns Optional. The evaluation expectations to evaluate the conversation
produced by the simulation against. Format:
projects/{project}/locations/{location}/apps/{app}/evaluationExpectations/{evaluationExpectation}.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#max_turns ⇒ ::Integer
Returns Optional. The maximum number of turns to simulate. The maximum allowed value is 100. The default value is 100.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#rubrics ⇒ ::Array<::String>
Returns Required. The rubrics to score the scenario against.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#scenario_execution_mode ⇒ ::Google::Cloud::Ces::V1beta::EvaluationSettings::ScenarioExecutionMode
Returns Optional. The execution mode for scenario evaluations.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#scenario_expectations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation>
Returns Required. The ScenarioExpectations to evaluate the conversation produced by the user simulation.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#task ⇒ ::String
Returns Required. The task to be targeted by the scenario.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#task_completion_behavior ⇒ ::Google::Cloud::Ces::V1beta::Evaluation::Scenario::TaskCompletionBehavior
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated. Use user_goal_behavior instead.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#user_facts ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::Scenario::UserFact>
Returns Optional. The user facts to be used by the scenario.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#user_goal_behavior ⇒ ::Google::Cloud::Ces::V1beta::Evaluation::Scenario::UserGoalBehavior
Returns Optional. The expected behavior of the user goal.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |
#variable_overrides ⇒ ::Google::Protobuf::Struct
Returns Optional. Variables / Session Parameters as context for the session, keyed by variable names. Members of this struct will override any default values set by the system.
Note, these are different from user facts, which are facts known to the user. Variables are parameters known to the agent: i.e. MDN (phone number) passed by the telephony system.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 419 class Scenario include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Facts about the user as a key value pair. # @!attribute [rw] name # @return [::String] # Required. The name of the user fact. # @!attribute [rw] value # @return [::String] # Required. The value of the user fact. class UserFact include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The expected behavior of the user task. This is used to determine whether # the scenario is successful. module TaskCompletionBehavior # Behavior unspecified. Will default to TASK_SATISFIED. TASK_COMPLETION_BEHAVIOR_UNSPECIFIED = 0 # The user task should be completed successfully. TASK_SATISFIED = 1 # The user task should be rejected. TASK_REJECTED = 2 end # The expected behavior of the user goal. This is used to determine whether # the scenario is successful. module UserGoalBehavior # Behavior unspecified. Will default to USER_GOAL_SATISFIED. USER_GOAL_BEHAVIOR_UNSPECIFIED = 0 # The user goal should be completed successfully. USER_GOAL_SATISFIED = 1 # The user goal should be rejected. USER_GOAL_REJECTED = 2 # Ignore the user goal status. USER_GOAL_IGNORED = 3 end end |