Class: Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The expectation to evaluate the conversation produced by the simulation.

Defined Under Namespace

Classes: ToolExpectation

Instance Attribute Summary collapse

Instance Attribute Details

#agent_response::Google::Cloud::Ces::V1beta::Message

Returns Optional. The agent response to be evaluated.

Note: The following fields are mutually exclusive: agent_response, tool_expectation. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::Message)

    Optional. The agent response to be evaluated.

    Note: The following fields are mutually exclusive: agent_response, tool_expectation. If a field in that set is populated, all other fields in the set will automatically be cleared.



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 321

class ScenarioExpectation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The tool call and response pair to be evaluated.
  # @!attribute [rw] expected_tool_call
  #   @return [::Google::Cloud::Ces::V1beta::ToolCall]
  #     Required. The expected tool call, with the parameters of interest
  #     specified. Any parameters not specified will be hallucinated by the
  #     LLM.
  # @!attribute [rw] mock_tool_response
  #   @return [::Google::Cloud::Ces::V1beta::ToolResponse]
  #     Required. The tool response to mock, with the parameters of interest
  #     specified. Any parameters not specified will be hallucinated by the
  #     LLM.
  class ToolExpectation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tool_expectation::Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation::ToolExpectation

Returns Optional. The tool call and response pair to be evaluated.

Note: The following fields are mutually exclusive: tool_expectation, agent_response. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 321

class ScenarioExpectation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The tool call and response pair to be evaluated.
  # @!attribute [rw] expected_tool_call
  #   @return [::Google::Cloud::Ces::V1beta::ToolCall]
  #     Required. The expected tool call, with the parameters of interest
  #     specified. Any parameters not specified will be hallucinated by the
  #     LLM.
  # @!attribute [rw] mock_tool_response
  #   @return [::Google::Cloud::Ces::V1beta::ToolResponse]
  #     Required. The tool response to mock, with the parameters of interest
  #     specified. Any parameters not specified will be hallucinated by the
  #     LLM.
  class ToolExpectation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end