Class: Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation::ToolExpectation
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation::ToolExpectation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The tool call and response pair to be evaluated.
Instance Attribute Summary collapse
-
#expected_tool_call ⇒ ::Google::Cloud::Ces::V1beta::ToolCall
Required.
-
#mock_tool_response ⇒ ::Google::Cloud::Ces::V1beta::ToolResponse
Required.
Instance Attribute Details
#expected_tool_call ⇒ ::Google::Cloud::Ces::V1beta::ToolCall
Returns Required. The expected tool call, with the parameters of interest specified. Any parameters not specified will be hallucinated by the LLM.
336 337 338 339 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 336 class ToolExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mock_tool_response ⇒ ::Google::Cloud::Ces::V1beta::ToolResponse
Returns Required. The tool response to mock, with the parameters of interest specified. Any parameters not specified will be hallucinated by the LLM.
336 337 338 339 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 336 class ToolExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |