Class: Google::Cloud::Ces::V1beta::EvaluationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

EvaluationConfig configures settings for running the evaluation.

Defined Under Namespace

Modules: EvaluationChannel

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_channel::Google::Cloud::Ces::V1beta::EvaluationConfig::EvaluationChannel

Returns Optional. The channel to evaluate.

Returns:



1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1352

class EvaluationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The channel to evaluate.
  module EvaluationChannel
    # Unspecified evaluation channel.
    EVALUATION_CHANNEL_UNSPECIFIED = 0

    # Text-only evaluation channel.
    TEXT = 1

    # Audio evaluation channel.
    AUDIO = 2
  end
end

#input_audio_config::Google::Cloud::Ces::V1beta::InputAudioConfig

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Configuration for processing the input audio.

Returns:



1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1352

class EvaluationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The channel to evaluate.
  module EvaluationChannel
    # Unspecified evaluation channel.
    EVALUATION_CHANNEL_UNSPECIFIED = 0

    # Text-only evaluation channel.
    TEXT = 1

    # Audio evaluation channel.
    AUDIO = 2
  end
end

#output_audio_config::Google::Cloud::Ces::V1beta::OutputAudioConfig

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Optional. Configuration for generating the output audio.

Returns:



1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1352

class EvaluationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The channel to evaluate.
  module EvaluationChannel
    # Unspecified evaluation channel.
    EVALUATION_CHANNEL_UNSPECIFIED = 0

    # Text-only evaluation channel.
    TEXT = 1

    # Audio evaluation channel.
    AUDIO = 2
  end
end

#tool_call_behaviour::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour

Returns Optional. Specifies whether the evaluation should use real tool calls or fake tools.

Returns:



1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1352

class EvaluationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The channel to evaluate.
  module EvaluationChannel
    # Unspecified evaluation channel.
    EVALUATION_CHANNEL_UNSPECIFIED = 0

    # Text-only evaluation channel.
    TEXT = 1

    # Audio evaluation channel.
    AUDIO = 2
  end
end