Class: Google::Cloud::Ces::V1beta::EvaluationExpectation
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationExpectation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
An evaluation expectation represents a specific criteria to evaluate against.
Defined Under Namespace
Classes: LlmCriteria
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#etag ⇒ ::String
readonly
Output only.
-
#llm_criteria ⇒ ::Google::Cloud::Ces::V1beta::EvaluationExpectation::LlmCriteria
Optional.
-
#name ⇒ ::String
Identifier.
-
#tags ⇒ ::Array<::String>
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the evaluation expectation was created.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Required. User-defined display name. Must be unique within the app.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String (readonly)
Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#llm_criteria ⇒ ::Google::Cloud::Ces::V1beta::EvaluationExpectation::LlmCriteria
Returns Optional. Evaluation criteria based on an LLM prompt.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The unique identifier of this evaluation expectation.
Format:
projects/{project}/locations/{location}/apps/{app}/evaluationExpectations/{evaluation_expectation}.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tags ⇒ ::Array<::String>
Returns Optional. User-defined tags for expectations. Can be used to filter expectations.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the evaluation expectation was last updated.
1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1322 class EvaluationExpectation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for LLM-based evaluation criteria. # @!attribute [rw] prompt # @return [::String] # Required. The prompt/instructions provided to the LLM judge. class LlmCriteria include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |