Class: Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::ExpectationsMetMetricsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::ExpectationsMetMetricsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb
Overview
Configuration for the expectation level metrics for the evaluation.
To disable the metric, set the message but do not set the
enable_expectations_met_metrics field to true (or explicitly set it to
false). To unset the configuration and fallback to the default behavior,
omit the message entirely.
Instance Attribute Summary collapse
Instance Attribute Details
#enable_expectations_met_metrics ⇒ ::Boolean
Returns Optional. Whether to calculate the expectation level metrics for the evaluation.
99 100 101 102 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb', line 99 class ExpectationsMetMetricsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |