Class: Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::HallucinationMetricsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::HallucinationMetricsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb
Overview
Configuration for the hallucination metrics for the evaluation.
To disable the metric, set the message but do not set the
enable_hallucination_metrics field to true (or explicitly set it to
false). To unset the configuration and fallback to the default behavior,
omit the message entirely.
Instance Attribute Summary collapse
Instance Attribute Details
#enable_hallucination_metrics ⇒ ::Boolean
Returns Optional. Whether to calculate hallucination metrics for the evaluation.
71 72 73 74 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb', line 71 class HallucinationMetricsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |