Class: Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::SemanticSimilarityMetricsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::SemanticSimilarityMetricsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb
Overview
Configuration for similarity metrics for the evaluation.
To disable the metric, set the message but do not set the
enable_semantic_similarity_metrics field to true (or explicitly set it to
false). To unset the configuration and fallback to the default behavior,
omit the message entirely.
Instance Attribute Summary collapse
Instance Attribute Details
#enable_semantic_similarity_metrics ⇒ ::Boolean
Returns Optional. Whether to calculate semantic similarity metrics for the evaluation.
44 45 46 47 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb', line 44 class SemanticSimilarityMetricsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |