Class: Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::ToolCorrectnessMetricsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::ToolCorrectnessMetricsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb
Overview
Configuration for correctness metrics for the evaluation.
To disable the metric, set the message but do not set the
enable_tool_correctness_metrics field to true (or explicitly set it to
false). To unset the configuration and fallback to the default behavior,
omit the message entirely.
Instance Attribute Summary collapse
Instance Attribute Details
#enable_tool_correctness_metrics ⇒ ::Boolean
Returns Optional. Whether to calculate tool correctness metrics for the evaluation.
58 59 60 61 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb', line 58 class ToolCorrectnessMetricsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |