Class: Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::UserGoalMetMetricsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsConfig::UserGoalMetMetricsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb
Overview
Configuration for the user goal met metrics for the evaluation.
To disable the metric, set the message but do not set the
enable_user_goal_met_metrics field to true (or explicitly set it to
false). To unset the configuration and fallback to the default behavior,
omit the message entirely.
Instance Attribute Summary collapse
Instance Attribute Details
#enable_user_goal_met_metrics ⇒ ::Boolean
Returns Optional. Whether to calculate the user goal met metrics for the evaluation.
85 86 87 88 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_metrics_config.rb', line 85 class UserGoalMetMetricsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |