Class: Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Threshold settings for metrics in an Evaluation.
Defined Under Namespace
Modules: HallucinationMetricBehavior Classes: GoldenEvaluationMetricsThresholds, ToolMatchingSettings
Instance Attribute Summary collapse
-
#golden_evaluation_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds
Optional.
-
#golden_hallucination_metric_behavior ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Optional.
-
#hallucination_metric_behavior ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#scenario_hallucination_metric_behavior ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Optional.
Instance Attribute Details
#golden_evaluation_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds
Returns Optional. The golden evaluation metrics thresholds.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 501 class EvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for golden evaluations. # @!attribute [rw] turn_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds] # Optional. The turn level metrics thresholds. # @!attribute [rw] expectation_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds] # Optional. The expectation level metrics thresholds. # @!attribute [rw] tool_matching_settings # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings] # Optional. The tool matching settings. An # extra tool call is a tool call that is present in the execution but does # not match any tool call in the golden expectation. class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Settings for matching tool calls. # @!attribute [rw] extra_tool_call_behavior # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior] # Optional. Behavior for extra tool calls. # Defaults to FAIL. class ToolMatchingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the behavior when an extra tool call is encountered. An extra # tool call is a tool call that is present in the execution but does not # match any tool call in the golden expectation. module ExtraToolCallBehavior # Unspecified behavior. Defaults to FAIL. EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Fail the evaluation if an extra tool call is encountered. FAIL = 1 # Allow the extra tool call. ALLOW = 2 end end # The hallucination metric behavior. Regardless of the behavior, the metric # will always be calculated. The difference is that when disabled, the # metric is not used to calculate the overall evaluation score. module HallucinationMetricBehavior # Unspecified hallucination metric behavior. HALLUCINATION_METRIC_BEHAVIOR_UNSPECIFIED = 0 # Disable hallucination metric. DISABLED = 1 # Enable hallucination metric. ENABLED = 2 end end |
#golden_hallucination_metric_behavior ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Returns Optional. The hallucination metric behavior for golden evaluations.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 501 class EvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for golden evaluations. # @!attribute [rw] turn_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds] # Optional. The turn level metrics thresholds. # @!attribute [rw] expectation_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds] # Optional. The expectation level metrics thresholds. # @!attribute [rw] tool_matching_settings # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings] # Optional. The tool matching settings. An # extra tool call is a tool call that is present in the execution but does # not match any tool call in the golden expectation. class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Settings for matching tool calls. # @!attribute [rw] extra_tool_call_behavior # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior] # Optional. Behavior for extra tool calls. # Defaults to FAIL. class ToolMatchingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the behavior when an extra tool call is encountered. An extra # tool call is a tool call that is present in the execution but does not # match any tool call in the golden expectation. module ExtraToolCallBehavior # Unspecified behavior. Defaults to FAIL. EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Fail the evaluation if an extra tool call is encountered. FAIL = 1 # Allow the extra tool call. ALLOW = 2 end end # The hallucination metric behavior. Regardless of the behavior, the metric # will always be calculated. The difference is that when disabled, the # metric is not used to calculate the overall evaluation score. module HallucinationMetricBehavior # Unspecified hallucination metric behavior. HALLUCINATION_METRIC_BEHAVIOR_UNSPECIFIED = 0 # Disable hallucination metric. DISABLED = 1 # Enable hallucination metric. ENABLED = 2 end end |
#hallucination_metric_behavior ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated: Use golden_hallucination_metric_behavior instead.
The hallucination metric behavior is currently used for golden evaluations.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 501 class EvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for golden evaluations. # @!attribute [rw] turn_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds] # Optional. The turn level metrics thresholds. # @!attribute [rw] expectation_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds] # Optional. The expectation level metrics thresholds. # @!attribute [rw] tool_matching_settings # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings] # Optional. The tool matching settings. An # extra tool call is a tool call that is present in the execution but does # not match any tool call in the golden expectation. class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Settings for matching tool calls. # @!attribute [rw] extra_tool_call_behavior # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior] # Optional. Behavior for extra tool calls. # Defaults to FAIL. class ToolMatchingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the behavior when an extra tool call is encountered. An extra # tool call is a tool call that is present in the execution but does not # match any tool call in the golden expectation. module ExtraToolCallBehavior # Unspecified behavior. Defaults to FAIL. EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Fail the evaluation if an extra tool call is encountered. FAIL = 1 # Allow the extra tool call. ALLOW = 2 end end # The hallucination metric behavior. Regardless of the behavior, the metric # will always be calculated. The difference is that when disabled, the # metric is not used to calculate the overall evaluation score. module HallucinationMetricBehavior # Unspecified hallucination metric behavior. HALLUCINATION_METRIC_BEHAVIOR_UNSPECIFIED = 0 # Disable hallucination metric. DISABLED = 1 # Enable hallucination metric. ENABLED = 2 end end |
#scenario_hallucination_metric_behavior ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::HallucinationMetricBehavior
Returns Optional. The hallucination metric behavior for scenario evaluations.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 501 class EvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Settings for golden evaluations. # @!attribute [rw] turn_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds] # Optional. The turn level metrics thresholds. # @!attribute [rw] expectation_level_metrics_thresholds # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds] # Optional. The expectation level metrics thresholds. # @!attribute [rw] tool_matching_settings # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings] # Optional. The tool matching settings. An # extra tool call is a tool call that is present in the execution but does # not match any tool call in the golden expectation. class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Settings for matching tool calls. # @!attribute [rw] extra_tool_call_behavior # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings::ExtraToolCallBehavior] # Optional. Behavior for extra tool calls. # Defaults to FAIL. class ToolMatchingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines the behavior when an extra tool call is encountered. An extra # tool call is a tool call that is present in the execution but does not # match any tool call in the golden expectation. module ExtraToolCallBehavior # Unspecified behavior. Defaults to FAIL. EXTRA_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Fail the evaluation if an extra tool call is encountered. FAIL = 1 # Allow the extra tool call. ALLOW = 2 end end # The hallucination metric behavior. Regardless of the behavior, the metric # will always be calculated. The difference is that when disabled, the # metric is not used to calculate the overall evaluation score. module HallucinationMetricBehavior # Unspecified hallucination metric behavior. HALLUCINATION_METRIC_BEHAVIOR_UNSPECIFIED = 0 # Disable hallucination metric. DISABLED = 1 # Enable hallucination metric. ENABLED = 2 end end |