Class: Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Settings for golden evaluations.
Defined Under Namespace
Classes: ExpectationLevelMetricsThresholds, TurnLevelMetricsThresholds
Instance Attribute Summary collapse
-
#expectation_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds
Optional.
-
#tool_matching_settings ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings
Optional.
-
#turn_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds
Optional.
Instance Attribute Details
#expectation_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::ExpectationLevelMetricsThresholds
Returns Optional. The expectation level metrics thresholds.
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 555 class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tool_matching_settings ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::ToolMatchingSettings
Returns Optional. The tool matching settings. An extra tool call is a tool call that is present in the execution but does not match any tool call in the golden expectation.
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 555 class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#turn_level_metrics_thresholds ⇒ ::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds
Returns Optional. The turn level metrics thresholds.
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 555 class GoldenEvaluationMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Turn level metrics thresholds. # @!attribute [rw] semantic_similarity_success_threshold # @return [::Integer] # Optional. The success threshold for semantic similarity. Must be an # integer between 0 and 4. Default is >= 3. # @!attribute [rw] overall_tool_invocation_correctness_threshold # @return [::Float] # Optional. The success threshold for overall tool invocation # correctness. Must be a float between 0 and 1. Default is 1.0. # @!attribute [rw] semantic_similarity_channel # @return [::Google::Cloud::Ces::V1beta::EvaluationMetricsThresholds::GoldenEvaluationMetricsThresholds::TurnLevelMetricsThresholds::SemanticSimilarityChannel] # Optional. The semantic similarity channel to use for evaluation. class TurnLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Semantic similarity channel to use. module SemanticSimilarityChannel # Metric unspecified. Defaults to TEXT. SEMANTIC_SIMILARITY_CHANNEL_UNSPECIFIED = 0 # Use text semantic similarity. TEXT = 1 # Use audio semantic similarity. AUDIO = 2 end end # Expectation level metrics thresholds. # @!attribute [rw] tool_invocation_parameter_correctness_threshold # @return [::Float] # Optional. The success threshold for individual tool invocation # parameter correctness. Must be a float between 0 and 1. Default is 1.0. class ExpectationLevelMetricsThresholds include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |