Class: Google::Cloud::Ces::V1beta::EvaluationPersona
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationPersona
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
A persona represents an end user in an evaluation.
Defined Under Namespace
Classes: SpeechConfig
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#name ⇒ ::String
Required.
-
#personality ⇒ ::String
Required.
-
#speech_config ⇒ ::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig
Optional.
Instance Attribute Details
#description ⇒ ::String
Returns Optional. The description of the persona.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 793 class EvaluationPersona include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Text-to-Speech generation. # @!attribute [rw] speaking_rate # @return [::Float] # Optional. The speaking rate. 1.0 is normal. # Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). # Useful for testing how the agent handles fast talkers. # @!attribute [rw] environment # @return [::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment] # Optional. The simulated audio environment. # @!attribute [rw] voice_id # @return [::String] # Optional. The specific voice identifier/accent to use. # Example: "en-US-Wavenet-D" or "en-GB-Standard-A" class SpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Simulated audio environment. module BackgroundEnvironment # Background environment unspecified. BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0 # Call center environment. CALL_CENTER = 3 # Traffic noise environment. TRAFFIC = 4 # Kids noise environment. KIDS_NOISE = 5 # Cafe environment. CAFE = 6 end end end |
#display_name ⇒ ::String
Returns Required. The display name of the persona. Unique within an app.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 793 class EvaluationPersona include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Text-to-Speech generation. # @!attribute [rw] speaking_rate # @return [::Float] # Optional. The speaking rate. 1.0 is normal. # Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). # Useful for testing how the agent handles fast talkers. # @!attribute [rw] environment # @return [::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment] # Optional. The simulated audio environment. # @!attribute [rw] voice_id # @return [::String] # Optional. The specific voice identifier/accent to use. # Example: "en-US-Wavenet-D" or "en-GB-Standard-A" class SpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Simulated audio environment. module BackgroundEnvironment # Background environment unspecified. BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0 # Call center environment. CALL_CENTER = 3 # Traffic noise environment. TRAFFIC = 4 # Kids noise environment. KIDS_NOISE = 5 # Cafe environment. CAFE = 6 end end end |
#name ⇒ ::String
Returns Required. The unique identifier of the persona.
Format:
projects/{project}/locations/{location}/apps/{app}/evaluationPersonas/{evaluationPersona}.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 793 class EvaluationPersona include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Text-to-Speech generation. # @!attribute [rw] speaking_rate # @return [::Float] # Optional. The speaking rate. 1.0 is normal. # Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). # Useful for testing how the agent handles fast talkers. # @!attribute [rw] environment # @return [::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment] # Optional. The simulated audio environment. # @!attribute [rw] voice_id # @return [::String] # Optional. The specific voice identifier/accent to use. # Example: "en-US-Wavenet-D" or "en-GB-Standard-A" class SpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Simulated audio environment. module BackgroundEnvironment # Background environment unspecified. BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0 # Call center environment. CALL_CENTER = 3 # Traffic noise environment. TRAFFIC = 4 # Kids noise environment. KIDS_NOISE = 5 # Cafe environment. CAFE = 6 end end end |
#personality ⇒ ::String
Returns Required. An instruction for the agent on how to behave in the evaluation.
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 793 class EvaluationPersona include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Text-to-Speech generation. # @!attribute [rw] speaking_rate # @return [::Float] # Optional. The speaking rate. 1.0 is normal. # Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). # Useful for testing how the agent handles fast talkers. # @!attribute [rw] environment # @return [::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment] # Optional. The simulated audio environment. # @!attribute [rw] voice_id # @return [::String] # Optional. The specific voice identifier/accent to use. # Example: "en-US-Wavenet-D" or "en-GB-Standard-A" class SpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Simulated audio environment. module BackgroundEnvironment # Background environment unspecified. BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0 # Call center environment. CALL_CENTER = 3 # Traffic noise environment. TRAFFIC = 4 # Kids noise environment. KIDS_NOISE = 5 # Cafe environment. CAFE = 6 end end end |
#speech_config ⇒ ::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig
Returns Optional. Configuration for how the persona sounds (TTS settings).
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 793 class EvaluationPersona include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for Text-to-Speech generation. # @!attribute [rw] speaking_rate # @return [::Float] # Optional. The speaking rate. 1.0 is normal. # Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). # Useful for testing how the agent handles fast talkers. # @!attribute [rw] environment # @return [::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment] # Optional. The simulated audio environment. # @!attribute [rw] voice_id # @return [::String] # Optional. The specific voice identifier/accent to use. # Example: "en-US-Wavenet-D" or "en-GB-Standard-A" class SpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Simulated audio environment. module BackgroundEnvironment # Background environment unspecified. BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0 # Call center environment. CALL_CENTER = 3 # Traffic noise environment. TRAFFIC = 4 # Kids noise environment. KIDS_NOISE = 5 # Cafe environment. CAFE = 6 end end end |