Class: Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Configuration for Text-to-Speech generation.

Defined Under Namespace

Modules: BackgroundEnvironment

Instance Attribute Summary collapse

Instance Attribute Details

#environment::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment

Returns Optional. The simulated audio environment.

Returns:



857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 857

class SpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Simulated audio environment.
  module BackgroundEnvironment
    # Background environment unspecified.
    BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0

    # Call center environment.
    CALL_CENTER = 3

    # Traffic noise environment.
    TRAFFIC = 4

    # Kids noise environment.
    KIDS_NOISE = 5

    # Cafe environment.
    CAFE = 6
  end
end

#speaking_rate::Float

Returns Optional. The speaking rate. 1.0 is normal. Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). Useful for testing how the agent handles fast talkers.

Returns:

  • (::Float)

    Optional. The speaking rate. 1.0 is normal. Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). Useful for testing how the agent handles fast talkers.



857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 857

class SpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Simulated audio environment.
  module BackgroundEnvironment
    # Background environment unspecified.
    BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0

    # Call center environment.
    CALL_CENTER = 3

    # Traffic noise environment.
    TRAFFIC = 4

    # Kids noise environment.
    KIDS_NOISE = 5

    # Cafe environment.
    CAFE = 6
  end
end

#voice_id::String

Returns Optional. The specific voice identifier/accent to use. Example: "en-US-Wavenet-D" or "en-GB-Standard-A".

Returns:

  • (::String)

    Optional. The specific voice identifier/accent to use. Example: "en-US-Wavenet-D" or "en-GB-Standard-A"



857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 857

class SpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Simulated audio environment.
  module BackgroundEnvironment
    # Background environment unspecified.
    BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0

    # Call center environment.
    CALL_CENTER = 3

    # Traffic noise environment.
    TRAFFIC = 4

    # Kids noise environment.
    KIDS_NOISE = 5

    # Cafe environment.
    CAFE = 6
  end
end