Class: Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Configuration for Text-to-Speech generation.

Defined Under Namespace

Modules: BackgroundEnvironment

Instance Attribute Summary collapse

Instance Attribute Details

#environment::Google::Cloud::Ces::V1beta::EvaluationPersona::SpeechConfig::BackgroundEnvironment

Returns Optional. The simulated audio environment.

Returns:



810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 810

class SpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Simulated audio environment.
  module BackgroundEnvironment
    # Background environment unspecified.
    BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0

    # Call center environment.
    CALL_CENTER = 3

    # Traffic noise environment.
    TRAFFIC = 4

    # Kids noise environment.
    KIDS_NOISE = 5

    # Cafe environment.
    CAFE = 6
  end
end

#speaking_rate::Float

Returns Optional. The speaking rate. 1.0 is normal. Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). Useful for testing how the agent handles fast talkers.

Returns:

  • (::Float)

    Optional. The speaking rate. 1.0 is normal. Lower is slower (e.g., 0.8), higher is faster (e.g., 1.5). Useful for testing how the agent handles fast talkers.



810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 810

class SpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Simulated audio environment.
  module BackgroundEnvironment
    # Background environment unspecified.
    BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0

    # Call center environment.
    CALL_CENTER = 3

    # Traffic noise environment.
    TRAFFIC = 4

    # Kids noise environment.
    KIDS_NOISE = 5

    # Cafe environment.
    CAFE = 6
  end
end

#voice_id::String

Returns Optional. The specific voice identifier/accent to use. Example: "en-US-Wavenet-D" or "en-GB-Standard-A".

Returns:

  • (::String)

    Optional. The specific voice identifier/accent to use. Example: "en-US-Wavenet-D" or "en-GB-Standard-A"



810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 810

class SpeechConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Simulated audio environment.
  module BackgroundEnvironment
    # Background environment unspecified.
    BACKGROUND_ENVIRONMENT_UNSPECIFIED = 0

    # Call center environment.
    CALL_CENTER = 3

    # Traffic noise environment.
    TRAFFIC = 4

    # Kids noise environment.
    KIDS_NOISE = 5

    # Cafe environment.
    CAFE = 6
  end
end