Class: Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

Specifies the expectation and the result of that expectation.

Defined Under Namespace

Classes: ToolInvocationResult

Instance Attribute Summary collapse

Instance Attribute Details

#expectation::Google::Cloud::Ces::V1beta::Evaluation::GoldenExpectation (readonly)

Returns Output only. The expectation that was evaluated.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#observed_agent_response::Google::Cloud::Ces::V1beta::Message (readonly)

Returns Output only. The result of the agent response expectation.

Note: The following fields are mutually exclusive: observed_agent_response, observed_tool_call, observed_tool_response, observed_agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::Message)

    Output only. The result of the agent response expectation.

    Note: The following fields are mutually exclusive: observed_agent_response, observed_tool_call, observed_tool_response, observed_agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#observed_agent_transfer::Google::Cloud::Ces::V1beta::AgentTransfer (readonly)

Returns Output only. The result of the agent transfer expectation.

Note: The following fields are mutually exclusive: observed_agent_transfer, observed_tool_call, observed_tool_response, observed_agent_response. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::AgentTransfer)

    Output only. The result of the agent transfer expectation.

    Note: The following fields are mutually exclusive: observed_agent_transfer, observed_tool_call, observed_tool_response, observed_agent_response. If a field in that set is populated, all other fields in the set will automatically be cleared.



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#observed_tool_call::Google::Cloud::Ces::V1beta::ToolCall (readonly)

Returns Output only. The result of the tool call expectation.

Note: The following fields are mutually exclusive: observed_tool_call, observed_tool_response, observed_agent_response, observed_agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::ToolCall)

    Output only. The result of the tool call expectation.

    Note: The following fields are mutually exclusive: observed_tool_call, observed_tool_response, observed_agent_response, observed_agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#observed_tool_response::Google::Cloud::Ces::V1beta::ToolResponse (readonly)

Returns Output only. The result of the tool response expectation.

Note: The following fields are mutually exclusive: observed_tool_response, observed_tool_call, observed_agent_response, observed_agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::ToolResponse)

    Output only. The result of the tool response expectation.

    Note: The following fields are mutually exclusive: observed_tool_response, observed_tool_call, observed_agent_response, observed_agent_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#outcome::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome (readonly)

Returns Output only. The outcome of the expectation.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#semantic_similarity_result::Google::Cloud::Ces::V1beta::EvaluationResult::SemanticSimilarityResult (readonly)

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Output only. The result of the semantic similarity check.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tool_invocation_result::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome::ToolInvocationResult (readonly)

Returns Output only. The result of the tool invocation check.

Returns:



587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 587

class GoldenExpectationOutcome
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The result of the tool invocation check.
  # @!attribute [r] parameter_correctness_score
  #   @return [::Float]
  #     Output only. The tool invocation parameter correctness score. This
  #     indicates the percent of parameters from the expected tool call that
  #     were also present in the actual tool call.
  # @!attribute [r] outcome
  #   @return [::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome]
  #     Output only. The outcome of the tool invocation check. This is
  #     determined by comparing the parameter_correctness_score to the
  #     threshold. If the score is equal to or above the threshold, the outcome
  #     will be PASS. Otherwise, the outcome will be FAIL.
  # @!attribute [r] explanation
  #   @return [::String]
  #     Output only. A free text explanation for the tool invocation result.
  class ToolInvocationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end