Class: Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome::ToolInvocationResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

The result of the tool invocation check.

Instance Attribute Summary collapse

Instance Attribute Details

#explanation::String (readonly)

Returns Output only. A free text explanation for the tool invocation result.

Returns:

  • (::String)

    Output only. A free text explanation for the tool invocation result.



606
607
608
609
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 606

class ToolInvocationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#outcome::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome (readonly)

Returns Output only. The outcome of the tool invocation check. This is determined by comparing the parameter_correctness_score to the threshold. If the score is equal to or above the threshold, the outcome will be PASS. Otherwise, the outcome will be FAIL.

Returns:

  • (::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome)

    Output only. The outcome of the tool invocation check. This is determined by comparing the parameter_correctness_score to the threshold. If the score is equal to or above the threshold, the outcome will be PASS. Otherwise, the outcome will be FAIL.



606
607
608
609
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 606

class ToolInvocationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parameter_correctness_score::Float (readonly)

Returns Output only. The tool invocation parameter correctness score. This indicates the percent of parameters from the expected tool call that were also present in the actual tool call.

Returns:

  • (::Float)

    Output only. The tool invocation parameter correctness score. This indicates the percent of parameters from the expected tool call that were also present in the actual tool call.



606
607
608
609
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 606

class ToolInvocationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end