Class: Google::Cloud::Ces::V1beta::EvaluationResult::GoldenResult
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationResult::GoldenResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The result of a golden evaluation.
Defined Under Namespace
Classes: TurnReplayResult
Instance Attribute Summary collapse
-
#evaluation_expectation_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::EvaluationExpectationResult>
readonly
Output only.
-
#turn_replay_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenResult::TurnReplayResult>
readonly
Output only.
Instance Attribute Details
#evaluation_expectation_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::EvaluationExpectationResult> (readonly)
Returns Output only. The results of the evaluation expectations.
639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 639 class GoldenResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of running a single turn of the golden conversation. # @!attribute [r] conversation # @return [::String] # Output only. The conversation that was generated for this turn. # @!attribute [r] expectation_outcome # @return [::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome>] # Output only. The outcome of each expectation. # @!attribute [r] hallucination_result # @return [::Google::Cloud::Ces::V1beta::EvaluationResult::HallucinationResult] # Output only. The result of the hallucination check. # @!attribute [r] tool_invocation_score # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::Float] # Output only. Deprecated. Use OverallToolInvocationResult instead. # @!attribute [r] tool_ordered_invocation_score # @return [::Float] # Output only. The overall tool ordered invocation score for this turn. # This indicates the overall percent of tools from the expected turn that # were actually invoked in the expected order. # @!attribute [r] turn_latency # @return [::Google::Protobuf::Duration] # Output only. Duration of the turn. # @!attribute [r] tool_call_latencies # @return [::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ToolCallLatency>] # Output only. The latency of each tool call in the turn. # @!attribute [r] semantic_similarity_result # @return [::Google::Cloud::Ces::V1beta::EvaluationResult::SemanticSimilarityResult] # Output only. The result of the semantic similarity check. # @!attribute [r] overall_tool_invocation_result # @return [::Google::Cloud::Ces::V1beta::EvaluationResult::OverallToolInvocationResult] # Output only. The result of the overall tool invocation check. # @!attribute [r] error_info # @return [::Google::Cloud::Ces::V1beta::EvaluationErrorInfo] # Output only. Information about the error that occurred during this # turn. # @!attribute [r] span_latencies # @return [::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency>] # Output only. The latency of spans in the turn. class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#turn_replay_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenResult::TurnReplayResult> (readonly)
Returns Output only. The result of running each turn of the golden conversation.
639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 639 class GoldenResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of running a single turn of the golden conversation. # @!attribute [r] conversation # @return [::String] # Output only. The conversation that was generated for this turn. # @!attribute [r] expectation_outcome # @return [::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome>] # Output only. The outcome of each expectation. # @!attribute [r] hallucination_result # @return [::Google::Cloud::Ces::V1beta::EvaluationResult::HallucinationResult] # Output only. The result of the hallucination check. # @!attribute [r] tool_invocation_score # @deprecated This field is deprecated and may be removed in the next major version update. # @return [::Float] # Output only. Deprecated. Use OverallToolInvocationResult instead. # @!attribute [r] tool_ordered_invocation_score # @return [::Float] # Output only. The overall tool ordered invocation score for this turn. # This indicates the overall percent of tools from the expected turn that # were actually invoked in the expected order. # @!attribute [r] turn_latency # @return [::Google::Protobuf::Duration] # Output only. Duration of the turn. # @!attribute [r] tool_call_latencies # @return [::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ToolCallLatency>] # Output only. The latency of each tool call in the turn. # @!attribute [r] semantic_similarity_result # @return [::Google::Cloud::Ces::V1beta::EvaluationResult::SemanticSimilarityResult] # Output only. The result of the semantic similarity check. # @!attribute [r] overall_tool_invocation_result # @return [::Google::Cloud::Ces::V1beta::EvaluationResult::OverallToolInvocationResult] # Output only. The result of the overall tool invocation check. # @!attribute [r] error_info # @return [::Google::Cloud::Ces::V1beta::EvaluationErrorInfo] # Output only. Information about the error that occurred during this # turn. # @!attribute [r] span_latencies # @return [::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency>] # Output only. The latency of spans in the turn. class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |