Class: Google::Cloud::Ces::V1beta::EvaluationResult::GoldenResult::TurnReplayResult
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationResult::GoldenResult::TurnReplayResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The result of running a single turn of the golden conversation.
Instance Attribute Summary collapse
-
#conversation ⇒ ::String
readonly
Output only.
-
#error_info ⇒ ::Google::Cloud::Ces::V1beta::EvaluationErrorInfo
readonly
Output only.
-
#expectation_outcome ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome>
readonly
Output only.
-
#hallucination_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::HallucinationResult
readonly
Output only.
-
#overall_tool_invocation_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::OverallToolInvocationResult
readonly
Output only.
-
#semantic_similarity_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::SemanticSimilarityResult
readonly
Output only.
-
#span_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency>
readonly
Output only.
-
#tool_call_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ToolCallLatency>
readonly
Output only.
-
#tool_invocation_score ⇒ ::Float
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#tool_ordered_invocation_score ⇒ ::Float
readonly
Output only.
-
#turn_latency ⇒ ::Google::Protobuf::Duration
readonly
Output only.
Instance Attribute Details
#conversation ⇒ ::String (readonly)
Returns Output only. The conversation that was generated for this turn.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_info ⇒ ::Google::Cloud::Ces::V1beta::EvaluationErrorInfo (readonly)
Returns Output only. Information about the error that occurred during this turn.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expectation_outcome ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::GoldenExpectationOutcome> (readonly)
Returns Output only. The outcome of each expectation.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hallucination_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::HallucinationResult (readonly)
Returns Output only. The result of the hallucination check.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#overall_tool_invocation_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::OverallToolInvocationResult (readonly)
Returns Output only. The result of the overall tool invocation check.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#semantic_similarity_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::SemanticSimilarityResult (readonly)
Returns Output only. The result of the semantic similarity check.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#span_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency> (readonly)
Returns Output only. The latency of spans in the turn.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_call_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ToolCallLatency> (readonly)
Returns Output only. The latency of each tool call in the turn.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_invocation_score ⇒ ::Float (readonly)
This field is deprecated and may be removed in the next major version update.
Returns Output only. Deprecated. Use OverallToolInvocationResult instead.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_ordered_invocation_score ⇒ ::Float (readonly)
Returns Output only. The overall tool ordered invocation score for this turn. This indicates the overall percent of tools from the expected turn that were actually invoked in the expected order.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#turn_latency ⇒ ::Google::Protobuf::Duration (readonly)
Returns Output only. Duration of the turn.
681 682 683 684 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 681 class TurnReplayResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |