Module: Google::Cloud::Ces::V1beta::EvaluationResult::Outcome
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The outcome of the evaluation or expectation.
Constant Summary collapse
- OUTCOME_UNSPECIFIED =
Evaluation outcome is not specified.
0- PASS =
Evaluation/Expectation passed. In the case of an evaluation, this means that all expectations were met.
1- FAIL =
Evaluation/Expectation failed. In the case of an evaluation, this means that at least one expectation was not met.
2- SKIPPED =
Evaluation/Expectation was skipped.
3