Class: Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioExpectationOutcome
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioExpectationOutcome
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The outcome of a scenario expectation.
Defined Under Namespace
Classes: ObservedToolCall
Instance Attribute Summary collapse
-
#expectation ⇒ ::Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation
readonly
Output only.
-
#observed_agent_response ⇒ ::Google::Cloud::Ces::V1beta::Message
readonly
Output only.
-
#observed_tool_call ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioExpectationOutcome::ObservedToolCall
readonly
Output only.
-
#outcome ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome
readonly
Output only.
Instance Attribute Details
#expectation ⇒ ::Google::Cloud::Ces::V1beta::Evaluation::ScenarioExpectation (readonly)
Returns Output only. The expectation that was evaluated.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 764 class ScenarioExpectationOutcome include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The observed tool call and response. # @!attribute [r] tool_call # @return [::Google::Cloud::Ces::V1beta::ToolCall] # Output only. The observed tool call. # @!attribute [r] tool_response # @return [::Google::Cloud::Ces::V1beta::ToolResponse] # Output only. The observed tool response. class ObservedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#observed_agent_response ⇒ ::Google::Cloud::Ces::V1beta::Message (readonly)
Returns Output only. The observed agent response.
Note: The following fields are mutually exclusive: observed_agent_response, observed_tool_call. If a field in that set is populated, all other fields in the set will automatically be cleared.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 764 class ScenarioExpectationOutcome include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The observed tool call and response. # @!attribute [r] tool_call # @return [::Google::Cloud::Ces::V1beta::ToolCall] # Output only. The observed tool call. # @!attribute [r] tool_response # @return [::Google::Cloud::Ces::V1beta::ToolResponse] # Output only. The observed tool response. class ObservedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#observed_tool_call ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioExpectationOutcome::ObservedToolCall (readonly)
Returns Output only. The observed tool call.
Note: The following fields are mutually exclusive: observed_tool_call, observed_agent_response. If a field in that set is populated, all other fields in the set will automatically be cleared.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 764 class ScenarioExpectationOutcome include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The observed tool call and response. # @!attribute [r] tool_call # @return [::Google::Cloud::Ces::V1beta::ToolCall] # Output only. The observed tool call. # @!attribute [r] tool_response # @return [::Google::Cloud::Ces::V1beta::ToolResponse] # Output only. The observed tool response. class ObservedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#outcome ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::Outcome (readonly)
Returns Output only. The outcome of the ScenarioExpectation.
764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 764 class ScenarioExpectationOutcome include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The observed tool call and response. # @!attribute [r] tool_call # @return [::Google::Cloud::Ces::V1beta::ToolCall] # Output only. The observed tool call. # @!attribute [r] tool_response # @return [::Google::Cloud::Ces::V1beta::ToolResponse] # Output only. The observed tool response. class ObservedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |