Class: Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioResult
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The outcome of a scenario evaluation.
Instance Attribute Summary collapse
-
#all_expectations_satisfied ⇒ ::Boolean
readonly
Output only.
-
#conversation ⇒ ::String
readonly
Output only.
-
#evaluation_expectation_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::EvaluationExpectationResult>
readonly
Output only.
-
#expectation_outcomes ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioExpectationOutcome>
readonly
Output only.
-
#hallucination_result ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::HallucinationResult>
readonly
Output only.
-
#rubric_outcomes ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioRubricOutcome>
readonly
Output only.
-
#span_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency>
readonly
Output only.
-
#task ⇒ ::String
readonly
Output only.
-
#task_completed ⇒ ::Boolean
readonly
Output only.
-
#task_completion_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::TaskCompletionResult
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#tool_call_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ToolCallLatency>
readonly
Output only.
-
#user_facts ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::Scenario::UserFact>
readonly
Output only.
-
#user_goal_satisfaction_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::UserGoalSatisfactionResult
readonly
Output only.
Instance Attribute Details
#all_expectations_satisfied ⇒ ::Boolean (readonly)
Returns Output only. Whether all expectations were satisfied for this turn.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#conversation ⇒ ::String (readonly)
Returns Output only. The conversation that was generated in the scenario.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_expectation_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::EvaluationExpectationResult> (readonly)
Returns Output only. The results of the evaluation expectations.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expectation_outcomes ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioExpectationOutcome> (readonly)
Returns Output only. The outcome of each expectation.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hallucination_result ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::HallucinationResult> (readonly)
Returns Output only. The result of the hallucination check. There will be one hallucination result for each turn in the conversation.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rubric_outcomes ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ScenarioRubricOutcome> (readonly)
Returns Output only. The outcome of the rubric.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#span_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency> (readonly)
Returns Output only. The latency of spans in the conversation.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#task ⇒ ::String (readonly)
Returns Output only. The task that was used when running the scenario for this result.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#task_completed ⇒ ::Boolean (readonly)
Returns Output only. Whether the task was completed for this turn. This is a composite of all expectations satisfied, no hallucinations, and user goal satisfaction.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#task_completion_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::TaskCompletionResult (readonly)
This field is deprecated and may be removed in the next major version update.
Returns Output only. The result of the task completion check.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_call_latencies ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult::ToolCallLatency> (readonly)
Returns Output only. The latency of each tool call execution in the conversation.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_facts ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation::Scenario::UserFact> (readonly)
Returns Output only. The user facts that were used by the scenario for this result.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_goal_satisfaction_result ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::UserGoalSatisfactionResult (readonly)
Returns Output only. The result of the user goal satisfaction check.
782 783 784 785 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 782 class ScenarioResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |