Class: Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
The latency of a span execution.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#callback ⇒ ::String
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#execution_latency ⇒ ::Google::Protobuf::Duration
readonly
Output only.
-
#model ⇒ ::String
readonly
Output only.
-
#resource ⇒ ::String
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#toolset ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
readonly
Output only.
-
#type ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency::Type
readonly
Output only.
Instance Attribute Details
#callback ⇒ ::String (readonly)
Returns Output only. The name of the user callback span.
Note: The following fields are mutually exclusive: callback, resource, toolset, model. If a field in that set is populated, all other fields in the set will automatically be cleared.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#display_name ⇒ ::String (readonly)
Returns Output only. The display name of the span. Applicable to tool and guardrail spans.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The end time of span.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#execution_latency ⇒ ::Google::Protobuf::Duration (readonly)
Returns Output only. The latency of span.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#model ⇒ ::String (readonly)
Returns Output only. The name of the LLM span.
Note: The following fields are mutually exclusive: model, resource, toolset, callback. If a field in that set is populated, all other fields in the set will automatically be cleared.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#resource ⇒ ::String (readonly)
Returns Output only. The resource name of the guardrail or tool spans.
Note: The following fields are mutually exclusive: resource, toolset, model, callback. If a field in that set is populated, all other fields in the set will automatically be cleared.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The start time of span.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#toolset ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool (readonly)
Returns Output only. The toolset tool identifier.
Note: The following fields are mutually exclusive: toolset, resource, model, callback. If a field in that set is populated, all other fields in the set will automatically be cleared.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |
#type ⇒ ::Google::Cloud::Ces::V1beta::EvaluationResult::SpanLatency::Type (readonly)
Returns Output only. The type of span.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 824 class SpanLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of span. # Additional values may be added in the future. module Type # Default value. This value is unused. TYPE_UNSPECIFIED = 0 # Tool call span. TOOL = 1 # User callback span. USER_CALLBACK = 2 # Guardrail span. GUARDRAIL = 3 # LLM span. LLM = 4 end end |