Class: Google::Cloud::Ces::V1beta::EvaluationSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings for evaluation.

Defined Under Namespace

Modules: ScenarioConversationInitiator, ScenarioExecutionMode

Instance Attribute Summary collapse

Instance Attribute Details

#golden_evaluation_tool_call_behaviour::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour

Returns Optional. Configures the default tool call behaviour for golden evaluations.

Returns:



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 638

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end

  # The execution mode for scenario evaluations.
  module ScenarioExecutionMode
    # Unspecified execution mode. Defaults to QUALITY_OPTIMIZED.
    SCENARIO_EXECUTION_MODE_UNSPECIFIED = 0

    # Quality optimized mode.
    QUALITY_OPTIMIZED = 1

    # Speed optimized mode.
    SPEED_OPTIMIZED = 2
  end
end

#golden_run_method::Google::Cloud::Ces::V1beta::GoldenRunMethod

Returns Optional. The default method used to run golden evaluations. This will be used if no golden_run_method is specified in the RunEvaluationRequest.

Returns:



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 638

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end

  # The execution mode for scenario evaluations.
  module ScenarioExecutionMode
    # Unspecified execution mode. Defaults to QUALITY_OPTIMIZED.
    SCENARIO_EXECUTION_MODE_UNSPECIFIED = 0

    # Quality optimized mode.
    QUALITY_OPTIMIZED = 1

    # Speed optimized mode.
    SPEED_OPTIMIZED = 2
  end
end

#metrics_config::Google::Cloud::Ces::V1beta::EvaluationMetricsConfig

Returns Optional. Configures the default metrics for evaluations.

Returns:



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 638

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end

  # The execution mode for scenario evaluations.
  module ScenarioExecutionMode
    # Unspecified execution mode. Defaults to QUALITY_OPTIMIZED.
    SCENARIO_EXECUTION_MODE_UNSPECIFIED = 0

    # Quality optimized mode.
    QUALITY_OPTIMIZED = 1

    # Speed optimized mode.
    SPEED_OPTIMIZED = 2
  end
end

#scenario_conversation_initiator::Google::Cloud::Ces::V1beta::EvaluationSettings::ScenarioConversationInitiator

Returns Optional. Who starts the conversation in a scenario evaluation.

Returns:



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 638

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end

  # The execution mode for scenario evaluations.
  module ScenarioExecutionMode
    # Unspecified execution mode. Defaults to QUALITY_OPTIMIZED.
    SCENARIO_EXECUTION_MODE_UNSPECIFIED = 0

    # Quality optimized mode.
    QUALITY_OPTIMIZED = 1

    # Speed optimized mode.
    SPEED_OPTIMIZED = 2
  end
end

#scenario_evaluation_tool_call_behaviour::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour

Returns Optional. Configures the default tool call behaviour for scenario evaluations.

Returns:



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 638

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end

  # The execution mode for scenario evaluations.
  module ScenarioExecutionMode
    # Unspecified execution mode. Defaults to QUALITY_OPTIMIZED.
    SCENARIO_EXECUTION_MODE_UNSPECIFIED = 0

    # Quality optimized mode.
    QUALITY_OPTIMIZED = 1

    # Speed optimized mode.
    SPEED_OPTIMIZED = 2
  end
end

#scenario_execution_mode::Google::Cloud::Ces::V1beta::EvaluationSettings::ScenarioExecutionMode

Returns Optional. The execution mode for scenario evaluations. If not provided, will default to QUALITY_OPTIMIZED.

Returns:



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 638

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end

  # The execution mode for scenario evaluations.
  module ScenarioExecutionMode
    # Unspecified execution mode. Defaults to QUALITY_OPTIMIZED.
    SCENARIO_EXECUTION_MODE_UNSPECIFIED = 0

    # Quality optimized mode.
    QUALITY_OPTIMIZED = 1

    # Speed optimized mode.
    SPEED_OPTIMIZED = 2
  end
end