Class: Google::Cloud::Ces::V1beta::EvaluationSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/app.rb

Overview

Settings for evaluation.

Defined Under Namespace

Modules: ScenarioConversationInitiator

Instance Attribute Summary collapse

Instance Attribute Details

#golden_evaluation_tool_call_behaviour::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour

Returns Optional. Configures the default tool call behaviour for golden evaluations.

Returns:



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 616

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end
end

#golden_run_method::Google::Cloud::Ces::V1beta::GoldenRunMethod

Returns Optional. The default method used to run golden evaluations. This will be used if no golden_run_method is specified in the RunEvaluationRequest.

Returns:



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 616

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end
end

#scenario_conversation_initiator::Google::Cloud::Ces::V1beta::EvaluationSettings::ScenarioConversationInitiator

Returns Optional. Who starts the conversation in a scenario evaluation.

Returns:



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 616

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end
end

#scenario_evaluation_tool_call_behaviour::Google::Cloud::Ces::V1beta::EvaluationToolCallBehaviour

Returns Optional. Configures the default tool call behaviour for scenario evaluations.

Returns:



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 616

class EvaluationSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Determines who starts the conversation in a scenario evaluation session.
  module ScenarioConversationInitiator
    # Unspecified. Defaults to USER.
    SCENARIO_CONVERSATION_INITIATOR_UNSPECIFIED = 0

    # The user starts the conversation.
    USER = 1

    # The agent starts the conversation.
    AGENT = 2
  end
end