Class: Google::Cloud::Ces::V1beta::ExecuteToolResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ExecuteToolResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/tool_service.rb
Overview
Response message for ToolService.ExecuteTool.
Instance Attribute Summary collapse
-
#response ⇒ ::Google::Protobuf::Struct
The tool execution result in JSON object format.
-
#tool ⇒ ::String
The name of the tool that got executed.
-
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
The toolset tool that got executed.
-
#variables ⇒ ::Google::Protobuf::Struct
The variable values at the end of the tool execution.
Instance Attribute Details
#response ⇒ ::Google::Protobuf::Struct
Returns The tool execution result in JSON object format. Use "output" key to specify tool response and "error" key to specify error details (if any). If "output" and "error" keys are not specified, then whole "response" is treated as tool execution result.
91 92 93 94 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 91 class ExecuteToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String
Returns The name of the tool that got executed.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
91 92 93 94 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 91 class ExecuteToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Returns The toolset tool that got executed.
Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
91 92 93 94 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 91 class ExecuteToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variables ⇒ ::Google::Protobuf::Struct
Returns The variable values at the end of the tool execution.
91 92 93 94 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 91 class ExecuteToolResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |