Class: Google::Cloud::Ces::V1beta::ExportEvaluationResultsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ExportEvaluationResultsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Response message for [EvaluationService.ExportEvaluationResults][google.cloud.ces.v1beta.EvaluationService.ExportEvaluationResults].
Instance Attribute Summary collapse
-
#evaluation_results_content ⇒ ::String
The content of the exported Evaluation Results.
-
#evaluation_results_uri ⇒ ::String
The Google Cloud Storage URI folder where the exported Evaluation Results were written.
Instance Attribute Details
#evaluation_results_content ⇒ ::String
Returns The content of the exported Evaluation Results. This will be populated if gcs_uri was not specified in the request.
Note: The following fields are mutually exclusive: evaluation_results_content, evaluation_results_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.
982 983 984 985 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 982 class ExportEvaluationResultsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_results_uri ⇒ ::String
Returns The Google Cloud Storage URI folder where the exported Evaluation Results were written. This will be populated if gcs_uri was specified in the request.
Note: The following fields are mutually exclusive: evaluation_results_uri, evaluation_results_content. If a field in that set is populated, all other fields in the set will automatically be cleared.
982 983 984 985 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 982 class ExportEvaluationResultsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |