Class: Google::Cloud::Ces::V1beta::ExportEvaluationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ExportEvaluationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Response message for EvaluationService.ExportEvaluations.
Defined Under Namespace
Classes: FailedEvaluationsEntry
Instance Attribute Summary collapse
-
#evaluations_content ⇒ ::String
The content of the exported Evaluations.
-
#evaluations_uri ⇒ ::String
The Google Cloud Storage URI folder where the exported evaluations were written.
-
#failed_evaluations ⇒ ::Google::Protobuf::Map{::String => ::String}
readonly
Output only.
Instance Attribute Details
#evaluations_content ⇒ ::String
Returns The content of the exported Evaluations. This will be populated if gcs_uri was not specified in the request.
Note: The following fields are mutually exclusive: evaluations_content, evaluations_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.
953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 953 class ExportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FailedEvaluationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#evaluations_uri ⇒ ::String
Returns The Google Cloud Storage URI folder where the exported evaluations were written. This will be populated if gcs_uri was specified in the request.
Note: The following fields are mutually exclusive: evaluations_uri, evaluations_content. If a field in that set is populated, all other fields in the set will automatically be cleared.
953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 953 class ExportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FailedEvaluationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#failed_evaluations ⇒ ::Google::Protobuf::Map{::String => ::String} (readonly)
Returns Output only. A map of evaluation resource names that could not be exported, to the reason why they failed.
953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 953 class ExportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class FailedEvaluationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |