Class: Google::Cloud::Ces::V1beta::GenerateAppResourceOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Operation metadata for AgentService.GenerateAppResource.

Defined Under Namespace

Modules: GenerationType

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation was created.

Returns:



1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1548

class GenerateAppResourceOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the generation operation.
  module GenerationType
    # Unspecified operation type.
    GENERATION_TYPE_UNSPECIFIED = 0

    # Agent instruction restructure type.
    AGENT_RESTRUCTURE = 1

    # Agent instruction refinement type.
    AGENT_REFINE = 2

    # Agent creation from type.
    AGENT_CREATE = 3

    # Tool creation type.
    TOOL_CREATE = 4

    # Scenario creation type.
    SCENARIO_CREATE = 5

    # Scenario creation from transcripts type.
    SCENARIO_CREATE_FROM_TRANSCRIPTS = 7

    # Evaluation persona generation type.
    EVALUATION_PERSONA_CREATE = 6

    # Quality report generation type.
    QUALITY_REPORT_CREATE = 8

    # Instruction following fix type (used for hill climbing fixes).
    INSTRUCTION_FOLLOWING_FIX = 9
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation finished running.

Returns:



1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1548

class GenerateAppResourceOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the generation operation.
  module GenerationType
    # Unspecified operation type.
    GENERATION_TYPE_UNSPECIFIED = 0

    # Agent instruction restructure type.
    AGENT_RESTRUCTURE = 1

    # Agent instruction refinement type.
    AGENT_REFINE = 2

    # Agent creation from type.
    AGENT_CREATE = 3

    # Tool creation type.
    TOOL_CREATE = 4

    # Scenario creation type.
    SCENARIO_CREATE = 5

    # Scenario creation from transcripts type.
    SCENARIO_CREATE_FROM_TRANSCRIPTS = 7

    # Evaluation persona generation type.
    EVALUATION_PERSONA_CREATE = 6

    # Quality report generation type.
    QUALITY_REPORT_CREATE = 8

    # Instruction following fix type (used for hill climbing fixes).
    INSTRUCTION_FOLLOWING_FIX = 9
  end
end

#generation_type::Google::Cloud::Ces::V1beta::GenerateAppResourceOperationMetadata::GenerationType (readonly)

Returns Output only. The type of the operation.

Returns:



1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1548

class GenerateAppResourceOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the generation operation.
  module GenerationType
    # Unspecified operation type.
    GENERATION_TYPE_UNSPECIFIED = 0

    # Agent instruction restructure type.
    AGENT_RESTRUCTURE = 1

    # Agent instruction refinement type.
    AGENT_REFINE = 2

    # Agent creation from type.
    AGENT_CREATE = 3

    # Tool creation type.
    TOOL_CREATE = 4

    # Scenario creation type.
    SCENARIO_CREATE = 5

    # Scenario creation from transcripts type.
    SCENARIO_CREATE_FROM_TRANSCRIPTS = 7

    # Evaluation persona generation type.
    EVALUATION_PERSONA_CREATE = 6

    # Quality report generation type.
    QUALITY_REPORT_CREATE = 8

    # Instruction following fix type (used for hill climbing fixes).
    INSTRUCTION_FOLLOWING_FIX = 9
  end
end

#message::String (readonly)

Returns Output only. Human-readable status of the operation, if any.

Returns:

  • (::String)

    Output only. Human-readable status of the operation, if any.



1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1548

class GenerateAppResourceOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the generation operation.
  module GenerationType
    # Unspecified operation type.
    GENERATION_TYPE_UNSPECIFIED = 0

    # Agent instruction restructure type.
    AGENT_RESTRUCTURE = 1

    # Agent instruction refinement type.
    AGENT_REFINE = 2

    # Agent creation from type.
    AGENT_CREATE = 3

    # Tool creation type.
    TOOL_CREATE = 4

    # Scenario creation type.
    SCENARIO_CREATE = 5

    # Scenario creation from transcripts type.
    SCENARIO_CREATE_FROM_TRANSCRIPTS = 7

    # Evaluation persona generation type.
    EVALUATION_PERSONA_CREATE = 6

    # Quality report generation type.
    QUALITY_REPORT_CREATE = 8

    # Instruction following fix type (used for hill climbing fixes).
    INSTRUCTION_FOLLOWING_FIX = 9
  end
end

#partial_errors::Array<::Google::Rpc::Status> (readonly)

Returns Output only. Error messages from the resource generation process.

Returns:



1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1548

class GenerateAppResourceOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the generation operation.
  module GenerationType
    # Unspecified operation type.
    GENERATION_TYPE_UNSPECIFIED = 0

    # Agent instruction restructure type.
    AGENT_RESTRUCTURE = 1

    # Agent instruction refinement type.
    AGENT_REFINE = 2

    # Agent creation from type.
    AGENT_CREATE = 3

    # Tool creation type.
    TOOL_CREATE = 4

    # Scenario creation type.
    SCENARIO_CREATE = 5

    # Scenario creation from transcripts type.
    SCENARIO_CREATE_FROM_TRANSCRIPTS = 7

    # Evaluation persona generation type.
    EVALUATION_PERSONA_CREATE = 6

    # Quality report generation type.
    QUALITY_REPORT_CREATE = 8

    # Instruction following fix type (used for hill climbing fixes).
    INSTRUCTION_FOLLOWING_FIX = 9
  end
end

#target::String (readonly)

Returns Output only. The resource name of the app that the operation is associated with. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Output only. The resource name of the app that the operation is associated with. Format: projects/{project}/locations/{location}/apps/{app}.



1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1548

class GenerateAppResourceOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the generation operation.
  module GenerationType
    # Unspecified operation type.
    GENERATION_TYPE_UNSPECIFIED = 0

    # Agent instruction restructure type.
    AGENT_RESTRUCTURE = 1

    # Agent instruction refinement type.
    AGENT_REFINE = 2

    # Agent creation from type.
    AGENT_CREATE = 3

    # Tool creation type.
    TOOL_CREATE = 4

    # Scenario creation type.
    SCENARIO_CREATE = 5

    # Scenario creation from transcripts type.
    SCENARIO_CREATE_FROM_TRANSCRIPTS = 7

    # Evaluation persona generation type.
    EVALUATION_PERSONA_CREATE = 6

    # Quality report generation type.
    QUALITY_REPORT_CREATE = 8

    # Instruction following fix type (used for hill climbing fixes).
    INSTRUCTION_FOLLOWING_FIX = 9
  end
end