Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::AppGenerationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::AppGenerationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
The configuration to be used to generate the app.
Instance Attribute Summary collapse
-
#context ⇒ ::String
Optional.
-
#dataset_id ⇒ ::String
Optional.
-
#file_contexts ⇒ ::Array<::Google::Cloud::Ces::V1beta::FileContext>
Optional.
-
#gcs_location ⇒ ::String
Optional.
-
#generate_evaluations ⇒ ::Boolean
Optional.
Instance Attribute Details
#context ⇒ ::String
Returns Optional. The context which describes the requirements of the agents & tools to be generated.
1329 1330 1331 1332 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1329 class AppGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dataset_id ⇒ ::String
Returns Optional. The insights dataset to be used to fetch conversation data for
generating the agents & tools.
Format:
projects/{project}/locations/{location}/datasets/{dataset}.
1329 1330 1331 1332 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1329 class AppGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#file_contexts ⇒ ::Array<::Google::Cloud::Ces::V1beta::FileContext>
Returns Optional. The files to be used as context.
1329 1330 1331 1332 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1329 class AppGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_location ⇒ ::String
Returns Optional. The Cloud Storage location to store the generated question
answer data to be used by the Datastore tool. This data is generated only
when using conversation data as an input source. The location must be
in the same project as the app.
Format: gs://....
1329 1330 1331 1332 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1329 class AppGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#generate_evaluations ⇒ ::Boolean
Returns Optional. Whether to generate the evaluations for the app. If true, the provided context will be used to generate the evaluations data.
1329 1330 1331 1332 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1329 class AppGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |