Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::HillClimbingFixConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::HillClimbingFixConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
The configuration to be used for hill climbing fixes.
Instance Attribute Summary collapse
Instance Attribute Details
#quality_report ⇒ ::Google::Cloud::Ces::V1beta::QualityReport
Returns Required. The quality report used to inform the instruction following fix.
1366 1367 1368 1369 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1366 class HillClimbingFixConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |