Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::QualityReportGenerationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::QualityReportGenerationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
The configuration to be used for quality report generation.
Defined Under Namespace
Modules: LossAttributionAlgorithm
Instance Attribute Summary collapse
-
#algorithm ⇒ ::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::QualityReportGenerationConfig::LossAttributionAlgorithm
Optional.
-
#evaluation_run ⇒ ::String
Required.
Instance Attribute Details
#algorithm ⇒ ::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::QualityReportGenerationConfig::LossAttributionAlgorithm
Returns Optional. The loss attribution algorithm to use.
1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1380 class QualityReportGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The algorithm to use for loss attribution. module LossAttributionAlgorithm # Unspecified. LOSS_ATTRIBUTION_ALGORITHM_UNSPECIFIED = 0 # App-centric loss attribution. Treats the app as a single unit. APP_CENTRIC = 1 # Agent-centric loss attribution. Attributes loss to individual agents. AGENT_CENTRIC = 2 end end |
#evaluation_run ⇒ ::String
Returns Required. The evaluation run used to inform quality report analysis.
1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1380 class QualityReportGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The algorithm to use for loss attribution. module LossAttributionAlgorithm # Unspecified. LOSS_ATTRIBUTION_ALGORITHM_UNSPECIFIED = 0 # App-centric loss attribution. Treats the app as a single unit. APP_CENTRIC = 1 # Agent-centric loss attribution. Attributes loss to individual agents. AGENT_CENTRIC = 2 end end |