Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::RefineInstructions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The instructions to be used to refine a part of the resource. The part of the resource can be specified with a start index, end index and a field mask. For example, if you want to refine a part of the agent instructions you can specify the index of the first character of the instructions, the index of the last character of the instructions and the field mask as "instructions".

Instance Attribute Summary collapse

Instance Attribute Details

#end_index::Integer

Returns Required. The last character (inclusive) of the text to refine.

Returns:

  • (::Integer)

    Required. The last character (inclusive) of the text to refine.



1249
1250
1251
1252
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1249

class RefineInstructions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#field_mask::Google::Protobuf::FieldMask

Returns Required. The field of the resource being refined. Only one field is allowed per RefineInstructions. If refining agent instructions, the field mask should be "instructions".

Returns:

  • (::Google::Protobuf::FieldMask)

    Required. The field of the resource being refined. Only one field is allowed per RefineInstructions. If refining agent instructions, the field mask should be "instructions".



1249
1250
1251
1252
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1249

class RefineInstructions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instructions::String

Returns Required. The instructions to refine the resource.

Returns:

  • (::String)

    Required. The instructions to refine the resource.



1249
1250
1251
1252
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1249

class RefineInstructions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_index::Integer

Returns Required. The first character (inclusive) of the text to refine.

Returns:

  • (::Integer)

    Required. The first character (inclusive) of the text to refine.



1249
1250
1251
1252
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1249

class RefineInstructions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end