Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The configuration to be used to generate a tool.

Defined Under Namespace

Classes: OpenApiToolsetGenerationConfig

Instance Attribute Summary collapse

Instance Attribute Details

#context::String

Returns Optional. The context which describes the tool to be generated. This can be empty if the tool request & response are provided.

Returns:

  • (::String)

    Optional. The context which describes the tool to be generated. This can be empty if the tool request & response are provided.



1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1265

class ToolGenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration to be used to generate an Open API schema.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Required. The base uri of the tool.
  # @!attribute [rw] operation_generation_configs
  #   @return [::Array<::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig::OperationGenerationConfig>]
  #     Required. The list of operations to be added to the Open API schema.
  class OpenApiToolsetGenerationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The configuration to be used to generate an operation in the Open API
    # schema.
    # @!attribute [rw] method
    #   @return [::String]
    #     Required. The uri of the tool. This should include query and path
    #     parameters if any.
    # @!attribute [rw] path
    #   @return [::String]
    #     Required. The path of the tool to be appended to the base uri. This
    #     should include query and path parameters if any.
    # @!attribute [rw] request_json
    #   @return [::String]
    #     Required. A sample request to the tool in JSON format. Skip if the
    #     tool does not support request body.
    # @!attribute [rw] response_json
    #   @return [::String]
    #     Required. A sample response from the tool in JSON format.
    class OperationGenerationConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#file_contexts::Array<::Google::Cloud::Ces::V1beta::FileContext>

Returns Optional. The files to be used as context.

Returns:



1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1265

class ToolGenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration to be used to generate an Open API schema.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Required. The base uri of the tool.
  # @!attribute [rw] operation_generation_configs
  #   @return [::Array<::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig::OperationGenerationConfig>]
  #     Required. The list of operations to be added to the Open API schema.
  class OpenApiToolsetGenerationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The configuration to be used to generate an operation in the Open API
    # schema.
    # @!attribute [rw] method
    #   @return [::String]
    #     Required. The uri of the tool. This should include query and path
    #     parameters if any.
    # @!attribute [rw] path
    #   @return [::String]
    #     Required. The path of the tool to be appended to the base uri. This
    #     should include query and path parameters if any.
    # @!attribute [rw] request_json
    #   @return [::String]
    #     Required. A sample request to the tool in JSON format. Skip if the
    #     tool does not support request body.
    # @!attribute [rw] response_json
    #   @return [::String]
    #     Required. A sample response from the tool in JSON format.
    class OperationGenerationConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#open_api_toolset_generation_config::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig

Returns Optional. The configuration to be used to generate an Open API schema.

Returns:



1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1265

class ToolGenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration to be used to generate an Open API schema.
  # @!attribute [rw] uri
  #   @return [::String]
  #     Required. The base uri of the tool.
  # @!attribute [rw] operation_generation_configs
  #   @return [::Array<::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig::OperationGenerationConfig>]
  #     Required. The list of operations to be added to the Open API schema.
  class OpenApiToolsetGenerationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The configuration to be used to generate an operation in the Open API
    # schema.
    # @!attribute [rw] method
    #   @return [::String]
    #     Required. The uri of the tool. This should include query and path
    #     parameters if any.
    # @!attribute [rw] path
    #   @return [::String]
    #     Required. The path of the tool to be appended to the base uri. This
    #     should include query and path parameters if any.
    # @!attribute [rw] request_json
    #   @return [::String]
    #     Required. A sample request to the tool in JSON format. Skip if the
    #     tool does not support request body.
    # @!attribute [rw] response_json
    #   @return [::String]
    #     Required. A sample response from the tool in JSON format.
    class OperationGenerationConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end