Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The configuration to be used to generate an Open API schema.

Defined Under Namespace

Classes: OperationGenerationConfig

Instance Attribute Summary collapse

Instance Attribute Details

#operation_generation_configs::Array<::Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig::OperationGenerationConfig>

Returns Required. The list of operations to be added to the Open API schema.

Returns:



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1276

class OpenApiToolsetGenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration to be used to generate an operation in the Open API
  # schema.
  # @!attribute [rw] method
  #   @return [::String]
  #     Required. The uri of the tool. This should include query and path
  #     parameters if any.
  # @!attribute [rw] path
  #   @return [::String]
  #     Required. The path of the tool to be appended to the base uri. This
  #     should include query and path parameters if any.
  # @!attribute [rw] request_json
  #   @return [::String]
  #     Required. A sample request to the tool in JSON format. Skip if the
  #     tool does not support request body.
  # @!attribute [rw] response_json
  #   @return [::String]
  #     Required. A sample response from the tool in JSON format.
  class OperationGenerationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uri::String

Returns Required. The base uri of the tool.

Returns:

  • (::String)

    Required. The base uri of the tool.



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1276

class OpenApiToolsetGenerationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration to be used to generate an operation in the Open API
  # schema.
  # @!attribute [rw] method
  #   @return [::String]
  #     Required. The uri of the tool. This should include query and path
  #     parameters if any.
  # @!attribute [rw] path
  #   @return [::String]
  #     Required. The path of the tool to be appended to the base uri. This
  #     should include query and path parameters if any.
  # @!attribute [rw] request_json
  #   @return [::String]
  #     Required. A sample request to the tool in JSON format. Skip if the
  #     tool does not support request body.
  # @!attribute [rw] response_json
  #   @return [::String]
  #     Required. A sample response from the tool in JSON format.
  class OperationGenerationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end