Class: Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig::OperationGenerationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateAppResourceRequest::ToolGenerationConfig::OpenApiToolsetGenerationConfig::OperationGenerationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
The configuration to be used to generate an operation in the Open API schema.
Instance Attribute Summary collapse
-
#method ⇒ ::String
Required.
-
#path ⇒ ::String
Required.
-
#request_json ⇒ ::String
Required.
-
#response_json ⇒ ::String
Required.
Instance Attribute Details
#method ⇒ ::String
Returns Required. The uri of the tool. This should include query and path parameters if any.
1297 1298 1299 1300 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1297 class OperationGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path ⇒ ::String
Returns Required. The path of the tool to be appended to the base uri. This should include query and path parameters if any.
1297 1298 1299 1300 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1297 class OperationGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_json ⇒ ::String
Returns Required. A sample request to the tool in JSON format. Skip if the tool does not support request body.
1297 1298 1299 1300 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1297 class OperationGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#response_json ⇒ ::String
Returns Required. A sample response from the tool in JSON format.
1297 1298 1299 1300 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1297 class OperationGenerationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |