Class: Google::Cloud::Ces::V1beta::GenerateAppResourceResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

Response message for AgentService.GenerateAppResource.

Defined Under Namespace

Classes: AppResources, Evaluations, GenerateResultInfo, Tools

Instance Attribute Summary collapse

Instance Attribute Details

#agent::Google::Cloud::Ces::V1beta::Agent

Returns Agent generated by the LLM assistant.

Note: The following fields are mutually exclusive: agent, toolset, app_snapshot, tools, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::Agent)

    Agent generated by the LLM assistant.

    Note: The following fields are mutually exclusive: agent, toolset, app_snapshot, tools, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#app_resources::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::AppResources

Returns The app resources generated by the LLM assistant.

Note: The following fields are mutually exclusive: app_resources, agent, toolset, app_snapshot, tools, evaluations, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::AppResources)

    The app resources generated by the LLM assistant.

    Note: The following fields are mutually exclusive: app_resources, agent, toolset, app_snapshot, tools, evaluations, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#app_snapshot::Google::Cloud::Ces::V1beta::AppSnapshot

Returns App snapshot generated by the LLM assistant. This snapshot contains the app, agents & tools generated by the LLM assistant.

Note: The following fields are mutually exclusive: app_snapshot, agent, toolset, tools, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::AppSnapshot)

    App snapshot generated by the LLM assistant. This snapshot contains the app, agents & tools generated by the LLM assistant.

    Note: The following fields are mutually exclusive: app_snapshot, agent, toolset, tools, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#evaluations::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::Evaluations

Returns Evaluations generated by the LLM assistant.

Note: The following fields are mutually exclusive: evaluations, agent, toolset, app_snapshot, tools, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::Evaluations)

    Evaluations generated by the LLM assistant.

    Note: The following fields are mutually exclusive: evaluations, agent, toolset, app_snapshot, tools, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#generate_result_info::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::GenerateResultInfo

Returns Additional information about the generated result.

Returns:



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#quality_report::Google::Cloud::Ces::V1beta::QualityReport

Returns The quality report generated by the LLM assistant.

Note: The following fields are mutually exclusive: quality_report, agent, toolset, app_snapshot, tools, evaluations, app_resources. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::QualityReport)

    The quality report generated by the LLM assistant.

    Note: The following fields are mutually exclusive: quality_report, agent, toolset, app_snapshot, tools, evaluations, app_resources. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tools::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::Tools

Returns The list of tools generated by the LLM assistant.

Note: The following fields are mutually exclusive: tools, agent, toolset, app_snapshot, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::Tools)

    The list of tools generated by the LLM assistant.

    Note: The following fields are mutually exclusive: tools, agent, toolset, app_snapshot, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#toolset::Google::Cloud::Ces::V1beta::Toolset

Returns Toolset generated by the LLM assistant. Supports Open API toolset schema generation.

Note: The following fields are mutually exclusive: toolset, agent, app_snapshot, tools, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Ces::V1beta::Toolset)

    Toolset generated by the LLM assistant. Supports Open API toolset schema generation.

    Note: The following fields are mutually exclusive: toolset, agent, app_snapshot, tools, evaluations, app_resources, quality_report. If a field in that set is populated, all other fields in the set will automatically be cleared.



1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1414

class GenerateAppResourceResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The list of evaluations generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of generated evaluations.
  class Evaluations
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of tools generated by the LLM assistant.
  # @!attribute [rw] tools
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Tool>]
  #     The list of tools generated by the LLM assistant.
  class Tools
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The list of app resources generated by the LLM assistant.
  # @!attribute [rw] app_snapshot
  #   @return [::Google::Cloud::Ces::V1beta::AppSnapshot]
  #     The app snapshot generated by the LLM assistant. This snapshot contains
  #     the app, agents & tools generated by the LLM assistant.
  # @!attribute [rw] evaluations
  #   @return [::Array<::Google::Cloud::Ces::V1beta::Evaluation>]
  #     The list of evaluations generated by the LLM assistant.
  class AppResources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # This provides additional information about the generated result.
  # @!attribute [rw] explanation
  #   @return [::String]
  #     An explanation of the changes in the generated resource.
  class GenerateResultInfo
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end