Class: Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::AppResources
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::AppResources
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
The list of app resources generated by the LLM assistant.
Instance Attribute Summary collapse
-
#app_snapshot ⇒ ::Google::Cloud::Ces::V1beta::AppSnapshot
The app snapshot generated by the LLM assistant.
-
#evaluations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation>
The list of evaluations generated by the LLM assistant.
Instance Attribute Details
#app_snapshot ⇒ ::Google::Cloud::Ces::V1beta::AppSnapshot
Returns The app snapshot generated by the LLM assistant. This snapshot contains the app, agents & tools generated by the LLM assistant.
1444 1445 1446 1447 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1444 class AppResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation>
Returns The list of evaluations generated by the LLM assistant.
1444 1445 1446 1447 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1444 class AppResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |