Class: Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::GenerateResultInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateAppResourceResponse::GenerateResultInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
This provides additional information about the generated result.
Instance Attribute Summary collapse
-
#explanation ⇒ ::String
An explanation of the changes in the generated resource.
Instance Attribute Details
#explanation ⇒ ::String
Returns An explanation of the changes in the generated resource.
1453 1454 1455 1456 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1453 class GenerateResultInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |