Class: Google::Cloud::Ces::V1beta::GenerateChatTokenResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateChatTokenResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/widget_service.rb
Overview
Response message for WidgetService.GenerateChatToken.
Instance Attribute Summary collapse
-
#chat_token ⇒ ::String
The session scoped token for chat widget to authenticate with Session APIs.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
The time at which the chat token expires.
Instance Attribute Details
#chat_token ⇒ ::String
Returns The session scoped token for chat widget to authenticate with Session APIs.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/widget_service.rb', line 55 class GenerateChatTokenResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#expire_time ⇒ ::Google::Protobuf::Timestamp
Returns The time at which the chat token expires.
55 56 57 58 |
# File 'proto_docs/google/cloud/ces/v1beta/widget_service.rb', line 55 class GenerateChatTokenResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |