Class: Google::Cloud::Ces::V1beta::GenerateEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::GenerateEvaluationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Request message for EvaluationService.GenerateEvaluation.
Instance Attribute Summary collapse
-
#conversation ⇒ ::String
Required.
-
#source ⇒ ::Google::Cloud::Ces::V1beta::Conversation::Source
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#conversation ⇒ ::String
Returns Required. The conversation to create the golden evaluation for.
Format:
projects/{project}/locations/{location}/apps/{app}/conversations/{conversation}.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 115 class GenerateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::Google::Cloud::Ces::V1beta::Conversation::Source
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Optional. Indicate the source of the conversation. If not set, all sources will be searched.
115 116 117 118 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 115 class GenerateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |