Module: Google::Cloud::Ces::V1beta::GoldenRunMethod
- Defined in:
- proto_docs/google/cloud/ces/v1beta/golden_run.rb
Overview
The method used to run the evaluation.
Constant Summary collapse
- GOLDEN_RUN_METHOD_UNSPECIFIED =
Run method is not specified.
0- STABLE =
Run the evaluation as stable replay, where each turn is a unique session with the previous expected turns injected as context.
1- NAIVE =
Run the evaluation as naive replay, where the run is a single session with no context injected.
2