Class: Google::Cloud::Ces::V1beta::ImportEvaluationsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation_service.rb

Overview

Defined Under Namespace

Classes: ConversationList, ImportOptions

Instance Attribute Summary collapse

Instance Attribute Details

#conversation_list::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ConversationList

Returns The conversations to import the evaluations from.

Note: The following fields are mutually exclusive: conversation_list, gcs_uri, csv_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 147

class ImportEvaluationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A list of conversation resource names.
  # @!attribute [rw] conversations
  #   @return [::Array<::String>]
  #     Optional. Conversation resource names.
  class ConversationList
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration options for the evaluation import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing evaluations data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an evaluation with the
    # same evaluation ID already exists in the app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Overwrite the existing evaluation with the new one.
      OVERWRITE = 1

      # Keep the existing evaluation and skip the new one.
      SKIP = 2

      # Keep the existing evaluation and duplicate the new one as a new
      # evaluation.
      DUPLICATE = 3
    end
  end
end

#csv_content::String

Returns Raw bytes representing the csv file with the evaluations structure.

Note: The following fields are mutually exclusive: csv_content, conversation_list, gcs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Raw bytes representing the csv file with the evaluations structure.

    Note: The following fields are mutually exclusive: csv_content, conversation_list, gcs_uri. If a field in that set is populated, all other fields in the set will automatically be cleared.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 147

class ImportEvaluationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A list of conversation resource names.
  # @!attribute [rw] conversations
  #   @return [::Array<::String>]
  #     Optional. Conversation resource names.
  class ConversationList
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration options for the evaluation import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing evaluations data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an evaluation with the
    # same evaluation ID already exists in the app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Overwrite the existing evaluation with the new one.
      OVERWRITE = 1

      # Keep the existing evaluation and skip the new one.
      SKIP = 2

      # Keep the existing evaluation and duplicate the new one as a new
      # evaluation.
      DUPLICATE = 3
    end
  end
end

#gcs_uri::String

Returns The Google Cloud Storage URI from which to import evaluations. The format of this URI must be gs://<bucket-name>/<object-name>.

Note: The following fields are mutually exclusive: gcs_uri, conversation_list, csv_content. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The Google Cloud Storage URI from which to import evaluations. The format of this URI must be gs://<bucket-name>/<object-name>.

    Note: The following fields are mutually exclusive: gcs_uri, conversation_list, csv_content. If a field in that set is populated, all other fields in the set will automatically be cleared.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 147

class ImportEvaluationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A list of conversation resource names.
  # @!attribute [rw] conversations
  #   @return [::Array<::String>]
  #     Optional. Conversation resource names.
  class ConversationList
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration options for the evaluation import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing evaluations data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an evaluation with the
    # same evaluation ID already exists in the app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Overwrite the existing evaluation with the new one.
      OVERWRITE = 1

      # Keep the existing evaluation and skip the new one.
      SKIP = 2

      # Keep the existing evaluation and duplicate the new one as a new
      # evaluation.
      DUPLICATE = 3
    end
  end
end

#import_options::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions

Returns Optional. Options governing the import process for the evaluations.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 147

class ImportEvaluationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A list of conversation resource names.
  # @!attribute [rw] conversations
  #   @return [::Array<::String>]
  #     Optional. Conversation resource names.
  class ConversationList
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration options for the evaluation import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing evaluations data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an evaluation with the
    # same evaluation ID already exists in the app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Overwrite the existing evaluation with the new one.
      OVERWRITE = 1

      # Keep the existing evaluation and skip the new one.
      SKIP = 2

      # Keep the existing evaluation and duplicate the new one as a new
      # evaluation.
      DUPLICATE = 3
    end
  end
end

#parent::String

Returns Required. The app to import the evaluations into. Format: projects/{project}/locations/{location}/apps/{app}.

Returns:

  • (::String)

    Required. The app to import the evaluations into. Format: projects/{project}/locations/{location}/apps/{app}



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 147

class ImportEvaluationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A list of conversation resource names.
  # @!attribute [rw] conversations
  #   @return [::Array<::String>]
  #     Optional. Conversation resource names.
  class ConversationList
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration options for the evaluation import process.
  # These options control how the import behaves, particularly when
  # conflicts arise with existing evaluations data.
  # @!attribute [rw] conflict_resolution_strategy
  #   @return [::Google::Cloud::Ces::V1beta::ImportEvaluationsRequest::ImportOptions::ConflictResolutionStrategy]
  #     Optional. The strategy to use when resolving conflicts during import.
  class ImportOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Defines the strategy for handling conflicts when an evaluation with the
    # same evaluation ID already exists in the app.
    module ConflictResolutionStrategy
      # The conflict resolution strategy is unspecified.
      CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED = 0

      # Overwrite the existing evaluation with the new one.
      OVERWRITE = 1

      # Keep the existing evaluation and skip the new one.
      SKIP = 2

      # Keep the existing evaluation and duplicate the new one as a new
      # evaluation.
      DUPLICATE = 3
    end
  end
end