Class: Google::Cloud::Ces::V1beta::ImportEvaluationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ImportEvaluationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Response message for EvaluationService.ImportEvaluations.
Instance Attribute Summary collapse
-
#error_messages ⇒ ::Array<::String>
Optional.
-
#evaluation_result_import_failure_count ⇒ ::Integer
The number of evaluation results that either failed to import entirely or completed import with one or more errors.
-
#evaluation_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult>
The list of evaluation results that were imported into the app.
-
#evaluation_run_import_failure_count ⇒ ::Integer
The number of evaluation runs that either failed to import entirely or completed import with one or more errors.
-
#evaluation_runs ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationRun>
The list of evaluation runs that were imported into the app.
-
#evaluations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation>
The list of evaluations that were imported into the app.
-
#import_failure_count ⇒ ::Integer
The number of evaluations that either failed to import entirely or completed import with one or more errors.
Instance Attribute Details
#error_messages ⇒ ::Array<::String>
Returns Optional. A list of error messages associated with evaluations that failed to be imported.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_result_import_failure_count ⇒ ::Integer
Returns The number of evaluation results that either failed to import entirely or completed import with one or more errors.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_results ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationResult>
Returns The list of evaluation results that were imported into the app.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_run_import_failure_count ⇒ ::Integer
Returns The number of evaluation runs that either failed to import entirely or completed import with one or more errors.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_runs ⇒ ::Array<::Google::Cloud::Ces::V1beta::EvaluationRun>
Returns The list of evaluation runs that were imported into the app.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Evaluation>
Returns The list of evaluations that were imported into the app.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#import_failure_count ⇒ ::Integer
Returns The number of evaluations that either failed to import entirely or completed import with one or more errors.
216 217 218 219 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 216 class ImportEvaluationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |