Class: Google::Cloud::Ces::V1beta::LatencyReport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

Latency report for the evaluation run.

Defined Under Namespace

Classes: CallbackLatency, GuardrailLatency, LatencyMetrics, LlmCallLatency, ToolLatency

Instance Attribute Summary collapse

Instance Attribute Details

#callback_latencies::Array<::Google::Cloud::Ces::V1beta::LatencyReport::CallbackLatency> (readonly)

Returns Output only. Unordered list. Latency metrics for each callback.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1208

class LatencyReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Latency metrics for a component.
  # @!attribute [r] p50_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 50th percentile latency.
  # @!attribute [r] p90_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 90th percentile latency.
  # @!attribute [r] p99_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 99th percentile latency.
  # @!attribute [r] call_count
  #   @return [::Integer]
  #     Output only. The number of times the resource was called.
  class LatencyMetrics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single tool.
  # @!attribute [r] tool
  #   @return [::String]
  #     Output only. Format:
  #     `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`.
  #
  #     Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] toolset_tool
  #   @return [::Google::Cloud::Ces::V1beta::ToolsetTool]
  #     Output only. The toolset tool identifier.
  #
  #     Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] tool_display_name
  #   @return [::String]
  #     Output only. The display name of the tool.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the tool.
  class ToolLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single callback.
  # @!attribute [r] stage
  #   @return [::String]
  #     Output only. The stage of the callback.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the callback.
  class CallbackLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single guardrail.
  # @!attribute [r] guardrail
  #   @return [::String]
  #     Output only. The name of the guardrail.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`.
  # @!attribute [r] guardrail_display_name
  #   @return [::String]
  #     Output only. The display name of the guardrail.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the guardrail.
  class GuardrailLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single LLM call.
  # @!attribute [r] model
  #   @return [::String]
  #     Output only. The name of the model.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the LLM call.
  class LlmCallLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#guardrail_latencies::Array<::Google::Cloud::Ces::V1beta::LatencyReport::GuardrailLatency> (readonly)

Returns Output only. Unordered list. Latency metrics for each guardrail.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1208

class LatencyReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Latency metrics for a component.
  # @!attribute [r] p50_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 50th percentile latency.
  # @!attribute [r] p90_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 90th percentile latency.
  # @!attribute [r] p99_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 99th percentile latency.
  # @!attribute [r] call_count
  #   @return [::Integer]
  #     Output only. The number of times the resource was called.
  class LatencyMetrics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single tool.
  # @!attribute [r] tool
  #   @return [::String]
  #     Output only. Format:
  #     `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`.
  #
  #     Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] toolset_tool
  #   @return [::Google::Cloud::Ces::V1beta::ToolsetTool]
  #     Output only. The toolset tool identifier.
  #
  #     Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] tool_display_name
  #   @return [::String]
  #     Output only. The display name of the tool.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the tool.
  class ToolLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single callback.
  # @!attribute [r] stage
  #   @return [::String]
  #     Output only. The stage of the callback.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the callback.
  class CallbackLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single guardrail.
  # @!attribute [r] guardrail
  #   @return [::String]
  #     Output only. The name of the guardrail.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`.
  # @!attribute [r] guardrail_display_name
  #   @return [::String]
  #     Output only. The display name of the guardrail.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the guardrail.
  class GuardrailLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single LLM call.
  # @!attribute [r] model
  #   @return [::String]
  #     Output only. The name of the model.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the LLM call.
  class LlmCallLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#llm_call_latencies::Array<::Google::Cloud::Ces::V1beta::LatencyReport::LlmCallLatency> (readonly)

Returns Output only. Unordered list. Latency metrics for each LLM call.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1208

class LatencyReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Latency metrics for a component.
  # @!attribute [r] p50_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 50th percentile latency.
  # @!attribute [r] p90_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 90th percentile latency.
  # @!attribute [r] p99_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 99th percentile latency.
  # @!attribute [r] call_count
  #   @return [::Integer]
  #     Output only. The number of times the resource was called.
  class LatencyMetrics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single tool.
  # @!attribute [r] tool
  #   @return [::String]
  #     Output only. Format:
  #     `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`.
  #
  #     Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] toolset_tool
  #   @return [::Google::Cloud::Ces::V1beta::ToolsetTool]
  #     Output only. The toolset tool identifier.
  #
  #     Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] tool_display_name
  #   @return [::String]
  #     Output only. The display name of the tool.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the tool.
  class ToolLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single callback.
  # @!attribute [r] stage
  #   @return [::String]
  #     Output only. The stage of the callback.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the callback.
  class CallbackLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single guardrail.
  # @!attribute [r] guardrail
  #   @return [::String]
  #     Output only. The name of the guardrail.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`.
  # @!attribute [r] guardrail_display_name
  #   @return [::String]
  #     Output only. The display name of the guardrail.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the guardrail.
  class GuardrailLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single LLM call.
  # @!attribute [r] model
  #   @return [::String]
  #     Output only. The name of the model.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the LLM call.
  class LlmCallLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#session_count::Integer (readonly)

Returns Output only. The total number of sessions considered in the latency report.

Returns:

  • (::Integer)

    Output only. The total number of sessions considered in the latency report.



1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1208

class LatencyReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Latency metrics for a component.
  # @!attribute [r] p50_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 50th percentile latency.
  # @!attribute [r] p90_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 90th percentile latency.
  # @!attribute [r] p99_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 99th percentile latency.
  # @!attribute [r] call_count
  #   @return [::Integer]
  #     Output only. The number of times the resource was called.
  class LatencyMetrics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single tool.
  # @!attribute [r] tool
  #   @return [::String]
  #     Output only. Format:
  #     `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`.
  #
  #     Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] toolset_tool
  #   @return [::Google::Cloud::Ces::V1beta::ToolsetTool]
  #     Output only. The toolset tool identifier.
  #
  #     Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] tool_display_name
  #   @return [::String]
  #     Output only. The display name of the tool.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the tool.
  class ToolLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single callback.
  # @!attribute [r] stage
  #   @return [::String]
  #     Output only. The stage of the callback.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the callback.
  class CallbackLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single guardrail.
  # @!attribute [r] guardrail
  #   @return [::String]
  #     Output only. The name of the guardrail.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`.
  # @!attribute [r] guardrail_display_name
  #   @return [::String]
  #     Output only. The display name of the guardrail.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the guardrail.
  class GuardrailLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single LLM call.
  # @!attribute [r] model
  #   @return [::String]
  #     Output only. The name of the model.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the LLM call.
  class LlmCallLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tool_latencies::Array<::Google::Cloud::Ces::V1beta::LatencyReport::ToolLatency> (readonly)

Returns Output only. Unordered list. Latency metrics for each tool.

Returns:



1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1208

class LatencyReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Latency metrics for a component.
  # @!attribute [r] p50_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 50th percentile latency.
  # @!attribute [r] p90_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 90th percentile latency.
  # @!attribute [r] p99_latency
  #   @return [::Google::Protobuf::Duration]
  #     Output only. The 99th percentile latency.
  # @!attribute [r] call_count
  #   @return [::Integer]
  #     Output only. The number of times the resource was called.
  class LatencyMetrics
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single tool.
  # @!attribute [r] tool
  #   @return [::String]
  #     Output only. Format:
  #     `projects/{project}/locations/{location}/apps/{app}/tools/{tool}`.
  #
  #     Note: The following fields are mutually exclusive: `tool`, `toolset_tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] toolset_tool
  #   @return [::Google::Cloud::Ces::V1beta::ToolsetTool]
  #     Output only. The toolset tool identifier.
  #
  #     Note: The following fields are mutually exclusive: `toolset_tool`, `tool`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [r] tool_display_name
  #   @return [::String]
  #     Output only. The display name of the tool.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the tool.
  class ToolLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single callback.
  # @!attribute [r] stage
  #   @return [::String]
  #     Output only. The stage of the callback.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the callback.
  class CallbackLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single guardrail.
  # @!attribute [r] guardrail
  #   @return [::String]
  #     Output only. The name of the guardrail.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/guardrails/{guardrail}`.
  # @!attribute [r] guardrail_display_name
  #   @return [::String]
  #     Output only. The display name of the guardrail.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the guardrail.
  class GuardrailLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Latency metrics for a single LLM call.
  # @!attribute [r] model
  #   @return [::String]
  #     Output only. The name of the model.
  # @!attribute [r] latency_metrics
  #   @return [::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics]
  #     Output only. The latency metrics for the LLM call.
  class LlmCallLatency
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end