Class: Google::Cloud::Ces::V1beta::LatencyReport::ToolLatency
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::LatencyReport::ToolLatency
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
Latency metrics for a single tool.
Instance Attribute Summary collapse
-
#latency_metrics ⇒ ::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics
readonly
Output only.
-
#tool ⇒ ::String
readonly
Output only.
-
#tool_display_name ⇒ ::String
readonly
Output only.
-
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
readonly
Output only.
Instance Attribute Details
#latency_metrics ⇒ ::Google::Cloud::Ces::V1beta::LatencyReport::LatencyMetrics (readonly)
Returns Output only. The latency metrics for the tool.
1248 1249 1250 1251 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1248 class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String (readonly)
Returns Output only. Format:
projects/{project}/locations/{location}/apps/{app}/tools/{tool}.
Note: The following fields are mutually exclusive: tool, toolset_tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
1248 1249 1250 1251 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1248 class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_display_name ⇒ ::String (readonly)
Returns Output only. The display name of the tool.
1248 1249 1250 1251 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1248 class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset_tool ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool (readonly)
Returns Output only. The toolset tool identifier.
Note: The following fields are mutually exclusive: toolset_tool, tool. If a field in that set is populated, all other fields in the set will automatically be cleared.
1248 1249 1250 1251 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1248 class ToolLatency include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |