Class: Google::Cloud::Ces::V1beta::ListConversationsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ListConversationsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Response message for AgentService.ListConversations.
Instance Attribute Summary collapse
-
#conversations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Conversation>
The list of conversations.
-
#next_page_token ⇒ ::String
A token that can be sent as ListConversationsRequest.page_token to retrieve the next page.
Instance Attribute Details
#conversations ⇒ ::Array<::Google::Cloud::Ces::V1beta::Conversation>
Returns The list of conversations.
679 680 681 682 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 679 class ListConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token that can be sent as ListConversationsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.
679 680 681 682 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 679 class ListConversationsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |