Class: Google::Cloud::Ces::V1beta::LoggingSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::LoggingSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Settings to describe the logging behaviors for the app.
Instance Attribute Summary collapse
-
#audio_recording_config ⇒ ::Google::Cloud::Ces::V1beta::AudioRecordingConfig
Optional.
-
#bigquery_export_settings ⇒ ::Google::Cloud::Ces::V1beta::BigQueryExportSettings
Optional.
-
#cloud_logging_settings ⇒ ::Google::Cloud::Ces::V1beta::CloudLoggingSettings
Optional.
-
#conversation_logging_settings ⇒ ::Google::Cloud::Ces::V1beta::ConversationLoggingSettings
Optional.
-
#evaluation_audio_recording_config ⇒ ::Google::Cloud::Ces::V1beta::AudioRecordingConfig
Optional.
-
#metric_analysis_settings ⇒ ::Google::Cloud::Ces::V1beta::MetricAnalysisSettings
Optional.
-
#redaction_config ⇒ ::Google::Cloud::Ces::V1beta::RedactionConfig
Optional.
Instance Attribute Details
#audio_recording_config ⇒ ::Google::Cloud::Ces::V1beta::AudioRecordingConfig
Returns Optional. Configuration for how audio interactions should be recorded.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bigquery_export_settings ⇒ ::Google::Cloud::Ces::V1beta::BigQueryExportSettings
Returns Optional. Settings to describe the BigQuery export behaviors for the app. The conversation data will be exported to BigQuery tables if it is enabled.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_logging_settings ⇒ ::Google::Cloud::Ces::V1beta::CloudLoggingSettings
Returns Optional. Settings to describe the Cloud Logging behaviors for the app.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#conversation_logging_settings ⇒ ::Google::Cloud::Ces::V1beta::ConversationLoggingSettings
Returns Optional. Settings to describe the conversation logging behaviors for the app.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_audio_recording_config ⇒ ::Google::Cloud::Ces::V1beta::AudioRecordingConfig
Returns Optional. Configuration for how audio interactions should be recorded for the evaluation. By default, audio recording is not enabled for evaluation sessions.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metric_analysis_settings ⇒ ::Google::Cloud::Ces::V1beta::MetricAnalysisSettings
Returns Optional. Settings to describe the conversation data collection behaviors for the LLM analysis pipeline for the app.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#redaction_config ⇒ ::Google::Cloud::Ces::V1beta::RedactionConfig
Returns Optional. Configuration for how sensitive data should be redacted.
408 409 410 411 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 408 class LoggingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |