Class: Google::Cloud::Ces::V1beta::McpTool
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::McpTool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/mcp_tool.rb
Overview
An MCP tool. See https://modelcontextprotocol.io/specification/2025-06-18/server/tools for more details.
Defined Under Namespace
Modules: State Classes: CustomHeadersEntry
Instance Attribute Summary collapse
-
#api_authentication ⇒ ::Google::Cloud::Ces::V1beta::ApiAuthentication
Optional.
-
#custom_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#description ⇒ ::String
Optional.
-
#input_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema
Optional.
-
#name ⇒ ::String
Required.
-
#name_override ⇒ ::String
Optional.
-
#output_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema
Optional.
-
#server_address ⇒ ::String
Required.
-
#service_directory_config ⇒ ::Google::Cloud::Ces::V1beta::ServiceDirectoryConfig
Optional.
-
#state ⇒ ::Google::Cloud::Ces::V1beta::McpTool::State
readonly
Output only.
-
#tls_config ⇒ ::Google::Cloud::Ces::V1beta::TlsConfig
Optional.
Instance Attribute Details
#api_authentication ⇒ ::Google::Cloud::Ces::V1beta::ApiAuthentication
Returns Optional. Authentication information required to execute the tool against the MCP server. For bearer token authentication, the token applies only to tool execution, not to listing tools. This requires that tools can be listed without authentication.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#custom_headers ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The custom headers to send in the request to the MCP server. The
values must be in the format $context.variables.<name_of_variable> and
can be set in the session variables. See
https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool/open-api#openapi-injection
for more details.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#description ⇒ ::String
Returns Optional. The description of the MCP tool.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#input_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema
Returns Optional. The schema of the input arguments of the MCP tool.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#name ⇒ ::String
Returns Required. The name of the MCP tool.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#name_override ⇒ ::String
Returns Optional. The name override of the MCP tool. This is populated if the name was overridden by a Toolset override.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#output_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema
Returns Optional. The schema of the output arguments of the MCP tool.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#server_address ⇒ ::String
Returns Required. The server address of the MCP server, e.g., "https://example.com/mcp/". If the server is built with the MCP SDK, the url should be suffixed with "/mcp/". Only Streamable HTTP transport based servers are supported. This is the same as the server_address in the McpToolset. See https://modelcontextprotocol.io/specification/2025-03-26/basic/transports#streamable-http for more details.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#service_directory_config ⇒ ::Google::Cloud::Ces::V1beta::ServiceDirectoryConfig
Returns Optional. Service Directory configuration for VPC-SC, used to resolve service names within a perimeter.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#state ⇒ ::Google::Cloud::Ces::V1beta::McpTool::State (readonly)
Returns Output only. The dynamic availability state of the tool on the external server.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |
#tls_config ⇒ ::Google::Cloud::Ces::V1beta::TlsConfig
Returns Optional. The TLS configuration. Includes the custom server certificates that the client should trust.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_tool.rb', line 77 class McpTool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class CustomHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the dynamic availability state of the tool. module State # Default state. STATE_UNSPECIFIED = 0 # The tool is available and actively offered by the server. ACTIVE = 1 # The tool is configured or pinned, but currently not offered by the # server. INACTIVE = 2 # The tool exists on the server, but does not match the version on the # server. STALE = 3 end end |