Module: Google::Cloud::Ces::V1beta::McpTool::State
- Defined in:
- proto_docs/google/cloud/ces/v1beta/mcp_tool.rb
Overview
Represents the dynamic availability state of the tool.
Constant Summary collapse
- STATE_UNSPECIFIED =
Default state.
0- ACTIVE =
The tool is available and actively offered by the server.
1- INACTIVE =
The tool is configured or pinned, but currently not offered by the server.
2- STALE =
The tool exists on the server, but does not match the version on the server.
3