Class: Google::Cloud::Ces::V1beta::McpToolDefinition
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::McpToolDefinition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb
Overview
Container for a tool's core definition elements that are snapshot. Schemas in the snapshot are used as-is and cannot be overridden.
Instance Attribute Summary collapse
-
#description ⇒ ::String
readonly
Output only.
-
#input_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema
readonly
Output only.
-
#output_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema
readonly
Output only.
Instance Attribute Details
#description ⇒ ::String (readonly)
Returns Output only. The description of the MCP tool. This can be overridden
by description_override in McpToolOverride.
111 112 113 114 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 111 class McpToolDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema (readonly)
Returns Output only. The schema of the input arguments of the MCP tool.
111 112 113 114 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 111 class McpToolDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_schema ⇒ ::Google::Cloud::Ces::V1beta::Schema (readonly)
Returns Output only. The schema of the output arguments of the MCP tool.
111 112 113 114 |
# File 'proto_docs/google/cloud/ces/v1beta/mcp_toolset.rb', line 111 class McpToolDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |