Class: Google::Cloud::Ces::V1beta::MockConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::MockConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/session_service.rb
Overview
Mock tool calls configuration for the session.
Defined Under Namespace
Modules: UnmatchedToolCallBehavior
Instance Attribute Summary collapse
-
#mocked_tool_calls ⇒ ::Array<::Google::Cloud::Ces::V1beta::MockedToolCall>
Optional.
-
#unmatched_tool_call_behavior ⇒ ::Google::Cloud::Ces::V1beta::MockConfig::UnmatchedToolCallBehavior
Required.
Instance Attribute Details
#mocked_tool_calls ⇒ ::Array<::Google::Cloud::Ces::V1beta::MockedToolCall>
Returns Optional. All tool calls to mock for the duration of the session.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 32 class MockConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What to do when a tool call doesn't match any mocked tool calls. module UnmatchedToolCallBehavior # Default value. This value is unused. UNMATCHED_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Throw an error for any tool calls that don't match a mock expected input # pattern. FAIL = 1 # For unmatched tool calls, pass the tool call through to real tool. PASS_THROUGH = 2 end end |
#unmatched_tool_call_behavior ⇒ ::Google::Cloud::Ces::V1beta::MockConfig::UnmatchedToolCallBehavior
Returns Required. Beavhior for tool calls that don't match any args patterns in mocked_tool_calls.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 32 class MockConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What to do when a tool call doesn't match any mocked tool calls. module UnmatchedToolCallBehavior # Default value. This value is unused. UNMATCHED_TOOL_CALL_BEHAVIOR_UNSPECIFIED = 0 # Throw an error for any tool calls that don't match a mock expected input # pattern. FAIL = 1 # For unmatched tool calls, pass the tool call through to real tool. PASS_THROUGH = 2 end end |