Module: Google::Cloud::Ces::V1beta::MockConfig::UnmatchedToolCallBehavior
- Defined in:
- proto_docs/google/cloud/ces/v1beta/session_service.rb
Overview
What to do when a tool call doesn't match any mocked tool calls.
Constant Summary collapse
- UNMATCHED_TOOL_CALL_BEHAVIOR_UNSPECIFIED =
Default value. This value is unused.
0- FAIL =
Throw an error for any tool calls that don't match a mock expected input pattern.
1- PASS_THROUGH =
For unmatched tool calls, pass the tool call through to real tool.
2