Class: Google::Cloud::Ces::V1beta::MockedToolCall
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::MockedToolCall
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/mocks.rb
Overview
A mocked tool call.
Expresses the target tool + a pattern to match against that tool's args / inputs. If the pattern matches, then the mock response will be returned.
Instance Attribute Summary collapse
-
#expected_args_pattern ⇒ ::Google::Protobuf::Struct
Required.
-
#mock_response ⇒ ::Google::Protobuf::Struct
Optional.
-
#tool ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#tool_id ⇒ ::String
Optional.
-
#toolset ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Optional.
Instance Attribute Details
#expected_args_pattern ⇒ ::Google::Protobuf::Struct
Returns Required. A pattern to match against the args / inputs of all dispatched tool calls. If the tool call inputs match this pattern, then mock output will be returned.
53 54 55 56 |
# File 'proto_docs/google/cloud/ces/v1beta/mocks.rb', line 53 class MockedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mock_response ⇒ ::Google::Protobuf::Struct
Returns Optional. The mock response / output to return if the tool call args / inputs match the pattern.
53 54 55 56 |
# File 'proto_docs/google/cloud/ces/v1beta/mocks.rb', line 53 class MockedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated. Use tool_identifier instead.
53 54 55 56 |
# File 'proto_docs/google/cloud/ces/v1beta/mocks.rb', line 53 class MockedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_id ⇒ ::String
Returns Optional. The name of the tool to mock.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Note: The following fields are mutually exclusive: tool_id, toolset. If a field in that set is populated, all other fields in the set will automatically be cleared.
53 54 55 56 |
# File 'proto_docs/google/cloud/ces/v1beta/mocks.rb', line 53 class MockedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset ⇒ ::Google::Cloud::Ces::V1beta::ToolsetTool
Returns Optional. The toolset to mock.
Note: The following fields are mutually exclusive: toolset, tool_id. If a field in that set is populated, all other fields in the set will automatically be cleared.
53 54 55 56 |
# File 'proto_docs/google/cloud/ces/v1beta/mocks.rb', line 53 class MockedToolCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |