Class: Google::Cloud::Ces::V1beta::OptimizationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/evaluation.rb

Overview

Configuration for running the optimization step after the evaluation run.

Defined Under Namespace

Modules: OptimizationStatus

Instance Attribute Summary collapse

Instance Attribute Details

#assistant_session::String (readonly)

Returns Output only. The assistant session to use for the optimization based on this evaluation run. Format: projects/{project}/locations/{location}/apps/{app}/assistantSessions/{assistantSession}.

Returns:

  • (::String)

    Output only. The assistant session to use for the optimization based on this evaluation run. Format: projects/{project}/locations/{location}/apps/{app}/assistantSessions/{assistantSession}



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end

#error_message::String (readonly)

Returns Output only. The error message if the optimization run failed.

Returns:

  • (::String)

    Output only. The error message if the optimization run failed.



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end

#generate_loss_report::Boolean

Returns Optional. Whether to generate a loss report.

Returns:

  • (::Boolean)

    Optional. Whether to generate a loss report.



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end

#loss_report::Google::Protobuf::Struct (readonly)

Returns Output only. The generated loss report.

Returns:



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end

#report_summary::String (readonly)

Returns Output only. The summary of the loss report.

Returns:

  • (::String)

    Output only. The summary of the loss report.



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end

#should_suggest_fix::Boolean (readonly)

Returns Output only. Whether to suggest a fix for the losses.

Returns:

  • (::Boolean)

    Output only. Whether to suggest a fix for the losses.



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end

#status::Google::Cloud::Ces::V1beta::OptimizationConfig::OptimizationStatus (readonly)

Returns Output only. The status of the optimization run.

Returns:



1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1596

class OptimizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The status of the optimization run.
  module OptimizationStatus
    # Optimization status is not specified.
    OPTIMIZATION_STATUS_UNSPECIFIED = 0

    # Optimization is running.
    RUNNING = 1

    # Optimization has completed.
    COMPLETED = 2

    # Optimization failed due to an internal error.
    ERROR = 3
  end
end