Class: Google::Cloud::Ces::V1beta::QualityReport

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/ces/v1beta/agent_service.rb

Overview

The report describing any identified quality issues in the app.

Defined Under Namespace

Classes: AgentIssues, Issue

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_runs::Array<::String>

Returns Optional. A list of evaluation runs used to generate the quality report. Format: projects/{project}/locations/{location}/evaluationRuns/{evaluationRun}.

Returns:

  • (::Array<::String>)

    Optional. A list of evaluation runs used to generate the quality report. Format: projects/{project}/locations/{location}/evaluationRuns/{evaluationRun}.



1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1492

class QualityReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The issue identified.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the issue found.
  # @!attribute [rw] occurrence_count
  #   @return [::Integer]
  #     Optional. How many times this issue occurred.
  # @!attribute [rw] proposed_solution
  #   @return [::String]
  #     Optional. Proposed solution to fix the issue by modifying instructions or
  #     tools.
  class Issue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Issues identified for a single agent.
  # @!attribute [rw] agent
  #   @return [::String]
  #     Optional. The name of the agent to which the issues are related.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/agents/{agent}`
  # @!attribute [rw] issues
  #   @return [::Array<::Google::Cloud::Ces::V1beta::QualityReport::Issue>]
  #     Optional. List of issues found for this agent.
  class AgentIssues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#general_issues::Array<::Google::Cloud::Ces::V1beta::QualityReport::Issue>

Returns Optional. General issues not specific to any agent.

Returns:



1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1492

class QualityReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The issue identified.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the issue found.
  # @!attribute [rw] occurrence_count
  #   @return [::Integer]
  #     Optional. How many times this issue occurred.
  # @!attribute [rw] proposed_solution
  #   @return [::String]
  #     Optional. Proposed solution to fix the issue by modifying instructions or
  #     tools.
  class Issue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Issues identified for a single agent.
  # @!attribute [rw] agent
  #   @return [::String]
  #     Optional. The name of the agent to which the issues are related.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/agents/{agent}`
  # @!attribute [rw] issues
  #   @return [::Array<::Google::Cloud::Ces::V1beta::QualityReport::Issue>]
  #     Optional. List of issues found for this agent.
  class AgentIssues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#issues::Array<::Google::Cloud::Ces::V1beta::QualityReport::AgentIssues>

Returns Optional. The issues grouped by agent.

Returns:



1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1492

class QualityReport
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The issue identified.
  # @!attribute [rw] description
  #   @return [::String]
  #     Optional. Description of the issue found.
  # @!attribute [rw] occurrence_count
  #   @return [::Integer]
  #     Optional. How many times this issue occurred.
  # @!attribute [rw] proposed_solution
  #   @return [::String]
  #     Optional. Proposed solution to fix the issue by modifying instructions or
  #     tools.
  class Issue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Issues identified for a single agent.
  # @!attribute [rw] agent
  #   @return [::String]
  #     Optional. The name of the agent to which the issues are related.
  #     Format:
  #     `projects/{project}/locations/{location}/apps/{app}/agents/{agent}`
  # @!attribute [rw] issues
  #   @return [::Array<::Google::Cloud::Ces::V1beta::QualityReport::Issue>]
  #     Optional. List of issues found for this agent.
  class AgentIssues
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end