Class: Google::Cloud::Ces::V1beta::RetrieveToolsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::RetrieveToolsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/tool_service.rb
Overview
Request message for ToolService.RetrieveTools.
Instance Attribute Summary collapse
-
#tool_ids ⇒ ::Array<::String>
Optional.
-
#toolset ⇒ ::String
Required.
Instance Attribute Details
#tool_ids ⇒ ::Array<::String>
Returns Optional. The identifiers of the tools to retrieve from the toolset. If empty, all tools in the toolset will be returned.
156 157 158 159 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 156 class RetrieveToolsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#toolset ⇒ ::String
Returns Required. The name of the toolset to retrieve the tools for.
Format:
projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}.
156 157 158 159 |
# File 'proto_docs/google/cloud/ces/v1beta/tool_service.rb', line 156 class RetrieveToolsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |