Class: Google::Cloud::Ces::V1beta::RunEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::RunEvaluationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
Request message for EvaluationService.RunEvaluation.
Instance Attribute Summary collapse
-
#app ⇒ ::String
Required.
-
#app_version ⇒ ::String
Optional.
-
#config ⇒ ::Google::Cloud::Ces::V1beta::EvaluationConfig
Optional.
-
#display_name ⇒ ::String
Optional.
-
#evaluation_dataset ⇒ ::String
Optional.
-
#evaluations ⇒ ::Array<::String>
Optional.
-
#generate_latency_report ⇒ ::Boolean
Optional.
-
#golden_run_method ⇒ ::Google::Cloud::Ces::V1beta::GoldenRunMethod
Optional.
-
#optimization_config ⇒ ::Google::Cloud::Ces::V1beta::OptimizationConfig
Optional.
-
#persona_run_configs ⇒ ::Array<::Google::Cloud::Ces::V1beta::PersonaRunConfig>
Optional.
-
#run_count ⇒ ::Integer
Optional.
-
#scheduled_evaluation_run ⇒ ::String
Optional.
Instance Attribute Details
#app ⇒ ::String
Returns Required. The app to evaluate.
Format:
projects/{project}/locations/{location}/apps/{app}.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#app_version ⇒ ::String
Returns Optional. The app version to evaluate.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#config ⇒ ::Google::Cloud::Ces::V1beta::EvaluationConfig
Returns Optional. The configuration to use for the run.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. The display name of the evaluation run.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_dataset ⇒ ::String
Returns Optional. An evaluation dataset to run.
Format:
projects/{project}/locations/{location}/apps/{app}/evaluationDatasets/{evaluationDataset}.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluations ⇒ ::Array<::String>
Returns Optional. List of evaluations to run.
Format:
projects/{project}/locations/{location}/apps/{app}/evaluations/{evaluation}.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#generate_latency_report ⇒ ::Boolean
Returns Optional. Whether to generate a latency report for the evaluation run.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#golden_run_method ⇒ ::Google::Cloud::Ces::V1beta::GoldenRunMethod
Returns Optional. The method to run the evaluation if it is a golden evaluation. If not set, default to STABLE.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#optimization_config ⇒ ::Google::Cloud::Ces::V1beta::OptimizationConfig
Returns Optional. Configuration for running the optimization step after the evaluation run. If not set, the optimization step will not be run.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#persona_run_configs ⇒ ::Array<::Google::Cloud::Ces::V1beta::PersonaRunConfig>
Returns Optional. The configuration to use for the run per persona.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#run_count ⇒ ::Integer
Returns Optional. The number of times to run the evaluation. If not set, the default value is 1 per golden, and 5 per scenario.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scheduled_evaluation_run ⇒ ::String
Returns Optional. The resource name of the ScheduledEvaluationRun that is
triggering this evaluation run.
If this field is set, the scheduled_evaluation_run field on the created
EvaluationRun resource will be populated from this value.
Format:
projects/{project}/locations/{location}/apps/{app}/scheduledEvaluationRuns/{scheduled_evaluation_run}.
1463 1464 1465 1466 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1463 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |