Class: Google::Cloud::Ces::V1beta::ScheduledEvaluationRun
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ScheduledEvaluationRun
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
Represents a scheduled evaluation run configuration.
Defined Under Namespace
Classes: SchedulingConfig
Instance Attribute Summary collapse
-
#active ⇒ ::Boolean
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#created_by ⇒ ::String
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#etag ⇒ ::String
readonly
Output only.
-
#last_completed_run ⇒ ::String
readonly
Output only.
-
#last_updated_by ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#next_scheduled_execution_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#request ⇒ ::Google::Cloud::Ces::V1beta::RunEvaluationRequest
Required.
-
#scheduling_config ⇒ ::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig
Required.
-
#total_executions ⇒ ::Integer
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#active ⇒ ::Boolean
Returns Optional. Whether this config is active.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the scheduled evaluation run was created.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#created_by ⇒ ::String (readonly)
Returns Output only. The user who created the scheduled evaluation run.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#description ⇒ ::String
Returns Optional. User-defined description of the scheduled evaluation run.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#display_name ⇒ ::String
Returns Required. User-defined display name of the scheduled evaluation run config.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#etag ⇒ ::String (readonly)
Returns Output only. Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#last_completed_run ⇒ ::String (readonly)
Returns Output only. The last successful EvaluationRun of this scheduled execution.
Format:
projects/{project}/locations/{location}/apps/{app}/evaluationRuns/{evaluationRun}.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#last_updated_by ⇒ ::String (readonly)
Returns Output only. The user who last updated the evaluation.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#name ⇒ ::String
Returns Identifier. The unique identifier of the scheduled evaluation run config. Format: projects/{projectId}/locations/{locationId}/apps/{appId}/scheduledEvaluationRuns/{scheduledEvaluationRunId}.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#next_scheduled_execution_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The next time this is scheduled to execute.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#request ⇒ ::Google::Cloud::Ces::V1beta::RunEvaluationRequest
Returns Required. The RunEvaluationRequest to schedule.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#scheduling_config ⇒ ::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig
Returns Required. Configuration for the timing and frequency with which to execute the evaluations.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#total_executions ⇒ ::Integer (readonly)
Returns Output only. The total number of times this run has been executed.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the evaluation was last updated.
1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1518 class ScheduledEvaluationRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Eval scheduling configuration details # @!attribute [rw] frequency # @return [::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency] # Required. The frequency with which to run the eval # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Required. Timestamp when the eval should start. # @!attribute [rw] days_of_week # @return [::Array<::Integer>] # Optional. The days of the week to run the eval. Applicable only for # Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is # Sunday. class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end end |