Class: Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation.rb
Overview
Eval scheduling configuration details
Defined Under Namespace
Modules: Frequency
Instance Attribute Summary collapse
-
#days_of_week ⇒ ::Array<::Integer>
Optional.
-
#frequency ⇒ ::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency
Required.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
Required.
Instance Attribute Details
#days_of_week ⇒ ::Array<::Integer>
Returns Optional. The days of the week to run the eval. Applicable only for Weekly and Biweekly frequencies. 1 is Monday, 2 is Tuesday, ..., 7 is Sunday.
1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1603 class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end |
#frequency ⇒ ::Google::Cloud::Ces::V1beta::ScheduledEvaluationRun::SchedulingConfig::Frequency
Returns Required. The frequency with which to run the eval.
1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1603 class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Timestamp when the eval should start.
1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation.rb', line 1603 class SchedulingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The frequencies evals can be run at module Frequency # The frequency is unspecified. FREQUENCY_UNSPECIFIED = 0 # Indicates a one-time scheduled run that should not repeat NONE = 1 # Run the evaluation daily. DAILY = 2 # Run the evaluation weekly. WEEKLY = 3 # Run the evaluation biweekly. BIWEEKLY = 4 end end |