Class: Google::Cloud::Ces::V1beta::SessionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::SessionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/session_service.rb
Overview
The configuration for the session.
Defined Under Namespace
Classes: RemoteDialogflowQueryParameters
Instance Attribute Summary collapse
-
#deployment ⇒ ::String
Optional.
-
#enable_text_streaming ⇒ ::Boolean
Optional.
-
#entry_agent ⇒ ::String
Optional.
-
#historical_contexts ⇒ ::Array<::Google::Cloud::Ces::V1beta::Message>
Optional.
-
#input_audio_config ⇒ ::Google::Cloud::Ces::V1beta::InputAudioConfig
Optional.
-
#output_audio_config ⇒ ::Google::Cloud::Ces::V1beta::OutputAudioConfig
Optional.
-
#remote_dialogflow_query_parameters ⇒ ::Google::Cloud::Ces::V1beta::SessionConfig::RemoteDialogflowQueryParameters
Optional.
-
#session ⇒ ::String
Required.
-
#time_zone ⇒ ::String
Optional.
-
#use_tool_fakes ⇒ ::Boolean
Optional.
Instance Attribute Details
#deployment ⇒ ::String
Returns Optional. The deployment of the app to use for the session.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#enable_text_streaming ⇒ ::Boolean
Returns Optional. Whether to enable streaming text outputs from the model. By default, text outputs from the model are collected before sending to the client. NOTE: This is only supported for text (non-voice) sessions via StreamRunSession or BidiRunSession.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#entry_agent ⇒ ::String
Returns Optional. The entry agent to handle the session. If not specified, the
session will be handled by the [root
agent][google.cloud.ces.v1beta.App.root_agent] of the app. Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#historical_contexts ⇒ ::Array<::Google::Cloud::Ces::V1beta::Message>
Returns Optional. The historical context of the session, including user inputs, agent responses, and other messages. Typically, CES agent would manage session automatically so client doesn't need to explicitly populate this field. However, client can optionally override the historical contexts to force the session start from certain state.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#input_audio_config ⇒ ::Google::Cloud::Ces::V1beta::InputAudioConfig
Returns Optional. Configuration for processing the input audio.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#output_audio_config ⇒ ::Google::Cloud::Ces::V1beta::OutputAudioConfig
Returns Optional. Configuration for generating the output audio.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#remote_dialogflow_query_parameters ⇒ ::Google::Cloud::Ces::V1beta::SessionConfig::RemoteDialogflowQueryParameters
Returns Optional. QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#session ⇒ ::String
Returns Required. The unique identifier of the session.
Format:
projects/{project}/locations/{location}/apps/{app}/sessions/{session}.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#time_zone ⇒ ::String
Returns Optional. The time zone of the user. If provided, the agent will use the time zone for date and time related variables. Otherwise, the agent will use the time zone specified in the App.time_zone_settings.
The format is the IANA Time Zone Database time zone, e.g. "America/Los_Angeles".
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#use_tool_fakes ⇒ ::Boolean
Returns Optional. Whether to use tool fakes for the session. If this field is set, the agent will attempt use tool fakes instead of calling the real tools.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 138 class SessionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters) # to send to the remote # [Dialogflow](https://cloud.google.com/dialogflow/cx/docs/concept/console-conversational-agents) # agent when the session control is transferred to the remote agent. # @!attribute [rw] webhook_headers # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. The HTTP headers to be sent as webhook_headers in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] payload # @return [::Google::Protobuf::Struct] # Optional. The payload to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). # @!attribute [rw] end_user_metadata # @return [::Google::Protobuf::Struct] # Optional. The end user metadata to be sent in # [QueryParameters](https://cloud.google.com/dialogflow/cx/docs/reference/rpc/google.cloud.dialogflow.cx.v3#queryparameters). class RemoteDialogflowQueryParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class WebhookHeadersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |