Class: Google::Cloud::Ces::V1beta::SessionInput
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::SessionInput
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/session_service.rb
Overview
Input for the session.
Instance Attribute Summary collapse
-
#audio ⇒ ::String
Optional.
-
#blob ⇒ ::Google::Cloud::Ces::V1beta::Blob
Optional.
-
#dtmf ⇒ ::String
Optional.
-
#event ⇒ ::Google::Cloud::Ces::V1beta::Event
Optional.
-
#image ⇒ ::Google::Cloud::Ces::V1beta::Image
Optional.
-
#text ⇒ ::String
Optional.
-
#tool_responses ⇒ ::Google::Cloud::Ces::V1beta::ToolResponses
Optional.
-
#variables ⇒ ::Google::Protobuf::Struct
Optional.
-
#will_continue ⇒ ::Boolean
Optional.
Instance Attribute Details
#audio ⇒ ::String
Returns Optional. Audio data from the end user.
Note: The following fields are mutually exclusive: audio, text, dtmf, tool_responses, image, blob, variables, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#blob ⇒ ::Google::Cloud::Ces::V1beta::Blob
Returns Optional. Blob data from the end user.
Note: The following fields are mutually exclusive: blob, text, dtmf, audio, tool_responses, image, variables, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dtmf ⇒ ::String
Returns Optional. DTMF digits from the end user.
Note: The following fields are mutually exclusive: dtmf, text, audio, tool_responses, image, blob, variables, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event ⇒ ::Google::Cloud::Ces::V1beta::Event
Returns Optional. Event input.
Note: The following fields are mutually exclusive: event, text, dtmf, audio, tool_responses, image, blob, variables. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image ⇒ ::Google::Cloud::Ces::V1beta::Image
Returns Optional. Image data from the end user.
Note: The following fields are mutually exclusive: image, text, dtmf, audio, tool_responses, blob, variables, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::String
Returns Optional. Text data from the end user.
Note: The following fields are mutually exclusive: text, dtmf, audio, tool_responses, image, blob, variables, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_responses ⇒ ::Google::Cloud::Ces::V1beta::ToolResponses
Returns Optional. Execution results for the tool calls from the client.
Note: The following fields are mutually exclusive: tool_responses, text, dtmf, audio, image, blob, variables, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variables ⇒ ::Google::Protobuf::Struct
Returns Optional. Contextual variables for the session, keyed by name. Only variables declared in the app will be used by the CES agent.
Unrecognized variables will still be sent to the [Dialogflow agent][Agent.RemoteDialogflowAgent] as additional session parameters.
Note: The following fields are mutually exclusive: variables, text, dtmf, audio, tool_responses, image, blob, event. If a field in that set is populated, all other fields in the set will automatically be cleared.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#will_continue ⇒ ::Boolean
Returns Optional. A flag to indicate if the current message is a fragment of a larger input in the bidi streaming session.
When set to true, the agent defers processing until it receives a
subsequent message where will_continue is false, or until the system
detects an endpoint in the audio input.
NOTE: This field does not apply to audio and DTMF inputs, as they are always processed automatically based on the endpointing signal.
281 282 283 284 |
# File 'proto_docs/google/cloud/ces/v1beta/session_service.rb', line 281 class SessionInput include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |