Class: Google::Cloud::Ces::V1beta::SessionService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::SessionService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/ces/v1beta/session_service/client.rb
Overview
Client for the SessionService service.
Session service provides APIs for interacting with CES agents.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Client
readonly
Get the associated client for mix-in of the Locations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client class.
Instance Method Summary collapse
-
#bidi_run_session(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::BidiSessionServerMessage>
Establishes a bidirectional streaming connection with the CES agent.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new SessionService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#run_session(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Ces::V1beta::RunSessionResponse
Initiates a single-turn interaction with the CES agent within a session.
-
#stream_run_session(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::RunSessionResponse>
Initiates a single-turn interaction with the CES agent.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#agent_path, #session_path, #tool_path, #toolset_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new SessionService client object.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 140 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/ces/v1beta/session_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @session_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Ces::V1beta::SessionService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @session_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @session_service_stub.endpoint config.universe_domain = @session_service_stub.universe_domain config.logger = @session_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Client (readonly)
Get the associated client for mix-in of the Locations.
204 205 206 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 204 def location_client @location_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Ces", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.run_session.timeout = 220.0 default_config.rpcs.run_session.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [] } default_config.rpcs.bidi_run_session.timeout = 3600.0 default_config.rpcs.bidi_run_session.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#bidi_run_session(request, options = nil) {|response, operation| ... } ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::BidiSessionServerMessage>
Establishes a bidirectional streaming connection with the CES agent. The agent processes continuous multimodal inputs (e.g., text, audio) and generates real-time multimodal output streams.
--- Client Request Stream --- The client streams requests in the following order:
Initialization: The first message must contain SessionConfig. For audio sessions, this should also include InputAudioConfig and OutputAudioConfig to define audio processing and synthesis parameters.
Interaction: Subsequent messages stream SessionInput containing real-time user input data.
Termination: The client should half-close the stream when there is no more user input. It should also half-close upon receiving EndSession or GoAway from the agent.
--- Server Response Stream --- For each interaction turn, the agent streams messages in the following sequence:
Speech Recognition (First N messages): Contains RecognitionResult representing the concatenated user speech segments captured so far. This is only populated for audio sessions.
Response (Next M messages): Contains SessionOutput delivering the agent's response in various modalities (e.g., text, audio).
Turn Completion (Final message of the turn): Contains SessionOutput with turn_completed set to true. This signals the end of the current turn and includes DiagnosticInfo with execution details.
--- Audio Best Practices ---
Streaming: Stream audio data CONTINUOUSLY, even during silence. Recommended chunk size: 40-120ms (balances latency vs. efficiency).
Playback & Interruption: Play audio responses upon receipt. Stop playback immediately if an InterruptionSignal is received (e.g., user barge-in or new agent response).
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 505 def bidi_run_session request, = nil unless request.is_a? ::Enumerable raise ::ArgumentError, "request must be an Enumerable" unless request.respond_to? :to_enum request = request.to_enum end request = request.lazy.map do |req| ::Gapic::Protobuf.coerce req, to: ::Google::Cloud::Ces::V1beta::BidiSessionClientMessage end # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bidi_run_session..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.bidi_run_session.timeout, metadata: , retry_policy: @config.rpcs.bidi_run_session.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @session_service_stub.call_rpc :bidi_run_session, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the SessionService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
110 111 112 113 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 110 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
211 212 213 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 211 def logger @session_service_stub.logger end |
#run_session(request, options = nil) ⇒ ::Google::Cloud::Ces::V1beta::RunSessionResponse #run_session(config: nil, inputs: nil) ⇒ ::Google::Cloud::Ces::V1beta::RunSessionResponse
Initiates a single-turn interaction with the CES agent within a session.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 263 def run_session request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::RunSessionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.run_session..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.config&.session header_params["config.session"] = request.config.session end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.run_session.timeout, metadata: , retry_policy: @config.rpcs.run_session.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @session_service_stub.call_rpc :run_session, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#stream_run_session(request, options = nil) ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::RunSessionResponse> #stream_run_session(config: nil, inputs: nil) ⇒ ::Enumerable<::Google::Cloud::Ces::V1beta::RunSessionResponse>
Initiates a single-turn interaction with the CES agent. Uses server-side streaming to deliver incremental results and partial responses as they are generated.
By default, complete responses (e.g., messages from callbacks or full LLM responses) are sent to the client as soon as they are available. To enable streaming individual text chunks directly from the model, set enable_text_streaming to true.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 361 def stream_run_session request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Ces::V1beta::RunSessionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.stream_run_session..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Ces::V1beta::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.config&.session header_params["config.session"] = request.config.session end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.stream_run_session.timeout, metadata: , retry_policy: @config.rpcs.stream_run_session.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @session_service_stub.call_rpc :stream_run_session, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
120 121 122 |
# File 'lib/google/cloud/ces/v1beta/session_service/client.rb', line 120 def universe_domain @session_service_stub.universe_domain end |