Class: Google::Cloud::Ces::V1beta::Span
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Span
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/common.rb
Overview
A span is a unit of work or a single operation during the request processing.
Instance Attribute Summary collapse
-
#attributes ⇒ ::Google::Protobuf::Struct
readonly
Output only.
-
#child_spans ⇒ ::Array<::Google::Cloud::Ces::V1beta::Span>
readonly
Output only.
-
#duration ⇒ ::Google::Protobuf::Duration
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#attributes ⇒ ::Google::Protobuf::Struct (readonly)
Returns Output only. Key-value attributes associated with the span.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 353 class Span include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#child_spans ⇒ ::Array<::Google::Cloud::Ces::V1beta::Span> (readonly)
Returns Output only. The child spans that are nested under this span.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 353 class Span include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#duration ⇒ ::Google::Protobuf::Duration (readonly)
Returns Output only. The duration of the span.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 353 class Span include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The end time of the span.
353 354 355 356 |
# File 'proto_docs/google/cloud/ces/v1beta/common.rb', line 353 class Span include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |