Class: Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::SynthesizeSpeechConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
Configuration for how the agent response should be synthesized.
Instance Attribute Summary collapse
-
#instruction ⇒ ::String
Optional.
-
#model ⇒ ::String
Optional.
-
#speaking_rate ⇒ ::Float
Optional.
-
#voice ⇒ ::String
Optional.
-
#voice_sample_gcs_uri ⇒ ::String
Optional.
Instance Attribute Details
#instruction ⇒ ::String
Returns Optional. The instruction used to synthesize speech when using a generative model.
388 389 390 391 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 388 class SynthesizeSpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#model ⇒ ::String
Returns Optional. The model used to synthesize audio. Currently supported values:
- "gemini-3.1-flash-tts-preview" If empty, Chirp3-HD is used.
388 389 390 391 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 388 class SynthesizeSpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#speaking_rate ⇒ ::Float
Optional. The speaking rate/speed in the range [0.25, 2.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. Values outside of the range [0.25, 2.0] will return an error.
388 389 390 391 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 388 class SynthesizeSpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#voice ⇒ ::String
Returns Optional. The name of the voice. If not set, the service will choose a voice based on the other parameters such as language_code.
For the list of available voices, please refer to Supported voices and languages from Cloud Text-to-Speech.
388 389 390 391 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 388 class SynthesizeSpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#voice_sample_gcs_uri ⇒ ::String
Returns Optional. The Cloud Storage URI to the audio sample for voice cloning. The audio sample should be a mono-channel, 24kHz WAV file.
Note: Please make sure the CES service agent
service-<PROJECT-NUMBER>@gcp-sa-ces.iam.gserviceaccount.com has
storage.objects.get permission to the Cloud Storage object.
388 389 390 391 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 388 class SynthesizeSpeechConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |