Class: Google::Cloud::Ces::V1beta::Toolset
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::Toolset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/toolset.rb
Overview
A toolset represents a group of dynamically managed tools that can be used by the agent.
Instance Attribute Summary collapse
-
#connector_toolset ⇒ ::Google::Cloud::Ces::V1beta::ConnectorToolset
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Optional.
-
#etag ⇒ ::String
ETag used to ensure the object hasn't changed during a read-modify-write operation.
-
#execution_type ⇒ ::Google::Cloud::Ces::V1beta::ExecutionType
Optional.
-
#mcp_toolset ⇒ ::Google::Cloud::Ces::V1beta::McpToolset
Optional.
-
#name ⇒ ::String
Identifier.
-
#open_api_toolset ⇒ ::Google::Cloud::Ces::V1beta::OpenApiToolset
Optional.
-
#tool_fake_config ⇒ ::Google::Cloud::Ces::V1beta::ToolFakeConfig
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#connector_toolset ⇒ ::Google::Cloud::Ces::V1beta::ConnectorToolset
Returns Optional. A toolset that generates tools from an Integration Connectors Connection.
Note: The following fields are mutually exclusive: connector_toolset, mcp_toolset, open_api_toolset. If a field in that set is populated, all other fields in the set will automatically be cleared.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the toolset was created.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. The description of the toolset.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. The display name of the toolset. Must be unique within the same app.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String
Returns ETag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#execution_type ⇒ ::Google::Cloud::Ces::V1beta::ExecutionType
Returns Optional. The execution type of the tools in the toolset.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mcp_toolset ⇒ ::Google::Cloud::Ces::V1beta::McpToolset
Returns Optional. A toolset that contains a list of tools that are offered by the MCP server.
Note: The following fields are mutually exclusive: mcp_toolset, open_api_toolset, connector_toolset. If a field in that set is populated, all other fields in the set will automatically be cleared.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The unique identifier of the toolset.
Format:
projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#open_api_toolset ⇒ ::Google::Cloud::Ces::V1beta::OpenApiToolset
Returns Optional. A toolset that contains a list of tools that are defined by an OpenAPI schema.
Note: The following fields are mutually exclusive: open_api_toolset, mcp_toolset, connector_toolset. If a field in that set is populated, all other fields in the set will automatically be cleared.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tool_fake_config ⇒ ::Google::Cloud::Ces::V1beta::ToolFakeConfig
Returns Optional. Configuration for tools behavior in fake mode.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the toolset was last updated.
73 74 75 76 |
# File 'proto_docs/google/cloud/ces/v1beta/toolset.rb', line 73 class Toolset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |