Class: Google::Cloud::Ces::V1beta::TransferRule
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::TransferRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_transfers.rb
Overview
Rule for transferring to a specific agent.
Defined Under Namespace
Modules: Direction Classes: DeterministicTransfer, DisablePlannerTransfer
Instance Attribute Summary collapse
-
#child_agent ⇒ ::String
Required.
-
#deterministic_transfer ⇒ ::Google::Cloud::Ces::V1beta::TransferRule::DeterministicTransfer
Optional.
-
#direction ⇒ ::Google::Cloud::Ces::V1beta::TransferRule::Direction
Required.
-
#disable_planner_transfer ⇒ ::Google::Cloud::Ces::V1beta::TransferRule::DisablePlannerTransfer
Optional.
Instance Attribute Details
#child_agent ⇒ ::String
Returns Required. The resource name of the child agent the rule applies to.
Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 63 class TransferRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deterministic transfer rule. When the condition evaluates to true, the # transfer occurs. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Optional. A rule that evaluates a session state condition. # If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `expression_condition`, `python_code_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] python_code_condition # @return [::Google::Cloud::Ces::V1beta::PythonCodeCondition] # Optional. A rule that uses Python code block to evaluate the # conditions. If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `python_code_condition`, `expression_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. class DeterministicTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A rule that prevents the planner from transferring to the target agent. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Required. If the condition evaluates to true, planner will not be allowed # to transfer to the target agent. class DisablePlannerTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The direction of the transfer. module Direction # Unspecified direction. DIRECTION_UNSPECIFIED = 0 # Transfer from the parent agent to the child agent. PARENT_TO_CHILD = 1 # Transfer from the child agent to the parent agent. CHILD_TO_PARENT = 2 end end |
#deterministic_transfer ⇒ ::Google::Cloud::Ces::V1beta::TransferRule::DeterministicTransfer
Returns Optional. A rule that immediately transfers to the target agent when the condition is met.
Note: The following fields are mutually exclusive: deterministic_transfer, disable_planner_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 63 class TransferRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deterministic transfer rule. When the condition evaluates to true, the # transfer occurs. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Optional. A rule that evaluates a session state condition. # If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `expression_condition`, `python_code_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] python_code_condition # @return [::Google::Cloud::Ces::V1beta::PythonCodeCondition] # Optional. A rule that uses Python code block to evaluate the # conditions. If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `python_code_condition`, `expression_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. class DeterministicTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A rule that prevents the planner from transferring to the target agent. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Required. If the condition evaluates to true, planner will not be allowed # to transfer to the target agent. class DisablePlannerTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The direction of the transfer. module Direction # Unspecified direction. DIRECTION_UNSPECIFIED = 0 # Transfer from the parent agent to the child agent. PARENT_TO_CHILD = 1 # Transfer from the child agent to the parent agent. CHILD_TO_PARENT = 2 end end |
#direction ⇒ ::Google::Cloud::Ces::V1beta::TransferRule::Direction
Returns Required. The direction of the transfer.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 63 class TransferRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deterministic transfer rule. When the condition evaluates to true, the # transfer occurs. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Optional. A rule that evaluates a session state condition. # If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `expression_condition`, `python_code_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] python_code_condition # @return [::Google::Cloud::Ces::V1beta::PythonCodeCondition] # Optional. A rule that uses Python code block to evaluate the # conditions. If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `python_code_condition`, `expression_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. class DeterministicTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A rule that prevents the planner from transferring to the target agent. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Required. If the condition evaluates to true, planner will not be allowed # to transfer to the target agent. class DisablePlannerTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The direction of the transfer. module Direction # Unspecified direction. DIRECTION_UNSPECIFIED = 0 # Transfer from the parent agent to the child agent. PARENT_TO_CHILD = 1 # Transfer from the child agent to the parent agent. CHILD_TO_PARENT = 2 end end |
#disable_planner_transfer ⇒ ::Google::Cloud::Ces::V1beta::TransferRule::DisablePlannerTransfer
Returns Optional. Rule that prevents the planner from transferring to the target agent.
Note: The following fields are mutually exclusive: disable_planner_transfer, deterministic_transfer. If a field in that set is populated, all other fields in the set will automatically be cleared.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 63 class TransferRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Deterministic transfer rule. When the condition evaluates to true, the # transfer occurs. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Optional. A rule that evaluates a session state condition. # If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `expression_condition`, `python_code_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] python_code_condition # @return [::Google::Cloud::Ces::V1beta::PythonCodeCondition] # Optional. A rule that uses Python code block to evaluate the # conditions. If the condition evaluates to true, the transfer occurs. # # Note: The following fields are mutually exclusive: `python_code_condition`, `expression_condition`. If a field in that set is populated, all other fields in the set will automatically be cleared. class DeterministicTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A rule that prevents the planner from transferring to the target agent. # @!attribute [rw] expression_condition # @return [::Google::Cloud::Ces::V1beta::ExpressionCondition] # Required. If the condition evaluates to true, planner will not be allowed # to transfer to the target agent. class DisablePlannerTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The direction of the transfer. module Direction # Unspecified direction. DIRECTION_UNSPECIFIED = 0 # Transfer from the parent agent to the child agent. PARENT_TO_CHILD = 1 # Transfer from the child agent to the parent agent. CHILD_TO_PARENT = 2 end end |