Class: Google::Cloud::Ces::V1beta::TransferRule::DisablePlannerTransfer
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::TransferRule::DisablePlannerTransfer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_transfers.rb
Overview
A rule that prevents the planner from transferring to the target agent.
Instance Attribute Summary collapse
Instance Attribute Details
#expression_condition ⇒ ::Google::Cloud::Ces::V1beta::ExpressionCondition
Returns Required. If the condition evaluates to true, planner will not be allowed to transfer to the target agent.
91 92 93 94 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_transfers.rb', line 91 class DisablePlannerTransfer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |