Class: Google::Cloud::Ces::V1beta::UpdateAgentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::UpdateAgentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.UpdateAgent.
Instance Attribute Summary collapse
-
#agent ⇒ ::Google::Cloud::Ces::V1beta::Agent
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#agent ⇒ ::Google::Cloud::Ces::V1beta::Agent
Returns Required. The agent to update.
367 368 369 370 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 367 class UpdateAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
367 368 369 370 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 367 class UpdateAgentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |