Class: Google::Cloud::Ces::V1beta::UpdateAppRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::UpdateAppRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.UpdateApp.
Instance Attribute Summary collapse
-
#app ⇒ ::Google::Cloud::Ces::V1beta::App
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#app ⇒ ::Google::Cloud::Ces::V1beta::App
Returns Required. The app to update.
109 110 111 112 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 109 class UpdateAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
109 110 111 112 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 109 class UpdateAppRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |