Class: Google::Cloud::Ces::V1beta::UpdateSecuritySettingsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::UpdateSecuritySettingsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/agent_service.rb
Overview
Request message for AgentService.UpdateSecuritySettings.
Instance Attribute Summary collapse
-
#security_settings ⇒ ::Google::Cloud::Ces::V1beta::SecuritySettings
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
Instance Attribute Details
#security_settings ⇒ ::Google::Cloud::Ces::V1beta::SecuritySettings
Returns Required. The security settings to update.
1654 1655 1656 1657 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1654 class UpdateSecuritySettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.
1654 1655 1656 1657 |
# File 'proto_docs/google/cloud/ces/v1beta/agent_service.rb', line 1654 class UpdateSecuritySettingsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |