Class: Google::Cloud::Ces::V1beta::UploadEvaluationAudioResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::UploadEvaluationAudioResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/evaluation_service.rb
Overview
Response message for EvaluationService.UploadEvaluationAudio.
Instance Attribute Summary collapse
-
#audio_gcs_uri ⇒ ::String
The Google Cloud Storage URI where the uploaded audio file is stored.
-
#duration ⇒ ::Google::Protobuf::Duration
The duration of the audio.
-
#transcript ⇒ ::String
The transcript of the audio, generated by Cloud Speech-to-Text.
Instance Attribute Details
#audio_gcs_uri ⇒ ::String
Returns The Google Cloud Storage URI where the uploaded audio file is stored.
Format: gs://<bucket-name>/<object-name>.
758 759 760 761 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 758 class UploadEvaluationAudioResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#duration ⇒ ::Google::Protobuf::Duration
Returns The duration of the audio.
758 759 760 761 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 758 class UploadEvaluationAudioResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transcript ⇒ ::String
Returns The transcript of the audio, generated by Cloud Speech-to-Text.
758 759 760 761 |
# File 'proto_docs/google/cloud/ces/v1beta/evaluation_service.rb', line 758 class UploadEvaluationAudioResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |