Class: Google::Cloud::Ces::V1beta::VpcScSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Ces::V1beta::VpcScSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/ces/v1beta/app.rb
Overview
VPC-SC settings for the app.
Instance Attribute Summary collapse
-
#allowed_origins ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#allowed_origins ⇒ ::Array<::String>
Returns Optional. The allowed HTTP(s) origins that OpenAPI tools in the App are able to directly call when VPC Service Controls are enabled. These strings must match the origin exactly, including the port if specified. For example, "https://example.com" or "https://example.com:443". This list does not yet apply to Python tools that may make direct HTTP calls.
696 697 698 699 |
# File 'proto_docs/google/cloud/ces/v1beta/app.rb', line 696 class VpcScSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |